@@ -6,5 +6,8 @@ then
 	exit
 fi
 
+theDate=`date +"Created_%Y%m%d_%H%M%S"`
+touch "$theDate"
 tar -czf ../tar/qdvdauthor-$1.tar.gz `find . -type f | grep -v "\.svn"`
+rm "$theDate"
 
