@@ -1,16 +1,20 @@
 /****************************************************************************
-** ImagePreview class
+** ButtonObject class
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
+** This class is the encapsulation of the ButtonObject. 
+** 
+** A ButtonObject is the object in a menu which was created by
+** either dragging a SourceFileEntry over to the  DVD menu or
+** by choosing "define as button" from the context menu of an 
+** MenuObject.
 **
 ****************************************************************************/
 
 #include <qobject.h>
+#include <qfileinfo.h>
 #include <qlistview.h>
 #include <qpopupmenu.h>
 
@@ -19,9 +23,11 @@
 #include "menupreview.h"
 #include "dialogbutton.h"
 #include "menuobject.h"
+#include "frameobject.h"
 #include "buttonobject.h"
 #include "qdvdauthor.h"
 #include "sourcefileentry.h"
+#include "structuretoolbar.h"
 
 ButtonObject::ButtonObject (QWidget *pParent) //, const char *pName, WFlags flags)
 	: MenuObject (pParent)
@@ -53,10 +59,10 @@ MenuObject *ButtonObject::clone()
 	pNewObject->setSourceFileEntry(sourceFileEntry());
 	pNewObject->setAction(m_qsAction);
 	pNewObject->setName  (m_qsName);
-	pNewObject->setNext (NEXT_BUTTON_UP, m_qsUp);
-	pNewObject->setNext (NEXT_BUTTON_DOWN, m_qsDown);
+	pNewObject->setNext (NEXT_BUTTON_UP,    m_qsUp   );
+	pNewObject->setNext (NEXT_BUTTON_DOWN,  m_qsDown );
 	pNewObject->setNext (NEXT_BUTTON_RIGHT, m_qsRight);
-	pNewObject->setNext (NEXT_BUTTON_LEFT, m_qsLeft);
+	pNewObject->setNext (NEXT_BUTTON_LEFT,  m_qsLeft );
 	
 	return pNewObject;
 }
@@ -173,43 +179,10 @@ bool ButtonObject::mouseMoveEvent (QMouseEvent *pEvent)
 
 bool ButtonObject::mousePressEvent (QMouseEvent *pEvent)
 {
-	int iID = -1;
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
 		QPoint globalPos = pEvent->globalPos();
-
-		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
-		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
-		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
-		pStackMenu->popup(globalPos, 1);
-
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = new QPopupMenu(m_pParent);
-		m_pContextMenu->setCheckable (true);
-		m_pContextMenu->insertItem ( tr ("Edit ..."), (QObject *)this, SLOT(slotEdit     ()));
-		m_pContextMenu->insertItem ( tr ("Unbutton"), (QObject *)this, SLOT(slotUnbutton ()));
-		m_pContextMenu->insertItem ( tr ("Delete")  , (QObject *)this, SLOT(slotDelete   ()));
-		iID = m_pContextMenu->insertItem ( tr ("Moveable"), (QObject *)this, SLOT(slotMoveable ()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( tr ("Add Frame"), (QObject *)this, SLOT(slotAddFrame()));
-		m_pContextMenu->insertItem ( tr ("Add Image"), (QObject *)this, SLOT(slotAddImage()));
-		m_pContextMenu->insertItem ( tr ("Add Movie"), (QObject *)this, SLOT(slotAddMovie()));
-		m_pContextMenu->setItemChecked (iID, m_bMoveable);
-
-		m_pContextMenu->exec(pEvent->globalPos(), 4);
-
-		delete pStackMenu;
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = NULL;
-
-		// Here we mark that the user called a menu item thus we don't want the
-		// base classes to continue with the mouse event
-//		if (iReturn != -1)
-			return true;
-//printf ("Clicked inside TextButton\n");
+		return createContextMenu ( globalPos );
 	}
 	else // Here I only want to activate the drawing of the frame rather then the full thing.
 		if (m_listNormalState[0])
@@ -439,11 +412,49 @@ bool ButtonObject::writeProjectFile (QDomElement &theElement)
 	return MenuObject::writeProjectFile( buttonNode );
 }
 
+bool ButtonObject::createContextMenu (QPoint globalPos)
+{
+	int iID = -1;
+        QPoint globalPos2 = globalPos;
+	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	pStackMenu->popup(globalPos, 1);
+
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = new QPopupMenu(m_pParent);
+	m_pContextMenu->setCheckable (true);
+	m_pContextMenu->insertItem ( tr ("Edit ..."), (QObject *)this, SLOT(slotEdit     ()));
+	m_pContextMenu->insertItem ( tr ("Unbutton"), (QObject *)this, SLOT(slotUnbutton ()));
+	m_pContextMenu->insertItem ( tr ("Delete")  , (QObject *)this, SLOT(slotDelete   ()));
+	iID = m_pContextMenu->insertItem ( tr ("Moveable"), (QObject *)this, SLOT(slotMoveable ()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Add Frame"), (QObject *)this, SLOT(slotAddFrame()));
+	m_pContextMenu->insertItem ( tr ("Add Image"), (QObject *)this, SLOT(slotAddImage()));
+	m_pContextMenu->insertItem ( tr ("Add Movie"), (QObject *)this, SLOT(slotAddMovie()));
+	m_pContextMenu->setItemChecked (iID, m_bMoveable);
+
+	m_pContextMenu->exec(globalPos2, 4);
+
+	delete pStackMenu;
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = NULL;
+
+	// Here we mark that the user called a menu item thus we don't want the
+	// base classes to continue with the mouse event
+//	if (iReturn != -1)
+		return true;
+//printf ("Clicked inside TextButton\n");
+}
+
 void ButtonObject::createStructure (QListViewItem *pParentItem)
 {
 	// Creating teh ListView structure of this Button.
-	QListViewItem *pButtonItem;
-	QListViewItem *pStateItem;
+	StructureItem *pButtonItem;
+	StructureItem *pStateItem;
 
 	QString qsAction;
 	QStringList actionList;
@@ -457,17 +468,17 @@ void ButtonObject::createStructure (QListViewItem *pParentItem)
 				qsAction += QString (" ") +actionList[3];
 		}
 	}
-	pButtonItem = new QListViewItem(pParentItem, m_qsName, qsAction);
+	pButtonItem = new StructureItem(this, pParentItem, m_qsName, qsAction);
 	pButtonItem->setExpandable (TRUE);
 
 	uint t;
 	for (t=0;t<m_listHighlightedState.count();t++)	{
-		pStateItem = new QListViewItem(pButtonItem, QString ("Highlighted"), QString (""));
+	  pStateItem = new StructureItem(this, pButtonItem, QString ("Highlighted"), QString (""));
 		pStateItem->setExpandable (TRUE);
 		m_listHighlightedState[t]->createStructure (pStateItem);
 	}
 	for (t=0;t<m_listSelectedState.count();t++)	{
-		pStateItem = new QListViewItem(pButtonItem, QString ("Selected"), QString (""));
+	  pStateItem = new StructureItem(this, pButtonItem, QString ("Selected"), QString (""));
 		pStateItem->setExpandable (TRUE);
 		m_listSelectedState[t]->createStructure (pStateItem);
 	}
@@ -494,6 +505,27 @@ void ButtonObject::replaceColor (QColor theColor, QColor oldColor)
 	}
 }
 
+QRect &ButtonObject::boundingRect()
+{
+  // Here we have a little special handling for frames to include the frame width
+  // for button objects.
+  static QRect rect;
+  FrameObject  tempFrameObject, *pFrame;
+  int iHalf;
+  rect = m_boundingRect;
+
+  if ( m_listHighlightedState.count () < 1 )
+    return rect;
+
+  if ( m_listHighlightedState[0]->objectType () == tempFrameObject.objectType() ) {
+    pFrame = (FrameObject *)m_listHighlightedState[0];
+    iHalf  = (int)((float)pFrame->width() / 2.0);
+    rect = QRect (m_boundingRect.x()-iHalf, m_boundingRect.y()-iHalf, m_boundingRect.width()+2*iHalf,  m_boundingRect.height()+2*iHalf);
+  }
+
+  return rect;
+}
+
 void ButtonObject::setAction(QString &qsAction)
 {
 	m_qsAction = qsAction;
@@ -523,6 +555,76 @@ SourceFileEntry *ButtonObject::sourceFileEntry()
 	return m_pSourceFileEntry;
 }
 
+SourceFileInfo *ButtonObject::sourceFileInfo()
+{
+  uint            t;
+  QString         qsName;
+  QFileInfo       fileInfo;
+  QStringList     actionList;
+  SourceFileInfo *pInfo = NULL;
+
+  if ( ! m_pSourceFileEntry )
+    return pInfo;
+
+  // default to the first info 
+  pInfo = m_pSourceFileEntry->listFileInfos[0];
+
+  if ( ! m_qsAction.isEmpty() )  {  // For new buttons this might be empty ...
+    actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
+    if (actionList.count() == 4)
+      qsName = actionList[actionList.count() - 2];
+    else if (actionList.count() > 1)
+      qsName = actionList[1];
+  }
+  // find the right sourceFileInfo from the action - string
+  for ( t=0;t<m_pSourceFileEntry->listFileInfos.count();t++ ) {
+    fileInfo.setFile ( m_pSourceFileEntry->listFileInfos[t]->qsFileName );
+    if ( qsName == fileInfo.fileName () )
+      return m_pSourceFileEntry->listFileInfos[t];
+  }
+
+  return pInfo;
+}
+
+int ButtonObject::chapter ( bool bAllEntries )
+{
+  uint t, iTemp;
+  int iChapterNumber = 1;
+  SourceFileEntry *pEntry = sourceFileEntry ();
+  SourceFileInfo  *pInfo  = sourceFileInfo  ();
+  if ( ( ! pEntry ) || ( ! pInfo ) )
+    return 0;  // No Info present ... Error
+  QStringList     actionList;
+
+  if ( ! m_qsAction.isEmpty() )  // For new buttons this might be empty ...
+    actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
+  if ( actionList.count() < 1 )
+    return iChapterNumber;
+  
+  // To get the total chapter number you have to add up the SourceFileInfos
+  // chapters in the SourceFileEntry that come before the actual SourceFIleInfo
+  // on which the button points.
+  iChapterNumber = 1;
+  if ( bAllEntries ) {
+    for (t=0;t<pEntry->listFileInfos.count();t++) {
+      if ( pEntry->listFileInfos[t] == pInfo )
+	break; // break out of the loop
+      iTemp = pEntry->listFileInfos[t]->listChapters.count();
+      iTemp = (iTemp < 1) ? 1: iTemp;
+      iChapterNumber += iTemp;
+    }
+  }
+
+  if ( pInfo->listChapters.count () > 0 ) {
+    for ( t=0;t<pInfo->listChapters.count ();t++ ) {
+      if (pInfo->listChapters[t] == actionList[actionList.count()-1])	// the chapter
+	iChapterNumber += t;
+    }
+  }
+  
+  return iChapterNumber;  // Info present but no chapter info...
+}
+
 void ButtonObject::setNext(uint iNext, QString &qsNext)
 {
 	switch (iNext)	{
