@@ -51,6 +51,7 @@ class QListViewItem;
 #include "menuobject.h"
 
 class SourceFileEntry;
+class SourceFileInfo;
 class MenuPreview;
 
 class ButtonObject : public MenuObject
@@ -67,36 +68,40 @@ public:
 	virtual bool mouseReleaseEvent    (QMouseEvent *);
 	virtual bool mouseDoubleClickEvent(QMouseEvent *);
 	virtual MenuObject *clone();
-	virtual ButtonObject &operator = (ButtonObject &);
+	virtual ButtonObject &operator =  (ButtonObject &);
 
-	virtual bool readProjectFile  (QDomNode &);
-	virtual bool writeProjectFile (QDomElement &);
-	virtual void createStructure (QListViewItem *);
-	void appendNormal (MenuObject *);
-	void appendSelected (MenuObject *);
-	void appendHighlighted (MenuObject *);
+	virtual bool readProjectFile      (QDomNode &);
+	virtual bool writeProjectFile     (QDomElement &);
+	virtual void createStructure      (QListViewItem *);
+	virtual bool createContextMenu    (QPoint);
+	void appendNormal                 (MenuObject *);
+	void appendSelected               (MenuObject *);
+	void appendHighlighted            (MenuObject *);
 
-	MenuObject *getNormal (int);
-	MenuObject *getSelected (int);
-	MenuObject *getHighlighted (int);
+	MenuObject *getNormal             (int);
+	MenuObject *getSelected           (int);
+	MenuObject *getHighlighted        (int);
 	
-	uint getNormalCount ();
-	uint getSelectedCount ();
-	uint getHighlightedCount ();
+	uint getNormalCount               ();
+	uint getSelectedCount             ();
+	uint getHighlightedCount          ();
 
-	void setAction  (QString &);
-	void setNext    (uint, QString &);
-	QString &next(uint);
-	QString &action();
+	int      chapter                  (bool);
+	void setAction                    (QString &);
+	void setNext                      (uint, QString &);
+	QString &next                     (uint);
+	QString &action                   ();
+	QRect &boundingRect               ();
 
-	SourceFileEntry *sourceFileEntry();
-	void setSourceFileEntry (SourceFileEntry *);
+	SourceFileInfo  *sourceFileInfo   ();
+	SourceFileEntry *sourceFileEntry  ();
+	void setSourceFileEntry           (SourceFileEntry *);
 
-	void deleteMasks();
-	bool readObjects (QDomNode &, MenuPreview *);
-	QString &sourceDisplayName ();
+	void deleteMasks                  ();
+	bool readObjects                  (QDomNode &, MenuPreview *);
+	QString &sourceDisplayName        ();
 
-	void replaceColor (QColor, QColor);
+	void replaceColor                 (QColor, QColor);
 
 protected:
 	void clear ();
@@ -104,16 +109,16 @@ protected:
 
 
 signals:
-	void signalUnbuttonMe        (ButtonObject *);
-	void signalCreateButtonDialog(ButtonObject *);
+	void signalUnbuttonMe             (ButtonObject *);
+	void signalCreateButtonDialog     (ButtonObject *);
 
 public slots:
-	virtual void slotEdit    ();
-	virtual void slotUnbutton();
-	virtual void slotMoveable();
-	virtual void slotAddFrame();
-	virtual void slotAddImage();
-	virtual void slotAddMovie();
+	virtual void slotEdit             ();
+	virtual void slotUnbutton         ();
+	virtual void slotMoveable         ();
+	virtual void slotAddFrame         ();
+	virtual void slotAddImage         ();
+	virtual void slotAddMovie         ();
 
 protected:
 	int     m_iButtonState;
