@@ -178,15 +178,17 @@ void ButtonPreview::mouseDoubleClickEvent	(QMouseEvent *pEvent)
 
 QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderFrameNumber, long iTotalFramesToRender)
 {
-	uint t, iCurrentBackgroundFile;
 	if (m_backgroundPixmap.isNull())
 		return m_backgroundPixmap;
 	if (!pInterface)
 		return m_backgroundPixmap;
-	QString   qsFileName, qsFullPath, qsMenuName;
-	QFileInfo fileInfo;
-	QFile     theFile;
-	QDir      theDir;
+
+	uint        t, iCurrentBackgroundFile;
+	QString     qsFileName, qsFullPath, qsMenuName;
+	MenuObject *pMenuObject;
+	QFileInfo   fileInfo;
+	QFile       theFile;
+	QDir        theDir;
 	// ////////////////////////////////////////////////////////////////////////////////////////////
 	// This function renders the frame number iRenderFrameNumber and spits the generated file out as :
 	// /TMP_PATH/PROJECT_NAME/MENU_NAME/background/rendered_$(iRenderFrameNumber).jpg
@@ -245,11 +247,16 @@ QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderF
 			fitDVDMenuBackground (&thePixmap, 0, pInterface->iStretchType, pInterface->posOffset, pInterface->iWidth, pInterface->iHeight);
 //			thePixmap.resize (m_backgroundPixmap.width(), m_backgroundPixmap.height());
 
-
 	QPainter thePainter(&thePixmap);
 	// And here we draw the objects ...
-	for (t=0;t<m_listMenuObjects.count();t++)
-		m_listMenuObjects.at(t)->drawContents (&thePainter, iRenderFrameNumber, iTotalFramesToRender);
+	for (t=0;t<m_listMenuObjects.count();t++)	{
+	  pMenuObject = m_listMenuObjects.at(t);
+	  // Filter out if StopFrame is > 0(property is used) AND the current frame is within the limits
+	  if ( ( pMenuObject->modifiers()->iStopFrame < 1) || 
+	       (  ( iRenderFrameNumber > pMenuObject->modifiers()->iStartFrame ) &&
+		  ( iRenderFrameNumber < pMenuObject->modifiers()->iStopFrame  ) ) )
+	    pMenuObject->drawContents (&thePainter, iRenderFrameNumber, iTotalFramesToRender);
+      }
 
 	float fProgress = (float)iRenderFrameNumber / iTotalFramesToRender;
 	emit (signalRenderProgress (fProgress));
