@@ -72,19 +72,20 @@ ColorToolBar::~ColorToolBar ()
 
 void ColorToolBar::slotColorClicked(int iColor)
 {
-	while (iColor > MAX_MASK_COLORS-1)
-		iColor -= MAX_MASK_COLORS;
-	QColorDialog::setCustomColor(0, m_colorFrames[0]->getColor().rgb());
-	QColorDialog::setCustomColor(1, m_colorFrames[1]->getColor().rgb());
-	QColorDialog::setCustomColor(2, m_colorFrames[2]->getColor().rgb());
-	QColorDialog::setCustomColor(3, m_colorFrames[3]->getColor().rgb());
-	QColor theColor = QColorDialog::getColor(m_colorFrames[iColor]->getColor());
-	if (theColor.isValid())
-		m_colorFrames[iColor]->setColor(theColor);
-	
-	// And here we set the color in the Menu accordingly
-	if (m_pCurrentDVDMenu)
-		m_pCurrentDVDMenu->modifyColor((uint)iColor, theColor);
+  while (iColor > MAX_MASK_COLORS-1)
+    iColor -= MAX_MASK_COLORS;
+  QColorDialog::setCustomColor(0, m_colorFrames[0]->getColor().rgb());
+  QColorDialog::setCustomColor(1, m_colorFrames[1]->getColor().rgb());
+  QColorDialog::setCustomColor(2, m_colorFrames[2]->getColor().rgb());
+  QColorDialog::setCustomColor(3, m_colorFrames[3]->getColor().rgb());
+  QColor theColor = QColorDialog::getColor(m_colorFrames[iColor]->getColor());
+  if ( ! theColor.isValid() )
+    return;
+  m_colorFrames[iColor]->setColor(theColor);
+  
+  // And here we set the color in the Menu accordingly
+  if (m_pCurrentDVDMenu)
+    m_pCurrentDVDMenu->modifyColor((uint)iColor, theColor);
 }
 
 QColor ColorToolBar::getColor(uint iWhichColor)
