@@ -14,6 +14,7 @@
 #include <qlistbox.h>
 #include <qspinbox.h>
 #include <qlineedit.h>
+#include <qlistview.h>
 #include <qdatetime.h>
 #include <qcheckbox.h>
 #include <qfileinfo.h>
@@ -21,6 +22,7 @@
 #include <qcombobox.h>
 #include <qpushbutton.h>
 #include <qmessagebox.h>
+#include <qcolordialog.h>
 
 #ifndef QPLAYER_ONLY
 #include "dvdmenu.h"
@@ -43,6 +45,24 @@
 #define COLOR_TRANSCODE   238,  33,  43
 #define COLOR_NOTRANSCODE 209, 226, 238
 
+ListViewColorItem::ListViewColorItem (QListView *parent, QColor theColor, QString l1, QString l2, QString l3, QString l4, QString l5, QString l6, QString l7, QString l8)
+        : QListViewItem (parent, l1, l2, l3, l4, l5, l6, l7, l8)
+{
+	m_theColor = theColor;
+}
+
+void ListViewColorItem::paintCell ( QPainter *p, const QColorGroup & cg, int column, int width, int align)
+{
+	QColorGroup theColors = cg;
+	if (isSelected())       {
+		theColors.setColor(QColorGroup::Base, theColors.highlight() );
+		theColors.setColor(QColorGroup::Text, theColors.highlightedText() );
+	}
+	else
+		theColors.setColor(QColorGroup::Base, m_theColor);
+	QListViewItem::paintCell(p, theColors, column, width, align);
+}
+
 DialogMovie::DialogMovie(QWidget * parent, const char * name, WFlags f)
 	: uiDialogMovie (parent, name, f)
 {
@@ -52,15 +72,18 @@ DialogMovie::DialogMovie(QWidget * parent, const char * name, WFlags f)
 	m_pMovieObject      = NULL;
 	m_iMovieLength      =    1;// 1ms default, so we never have 0
 	m_pDVDMenu          = NULL;
-	connect (m_pEditWidth,       SIGNAL(lostFocus ()), this, SLOT (slotWidth     ()));
-	connect (m_pEditHeight,      SIGNAL(lostFocus ()), this, SLOT (slotHeight    ()));
-	connect (m_pButtonPlay,      SIGNAL(clicked   ()), this, SLOT (slotPlay      ()));
-	connect (m_pButtonStop,      SIGNAL(clicked   ()), this, SLOT (slotStop      ()));
-	connect (m_pButtonStart,     SIGNAL(clicked   ()), this, SLOT (slotStart     ()));
-	connect (m_pButtonEnd,       SIGNAL(clicked   ()), this, SLOT (slotEnd       ()));
-	connect (m_pButtonTranscode, SIGNAL(clicked   ()), this, SLOT (slotTranscode ()));
-	connect (m_pButtonEncodeNow, SIGNAL(clicked   ()), this, SLOT (slotEncodeNow ()));
-	connect (m_pButtonAnimation, SIGNAL(clicked   ()), this, SLOT (slotAnimation ()));
+	connect (m_pEditWidth,       SIGNAL(lostFocus ()), this, SLOT (slotWidth          ()));
+	connect (m_pEditHeight,      SIGNAL(lostFocus ()), this, SLOT (slotHeight         ()));
+	connect (m_pButtonPlay,      SIGNAL(clicked   ()), this, SLOT (slotPlay           ()));
+	connect (m_pButtonStop,      SIGNAL(clicked   ()), this, SLOT (slotStop           ()));
+	connect (m_pButtonStart,     SIGNAL(clicked   ()), this, SLOT (slotStart          ()));
+	connect (m_pButtonEnd,       SIGNAL(clicked   ()), this, SLOT (slotEnd            ()));
+	connect (m_pButtonTranscode, SIGNAL(clicked   ()), this, SLOT (slotTranscode      ()));
+	connect (m_pButtonEncodeNow, SIGNAL(clicked   ()), this, SLOT (slotEncodeNow      ()));
+	connect (m_pButtonAnimation, SIGNAL(clicked   ()), this, SLOT (slotAnimation      ()));
+	connect (m_pButtonAddCK,     SIGNAL(clicked   ()), this, SLOT (slotAddColorKey    ()));
+	connect (m_pButtonDelCK,     SIGNAL(clicked   ()), this, SLOT (slotDelColorKey    ()));
+	connect (m_pButtonCK,        SIGNAL(clicked   ()), this, SLOT (slotBrowseColorKey ()));
 }
 
 DialogMovie::~DialogMovie()
@@ -71,6 +94,7 @@ DialogMovie::~DialogMovie()
 
 void DialogMovie::initMe(DVDMenu *pMenu)
 {
+	// Called when handling the bvackground of a menu (Image background or MovieBackground.)
 	if (!pMenu)
 		return;
 	if ( (pMenu->getInterface()->qsMovieFileName.isNull()) && (pMenu->getInterface()->qsBackgroundFileName.isNull()) )
@@ -92,9 +116,6 @@ void DialogMovie::initMe(DVDMenu *pMenu)
 	pTab = m_pTabWidget->page (CHAPTERS_TAB);
 	m_pTabWidget->removePage (pTab);
 	delete pTab;
-	pTab = m_pTabWidget->page (PROPERTIES_TAB);
-	m_pTabWidget->removePage (pTab);
-	delete pTab;
 	// Also no transcoding buttons will be needed.
 	delete m_pButtonTranscode;
 	delete m_pButtonEncodeNow;
@@ -104,11 +125,28 @@ void DialogMovie::initMe(DVDMenu *pMenu)
 	m_pEditStarting1 = m_pEditStarting2;
 	m_pEditEnding1   = m_pEditEnding2;
 
-	pTab = m_pTabWidget->currentPage ();
+	pTab = m_pTabWidget->page ( GEOMETRY_TAB );
+
+	// The following lines will display the [Change Size ...] button.
+	QSizePolicy policy (QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+	delete textLabel4;
+	delete m_pListViewCK;
+	delete m_pButtonAddCK;
+	delete m_pButtonDelCK;
+	delete m_pEditCK;
+	delete textLabel3_3;
+	delete textLabel2_2;
+	m_pButtonCK->setText (tr("Change Size ..."));
+	m_pButtonCK->setSizePolicy ( policy );
+	disconnect ( m_pButtonCK, SIGNAL(clicked ()), this, SLOT (slotBrowseColorKey ()) );
+	connect    ( m_pButtonCK, SIGNAL(clicked ()), this, SLOT ( slotSizeDialog ()) );
+	groupBox8->setTitle ("");
+
+	// Here we handle a MovieBackground ...
 	if ( ! pMenu->getInterface()->qsMovieFileName.isEmpty() ) 	{
-		// Here we handle a MovieBackground ...
 		initMediaInterface (pMenu);
 		m_pTabWidget->setTabLabel (pTab, "MovieBackground");
+		m_pTabWidget->setCurrentPage ( 1 );
 	}
 	else	{	// Here we handle a ImageBackground ...
 		if ( ! pMenu->getInterface()->qsBackgroundFileName.isEmpty ())	{
@@ -135,12 +173,60 @@ void DialogMovie::initMe(DVDMenu *pMenu)
 	}
 	// These controls are not used ...
 	delete groupBox2;
-	delete frame13;
-	layout41->remove (groupBox7);
-	layout41->addWidget (groupBox7, 1, 0);
 	resize (400, 300);		
 }
 
+void DialogMovie::initMe(SourceFileEntry *pSourceFileEntry)
+{
+	if (!pSourceFileEntry)
+		return;
+
+	m_sourceFileInfo   = *pSourceFileEntry->listFileInfos[0];
+	QFileInfo fileInfo;
+	QString qsFormat, qsBackgroundName;
+
+	// Okay coming from transcodeAll ...
+	//	QWidget *pTabProp = m_pTabWidget->page (PROPERTIES_TAB);
+	QWidget *pTabChap = m_pTabWidget->page (CHAPTERS_TAB);
+	QWidget *pTabGeom = m_pTabWidget->page (GEOMETRY_TAB);
+	//	m_pTabWidget->removePage (pTabProp);
+	//	delete pTabProp;
+	m_pTabWidget->removePage (pTabChap);
+	delete pTabChap;
+	m_pTabWidget->removePage (pTabGeom);
+	delete pTabGeom;
+	// Also no transcoding buttons will be needed.
+	delete m_pButtonTranscode;
+	delete m_pButtonEncodeNow;
+	delete m_pGroupCurrentFormat;
+	m_pButtonTranscode = NULL;
+	m_pButtonEncodeNow = NULL;
+	m_pEditStarting1   = NULL;
+	m_pEditEnding1     = NULL;
+	m_pComboPreCommand->setCurrentText  ( pSourceFileEntry->qsPre  );
+	m_pComboPostCommand->setCurrentText ( pSourceFileEntry->qsPost );
+
+	setCaption ( "Transcoding all files of the SourceFileEntry" );
+	m_pTextTitle->setText (tr ("SourceFileEntry : %1 Files").arg(pSourceFileEntry->listFileInfos.count()));
+	// And finally we hide the play buttons etc.
+	delete m_pMediaPreview;
+	delete m_pButtonPlay;
+	delete m_pButtonStop;
+	delete m_pButtonStart;
+	delete m_pButtonEnd;
+	delete m_pSliderVolume;
+	delete m_pLabelCurrentPos;
+	delete m_pFrameControl;
+
+	connect (m_pComboVideoOut,        SIGNAL( activated(const QString &)), this, SLOT (slotVideoOutChanged(const QString &)));
+	connect (m_pComboVideoResolution, SIGNAL( activated(const QString &)), this, SLOT (slotVideoResolutionChanged(const QString &)));
+	connect (m_pComboVideoRate,       SIGNAL( activated(const QString &)), this, SLOT (slotVideoRateChanged(const QString &)));
+	connect (m_pComboVideoType,       SIGNAL( activated(const QString &)), this, SLOT (slotVideoTypeChanged(const QString &)));
+	connect (m_pComboVideoAspect,     SIGNAL( activated(const QString &)), this, SLOT (slotVideoAspectChanged(const QString &)));
+	connect (m_pComboVideoBitrate,    SIGNAL( activated(const QString &)), this, SLOT (slotVideoBitrateChanged(const QString &)));
+	resize (300, 250);
+}
+
 void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine, int iThumbnailSize)
 {
 	Utils theUtil;
@@ -208,6 +294,8 @@ void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine
 	pLayout->addWidget( m_pStartStopControl, 0, 0 );
 
 	if (m_sourceFileInfo.pTranscodeInterface)	{
+		if (m_sourceFileInfo.pTranscodeInterface->iEndingAt == 0)
+			m_sourceFileInfo.pTranscodeInterface->iEndingAt = m_iMovieLength;
 		QString qsFormat = QString ("hh:mm:ss.zzz");
 		QTime endingTime, startingTime;
 		startingTime.addMSecs (m_sourceFileInfo.pTranscodeInterface->iStartingAt);
@@ -265,6 +353,8 @@ void DialogMovie::initMe(SourceFileInfo *pInfo, const void *pExistingMediaEngine
 
 void DialogMovie::initMe(MovieObject *pMovieObject)
 {
+	int t;
+	// Called when coming from a MovieObject in the Menu.
 	if (!pMovieObject)
 		return;
 
@@ -303,6 +393,15 @@ void DialogMovie::initMe(MovieObject *pMovieObject)
 	m_rectGeometry = pMovieObject->rect();
 	m_qsFileName   = pMovieObject->fileName();
 
+	QColor theColor;
+	ImageManipulator::colorKeying *pKey;
+	ImageManipulator *pMan = &pMovieObject->manipulator();
+	for (t=0;t<(int)pMan->listColorKeys.count();t++)	{
+		pKey = pMan->listColorKeys[t];
+		theColor.setRgb (pKey->theColor);
+		new ListViewColorItem (m_pListViewCK, theColor, theColor.name(), QString ("%1").arg(pKey->fDeltaColor));
+	}
+	
 	QFileInfo fileInfo(m_qsFileName);
 	// and now on to initializing the dialog. Length : 00:07:23.123 File : Cool Video.mpg
 	m_pTextTitle->setText (tr ("File : %1").arg(fileInfo.fileName()));
@@ -402,10 +501,11 @@ SourceFileInfo *DialogMovie::sourceFileInfo ()
 	return &m_sourceFileInfo;
 }
 
-void DialogMovie::slotNewVolume ( int iNewVolume)
+void DialogMovie::slotNewVolume ( int iNewVolume )
 {
-	// slider min = 0 slider max = 100
-	m_pMediaInterface->setVolume ((float)iNewVolume);
+  // slider min = 0 slider max = 100
+  float fNewVolume = (100 - iNewVolume) / 100.0;
+  m_pMediaInterface->setVolume ( fNewVolume );
 }
 
 void DialogMovie::slotBlink ( )
@@ -428,8 +528,8 @@ bool DialogMovie::transcodeEnabled ()
 void DialogMovie::initTranscodeTab ()
 {
 	// DVD restrictions ...
-	// NTSC : 740x480 704x480 352x480 352x240 * 29.97Hz
-	// PAL  : 740x576 704x576 352x576 352x288 * 25Hz
+	// NTSC : 720x480 704x480 352x480 352x240 * 29.97Hz
+	// PAL  : 720x576 704x576 352x576 352x288 * 25Hz
 	// Mpeg2: up to 9800 kbps
 	// Mpeg1: 352x288 or 352x240 limited to 4:3 up to 1856 kbps
 	// Audio bitrate : 32 .. 1536 kbps
@@ -440,34 +540,75 @@ void DialogMovie::initTranscodeTab ()
 	if (!m_sourceFileInfo.pTranscodeInterface)
 		return;
 
-	m_pComboVideoOut->setCurrentText        (m_sourceFileInfo.pTranscodeInterface->qsVideoFormat);
-	m_pComboVideoType->setCurrentText       (m_sourceFileInfo.pTranscodeInterface->qsVideoType);
-	m_pComboVideoResolution->setCurrentText (m_sourceFileInfo.pTranscodeInterface->qsResolution);
-	m_pComboVideoBitrate->setCurrentText    (longToNorm(m_sourceFileInfo.pTranscodeInterface->iVideoBitrate) + QString ("bps"));
-	m_pComboVideoRate->setCurrentText       (QString ("%1").arg(m_sourceFileInfo.pTranscodeInterface->fFrameRate));
-	m_pComboVideoAspect->setCurrentText     (m_sourceFileInfo.pTranscodeInterface->qsRatio);
+	m_sourceFileInfo.pTranscodeInterface->qsVideoFormat.remove ("Keep ");
+	m_sourceFileInfo.pTranscodeInterface->qsVideoType.remove ("Keep ");
+	m_sourceFileInfo.pTranscodeInterface->qsResolution.remove ("Keep ");
+//	m_pComboVideoBitrate->insertItem    (QString ("Keep %1").arg(longToNorm(m_sourceFileInfo.pTranscodeInterface->iVideoBitrate) + QString ("bps")), 0);
+//	m_pComboVideoRate->insertItem       (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->fFrameRate), 0);
+	m_sourceFileInfo.pTranscodeInterface->qsRatio.remove ("Keep ");
 	
-	m_pComboAudioOut->setCurrentText        (m_sourceFileInfo.pTranscodeInterface->qsAudioFormat);
-	m_pComboAudioType->setCurrentText       (m_sourceFileInfo.pTranscodeInterface->qsAudioType);
-	m_pComboAudioBitrate->setCurrentText    (longToNorm(m_sourceFileInfo.pTranscodeInterface->iAudioBitrate) + QString ("bps"));
-	m_pComboAudioSampleRate->setCurrentText (QString ("%1").arg(m_sourceFileInfo.pTranscodeInterface->iSample));
+//	m_pComboAudioOut->insertItem        ("Keep Original", 0);
+	m_sourceFileInfo.pTranscodeInterface->qsAudioType.remove ("Keep ");
+//	m_pComboAudioBitrate->insertItem    (QString ("Keep %1").arg(longToNorm(m_sourceFileInfo.pTranscodeInterface->iAudioBitrate) + QString ("bps")), 0);
+//	m_pComboAudioSampleRate->insertItem (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->iSample), 0);
+
+	m_pComboVideoOut->insertItem        (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->qsVideoFormat), 0);
+	m_pComboVideoType->insertItem       (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->qsVideoType), 0);
+	m_pComboVideoResolution->insertItem (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->qsResolution), 0);
+	if (m_sourceFileInfo.pTranscodeInterface->iVideoBitrate < 0)
+		m_sourceFileInfo.pTranscodeInterface->iVideoBitrate *= -1;
+	m_pComboVideoBitrate->insertItem    (QString ("Keep %1").arg(longToNorm(m_sourceFileInfo.pTranscodeInterface->iVideoBitrate) + QString ("bps")), 0);
+	if (m_sourceFileInfo.pTranscodeInterface->fFrameRate < 0.0)
+		m_sourceFileInfo.pTranscodeInterface->fFrameRate *= -1.0;
+	m_pComboVideoRate->insertItem       (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->fFrameRate), 0);
+	m_pComboVideoAspect->insertItem     (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->qsRatio), 0);
+	
+	m_pComboAudioOut->insertItem        ("Keep Original", 0);
+	m_pComboAudioType->insertItem       (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->qsAudioType), 0);
+printf ("DialogMovie::initTranscodeTab audioBitrate=<%d>\n", m_sourceFileInfo.pTranscodeInterface->iAudioBitrate);
+	if (m_sourceFileInfo.pTranscodeInterface->iAudioBitrate < 0)
+		m_sourceFileInfo.pTranscodeInterface->iAudioBitrate *= -1;
+	m_pComboAudioBitrate->insertItem    (QString ("Keep %1").arg(longToNorm(m_sourceFileInfo.pTranscodeInterface->iAudioBitrate) + QString ("bps")), 0);
+	if (m_sourceFileInfo.pTranscodeInterface->iSample < 0)
+		m_sourceFileInfo.pTranscodeInterface->iSample *= -1;
+	m_pComboAudioSampleRate->insertItem (QString ("Keep %1").arg(m_sourceFileInfo.pTranscodeInterface->iSample), 0);
+	
+//	m_pComboVideoOut->setCurrentText        (m_sourceFileInfo.pTranscodeInterface->qsVideoFormat);
+//	m_pComboVideoType->setCurrentText       (m_sourceFileInfo.pTranscodeInterface->qsVideoType);
+//	m_pComboVideoResolution->setCurrentText (m_sourceFileInfo.pTranscodeInterface->qsResolution);
+//	m_pComboVideoBitrate->setCurrentText    (longToNorm(m_sourceFileInfo.pTranscodeInterface->iVideoBitrate) + QString ("bps"));
+//	m_pComboVideoRate->setCurrentText       (QString ("%1").arg(m_sourceFileInfo.pTranscodeInterface->fFrameRate));
+//	m_pComboVideoAspect->setCurrentText     (m_sourceFileInfo.pTranscodeInterface->qsRatio);
+	
+//	m_pComboAudioOut->setCurrentText        (m_sourceFileInfo.pTranscodeInterface->qsAudioFormat);
+//	m_pComboAudioType->setCurrentText       (m_sourceFileInfo.pTranscodeInterface->qsAudioType);
+//	m_pComboAudioBitrate->setCurrentText    (longToNorm(m_sourceFileInfo.pTranscodeInterface->iAudioBitrate) + QString ("bps"));
+//	m_pComboAudioSampleRate->setCurrentText (QString ("%1").arg(m_sourceFileInfo.pTranscodeInterface->iSample));
 	// And make the transcode - tab visible again ...
 	slotTranscode ();
 }
 
 void DialogMovie::slotVideoOutChanged (const QString &)
 {
-	// NTSC : 740x480 704x480 352x480 352x240 * 29.97Hz
-	// PAL  : 740x576 704x576 352x576 352x288 * 25Hz
+	// NTSC : 720x480 704x480 352x480 352x240 * 29.97Hz
+	// PAL  : 720x576 704x576 352x576 352x288 * 25Hz
 	m_pComboVideoRate->clear ();
 	m_pComboVideoAspect->clear ();
 	m_pComboVideoResolution->clear ();
-	QString qsCurrentResolution = m_pComboVideoResolution->currentText ();
+//	QString qsCurrentResolution = m_pComboVideoResolution->currentText ();
 	QString qsNewString = m_pComboVideoOut->currentText ().upper();
 
+	MediaInfo *pMediaInfo = NULL;
+	if (m_pMediaInterface)
+		m_pMediaInterface->getMediaInfo ();
+	if (pMediaInfo)	{
+		m_pComboVideoResolution->insertItem (QString ("Keep %1").arg(pMediaInfo->getResolutionString()));
+		m_pComboVideoAspect->insertItem     (QString ("Keep %1").arg(pMediaInfo->getRatio()));
+		m_pComboVideoRate->insertItem       (QString ("Keep %1").arg(pMediaInfo->getFPS()));
+	}
 	if ( (qsNewString == "PAL") || (qsNewString == "CUSTOM") )	{
-		if (m_pComboVideoType->currentText () == "Mpeg 2")	{
-			m_pComboVideoResolution->insertItem ("740x576");
+		if (m_pComboVideoType->currentText () != "Mpeg 1")	{
+			m_pComboVideoResolution->insertItem ("720x576");
 			m_pComboVideoResolution->insertItem ("704x576");
 			m_pComboVideoResolution->insertItem ("352x576");
 		}
@@ -475,18 +616,18 @@ void DialogMovie::slotVideoOutChanged (const QString &)
 		m_pComboVideoRate->insertItem ("25");
 	}
 	if ( (qsNewString == "NTSC") || (qsNewString == "CUSTOM") )	{
-		if (m_pComboVideoType->currentText () == "Mpeg 2")	{
-			m_pComboVideoResolution->insertItem ("740x480");
+		if (m_pComboVideoType->currentText () != "Mpeg 1")	{
+			m_pComboVideoResolution->insertItem ("720x480");
 			m_pComboVideoResolution->insertItem ("704x480");
 			m_pComboVideoResolution->insertItem ("352x480");
 		}
 		m_pComboVideoResolution->insertItem ("352x240");
 		m_pComboVideoRate->insertItem ("29.97");
 	}
-	
+
 	m_pComboVideoAspect->insertItem ("4:3");
 	m_pComboVideoAspect->insertItem ("1:1");
-	if (m_pComboVideoType->currentText () == "Mpeg 2")	{
+	if (m_pComboVideoType->currentText () != "Mpeg 1")	{
 		m_pComboVideoAspect->insertItem ("16:9");
 		m_pComboVideoAspect->insertItem ("2.21:1");
 	}
@@ -525,6 +666,29 @@ void DialogMovie::slotAudioBitrateChanged (const QString &)
 {
 }
 
+void DialogMovie::slotAddColorKey ()
+{
+	float fDelta = m_pEditCK->text().toFloat();
+	//QListViewItem *pItem = 
+	new ListViewColorItem (m_pListViewCK, m_pButtonCK->paletteBackgroundColor(), QString (m_pButtonCK->paletteBackgroundColor().name ()), QString ("%1").arg(fDelta) );
+}
+
+void DialogMovie::slotDelColorKey ()
+{
+	QListViewItem *pItem = m_pListViewCK->selectedItem ();
+	// First we check if anything has been selected.
+	if ( ! pItem )
+		return;
+	delete pItem;
+}
+
+void DialogMovie::slotBrowseColorKey ()
+{
+	QColor theColor = QColorDialog::getColor(m_pButtonCK->paletteBackgroundColor ());
+
+	m_pButtonCK->setPaletteBackgroundColor ( theColor );
+}
+
 void DialogMovie::slotAutoChapters ()
 {
 	uint t, i, iDeltaStep, iStarting, iEnding, iChapter, iPreviousChapter;
@@ -617,6 +781,13 @@ void DialogMovie::slotAnimation ()
 	}
 }
 
+void DialogMovie::slotSizeDialog ()
+{
+  if ( ! m_pDVDMenu )
+    return;
+  m_pDVDMenu->changeSize ();
+}
+
 void DialogMovie::slotAddChapter ()
 {
 	// Here we add a chapter in the right space,
@@ -844,7 +1015,7 @@ long DialogMovie::normToLong ( QString qsInput )
 {
 	QString qsValue, arrayDigit (".0123456789");
 	uint t, i;
-	long iReturn;
+	long iReturn, iMultiplicator = 1;
 	// Here we take a string like 4400kbps and return 4400000.
 	for (t=0;t<qsInput.length();t++)	{
 		for (i=0;i<arrayDigit.length();i++)	{
@@ -855,19 +1026,19 @@ long DialogMovie::normToLong ( QString qsInput )
 			}
 		}
 		if (qsInput[t].upper () == "K")	{
-			qsValue += "000";
+			iMultiplicator = 1000;
 			break;
 		}
 		if (qsInput[t].upper () == "M")	{
-			qsValue += "000000";
+			iMultiplicator = 1000000;
 			break;
 		}
 		if (qsInput[t].upper () == "G")	{
-			qsValue += "000000000";
+			iMultiplicator = 1000000000;
 			break;
 		}
 	}
-	iReturn = qsValue.toLong();
+	iReturn = (long)(qsValue.toFloat() * iMultiplicator);
 	return iReturn;
 }
 
@@ -898,12 +1069,15 @@ void DialogMovie::accept ()
 {
 	uint t;
 	long iBitrate;
+	long iTemp;
+	float fTemp;
+	QString qsTemp;
 	QString qsFormat ("hh:mm:ss.zzz");
 	QTime startingTime, endingTime, duration, zeroTime;
 
-	startingTime = QTime::fromString (m_pEditStarting1->text());
-	endingTime   = QTime::fromString (m_pEditEnding1->text());
 	if ( m_pDVDMenu )	{
+		startingTime = QTime::fromString (m_pEditStarting1->text());
+		endingTime   = QTime::fromString (m_pEditEnding1->text());
 		// Here we hande the start/stop time.
 		if (startingTime.isValid())	{
 			m_pDVDMenu->getInterface()->timeOffset = startingTime;
@@ -915,8 +1089,32 @@ void DialogMovie::accept ()
 		}
 	}
 	else if (m_pMovieObject)	{
+		// Here we handle MovieObjects. Check out if we have set Color Keying.
+		ImageManipulator::colorKeying *pColorKey;
+		ListViewColorItem *pItem;
+		float  fDelta;
+		QColor theColor;
+
+		// First we should remove all entries in the color Key
+		ImageManipulator *pMan= &m_pMovieObject->manipulator();
+		for (t=0;t<pMan->listColorKeys.count();t++)
+			delete pMan->listColorKeys[t];
+		pMan->listColorKeys.clear();
+		// And then we add whats currently in the widget.
+		if ( m_pListViewCK->childCount() )	{
+			pItem = (ListViewColorItem *)m_pListViewCK->firstChild ();
+			while (pItem)	{
+				theColor.setNamedColor (pItem->text (0));	// The Color nam is stored in the first text
+				fDelta = pItem->text(1).toFloat();		// The delta value is stored in the second column.
+				pColorKey = new ImageManipulator::colorKeying ( theColor.rgb(), fDelta );
+				pMan->listColorKeys.append ( pColorKey );
+				pItem = (ListViewColorItem *)pItem->itemBelow ();
+			}
+		}
 	}
-	else	{
+	else if (m_pEditStarting1)	{// used as an indicator if we were coming from the SourceToolbar->SourceFileInfo
+		startingTime = QTime::fromString (m_pEditStarting1->text());
+		endingTime   = QTime::fromString (m_pEditEnding1->text());
 		m_sourceFileInfo.qsPreCommand  = m_pComboPreCommand->currentText ();
 		m_sourceFileInfo.qsPostCommand = m_pComboPostCommand->currentText ();
 		m_sourceFileInfo.iPause        = m_pSpinBoxPause->value ();
@@ -927,15 +1125,41 @@ void DialogMovie::accept ()
 			m_sourceFileInfo.pTranscodeInterface->qsVideoFormat = m_pComboVideoOut->currentText        ();
 			m_sourceFileInfo.pTranscodeInterface->qsVideoType   = m_pComboVideoType->currentText       ();
 			m_sourceFileInfo.pTranscodeInterface->qsResolution  = m_pComboVideoResolution->currentText ();
-			iBitrate = normToLong(m_pComboVideoBitrate->currentText ());
+			qsTemp = m_pComboVideoBitrate->currentText ();
+			if ( qsTemp.contains ("Keep "))	{
+				qsTemp.remove ("Keep ");
+				iBitrate = -normToLong(qsTemp);
+			}
+			else
+				iBitrate =  normToLong(qsTemp);
 			m_sourceFileInfo.pTranscodeInterface->iVideoBitrate = iBitrate;
-			m_sourceFileInfo.pTranscodeInterface->fFrameRate    = m_pComboVideoRate->currentText       ().toFloat();
+			qsTemp = m_pComboVideoRate->currentText ();
+			if ( qsTemp.contains ("Keep "))	{
+				qsTemp.remove ("Keep ");
+				fTemp = -qsTemp.toFloat ();
+			}
+			else
+				fTemp =  qsTemp.toFloat ();
+			m_sourceFileInfo.pTranscodeInterface->fFrameRate    = fTemp;
 			m_sourceFileInfo.pTranscodeInterface->qsRatio       = m_pComboVideoAspect->currentText     ();
 			m_sourceFileInfo.pTranscodeInterface->qsAudioFormat = m_pComboAudioOut->currentText        ();
 			m_sourceFileInfo.pTranscodeInterface->qsAudioType   = m_pComboAudioType->currentText       ();
-			iBitrate = normToLong (m_pComboAudioBitrate->currentText());
+			qsTemp = m_pComboAudioBitrate->currentText();
+			if ( qsTemp.contains ("Keep "))	{
+				qsTemp.remove ("Keep ");
+				iBitrate = -normToLong(qsTemp);
+			}
+			else
+				iBitrate =  normToLong(qsTemp);
 			m_sourceFileInfo.pTranscodeInterface->iAudioBitrate = iBitrate;
-			m_sourceFileInfo.pTranscodeInterface->iSample       = m_pComboAudioSampleRate->currentText ().toInt();
+			qsTemp = m_pComboAudioSampleRate->currentText ();
+			if ( qsTemp.contains ("Keep "))	{
+				qsTemp.remove ("Keep ");
+				iTemp = -qsTemp.toInt();
+			}
+			else
+				iTemp =  qsTemp.toInt();
+			m_sourceFileInfo.pTranscodeInterface->iSample       = iTemp;
 			m_sourceFileInfo.pTranscodeInterface->iStartingAt   = zeroTime.msecsTo(startingTime);
 			m_sourceFileInfo.pTranscodeInterface->iEndingAt     = zeroTime.msecsTo(endingTime);
 //		m_sourceFileInfo.pTranscodeInterface->bTranscoding  = later to indicate transcoding in progress.
@@ -951,7 +1175,25 @@ void DialogMovie::accept ()
 		for (t=0;t<m_pListBoxChapters->count ();t++)
 			m_sourceFileInfo.listChapters.append(m_pListBoxChapters->text (t));
 	}
+	else {	// Or if we are coming from the transcodeAll context menu
+		if (!m_sourceFileInfo.pTranscodeInterface)
+			m_sourceFileInfo.pTranscodeInterface = new TranscodeInterface;
+		m_sourceFileInfo.pTranscodeInterface->qsVideoFormat = m_pComboVideoOut->currentText        ( );
+		m_sourceFileInfo.pTranscodeInterface->qsVideoType   = m_pComboVideoType->currentText       ( );
+		m_sourceFileInfo.pTranscodeInterface->qsResolution  = m_pComboVideoResolution->currentText ( );
+		iBitrate = normToLong(m_pComboVideoBitrate->currentText ());
+		m_sourceFileInfo.pTranscodeInterface->iVideoBitrate = iBitrate;
+		m_sourceFileInfo.pTranscodeInterface->fFrameRate    = m_pComboVideoRate->currentText       ( ).toFloat();
+		m_sourceFileInfo.pTranscodeInterface->qsRatio       = m_pComboVideoAspect->currentText     ( );
+		m_sourceFileInfo.pTranscodeInterface->qsAudioFormat = m_pComboAudioOut->currentText        ( );
+		m_sourceFileInfo.pTranscodeInterface->qsAudioType   = m_pComboAudioType->currentText       ( );
+		iBitrate = normToLong (m_pComboAudioBitrate->currentText());
+		m_sourceFileInfo.pTranscodeInterface->iAudioBitrate = iBitrate;
+		m_sourceFileInfo.pTranscodeInterface->iSample       = m_pComboAudioSampleRate->currentText ( ).toInt();
+		m_sourceFileInfo.pTranscodeInterface->iStartingAt   = 0;
+		m_sourceFileInfo.pTranscodeInterface->iEndingAt     = 0;
+	}
 
-	QDialog:: accept ();
+	QDialog::accept ();
 }
 
