@@ -10,7 +10,7 @@
 #ifndef DIALOGMOVIE_H
 #define DIALOGMOVIE_H
 
-#include <qrect.h>
+#include <qlistview.h>
 
 #include "sourcefileentry.h"
 #include "uidialogmovie.h"
@@ -20,6 +20,17 @@ class DVDMenu;
 class MediaInterface;
 class StartStopControl;
 
+class ListViewColorItem : public QListViewItem
+{
+public:
+	ListViewColorItem (QListView *, QColor, QString, QString l2=QString::null, QString l3=QString::null, QString l4=QString::null,
+		QString l5=QString::null, QString l6=QString::null, QString l7=QString::null, QString l8=QString::null);
+
+	virtual void paintCell ( QPainter *, const QColorGroup &, int, int, int);
+private:
+	QColor m_theColor;
+};
+
 class DialogMovie : public uiDialogMovie
 {
 	Q_OBJECT
@@ -27,9 +38,10 @@ public:
 	 DialogMovie(QWidget *p=NULL, const char *n=NULL, WFlags f=0);
 	~DialogMovie();
 
-	void initMe(SourceFileInfo *, const void *, int);
-	void initMe(MovieObject    *);
-	void initMe(DVDMenu        *);
+	void initMe(SourceFileInfo  *, const void *, int);
+	void initMe(SourceFileEntry *);
+	void initMe(MovieObject     *);
+	void initMe(DVDMenu         *);
 	void initMediaInterface(DVDMenu *);
 
 	bool transcodeEnabled ();
@@ -54,6 +66,7 @@ protected slots:
 	virtual void slotDelChapters  ();
 	virtual void slotAutoChapters ();
 	virtual void slotAnimation    ();
+	virtual void slotSizeDialog   ();
 	virtual void slotCurrentChanged (QListBoxItem *);
 
 	
@@ -71,6 +84,10 @@ protected slots:
 	virtual void slotAudioBitrateChanged    (const QString &);
 	virtual void slotSetStartStop           ();
 
+	virtual void slotAddColorKey ();
+	virtual void slotDelColorKey ();
+	virtual void slotBrowseColorKey ();
+
 private:
 	long normToLong ( QString qsInput );
 	QString longToNorm  ( long iInput );
