@@ -89,7 +89,7 @@ QFont &DialogTextFont::getFont ()
 
 	QString qsFamily = m_pListFonts->text(m_pListFonts->currentItem());
 	QString qsStyle  = m_pComboFontStyle->text(m_pComboFontStyle->currentItem());
-	int iPointSize   = m_pComboFontSizes->text(m_pComboFontSizes->currentItem()).toInt();
+	int iPointSize   = m_pComboFontSizes->currentText().toInt();
 	m_qfFont =  database.font(qsFamily, qsStyle, iPointSize );
 	m_qfFont.setUnderline (m_pButtonUnderline->isOn());
 	m_qfFont.setStrikeOut (m_pButtonStrikeout->isOn());
@@ -318,6 +318,7 @@ void DialogTextFont::initMe()
 	connect (m_pListFonts, SIGNAL(highlighted (int)), this, SLOT(slotFontFamilyChanged(int)));
 	connect (m_pComboFontStyle, SIGNAL(activated (int)), this, SLOT(slotFontStyleChanged(int)));
 	connect (m_pComboFontSizes, SIGNAL(activated (int)), this, SLOT(slotFontSizeChanged(int)));
+	connect (m_pComboFontSizes, SIGNAL(textChanged ( const QString & )), this, SLOT(slotFontSizeChanged( const QString & )));
 	connect (m_pComboScript, SIGNAL(activated (int)), this, SLOT(slotScriptChanged(int)));
 
 	connect (m_pButtonLeft, SIGNAL(toggled (bool)), this, SLOT(slotLeft(bool)));
@@ -392,6 +393,11 @@ void DialogTextFont::slotFontSizeChanged(int)
 	updateFont(2);
 }
 
+void DialogTextFont::slotFontSizeChanged( const QString & )
+{
+	updateFont(2);
+}
+
 void DialogTextFont::slotScriptChanged(int)
 {
 	updateFont(0);
@@ -489,7 +495,7 @@ void  DialogTextFont::updateFont(uint iSwitch)
 	QFontDatabase database;
 	QString fontName  = m_pListFonts->text(m_pListFonts->currentItem());
 	QString styleName = m_pComboFontStyle->text(m_pComboFontStyle->currentItem());
-	int iFontSize     = m_pComboFontSizes->text(m_pComboFontSizes->currentItem()).toInt();
+	int iFontSize     = m_pComboFontSizes->currentText ().toInt();
 	switch (iSwitch)	{
 	case 0:	{
 		// The fontName has changed, so we need to get the styles avail for this new font.
