@@ -1,10 +1,5 @@
 /****************************************************************************
-** menu.h file.
-**
-** This file handles the user input to generate a DVD menu.
-** Please note that this is work in progress and depends also oin the
-** developement of dvdauthor, which is at the moment in version 0.67.
-** Future versions of dvdauthort might need changes to this file.
+** menu.cpp file.
 **
 *****************************************************************************/
 #include <stdlib.h>	// for system ()
@@ -16,7 +11,6 @@
 #include <qlineedit.h>
 #include <qfileinfo.h>
 #include <qcombobox.h>
-#include <qlistview.h>
 #include <qpainter.h>
 #include <qmenubar.h>
 #include <qpixmap.h>
@@ -28,26 +22,27 @@
 
 #include <qtimer.h>
 
-#include "qimagehelper.h"
-#include "qdvdauthor.h"
+#include "xml_dvd.h"
 #include "dvdmenu.h"
-#include "dialogresize.h"
+#include "dvdinfo.h"
+#include "mediainfo.h"
+#include "qdvdauthor.h"
+#include "textobject.h"
+#include "dialogmovie.h"
 #include "menupreview.h"
 #include "movieobject.h"
 #include "frameobject.h"
-#include "xml_dvd.h"
-#include "dvdinfo.h"
+#include "dialogresize.h"
+#include "qimagehelper.h"
 #include "buttonobject.h"
-#include "textobject.h"
 #include "sourcefileentry.h"
-#include "mediainfo.h"
 #include "dialogundostack.h"
-#include "dialogmovie.h"
-#include "dvdmenuundoobject.h"
 #include "objectcollection.h"
+#include "structuretoolbar.h"
+#include "dvdmenuundoobject.h"
 #include "uidialogrenderpreview.h"
-#include "qplayer/engines/dummywidget.h"
 #include "qrender/startmenurender.h"
+#include "qplayer/engines/dummywidget.h"
 
 //////////////////////////////////////////////////////////////
 //
@@ -67,6 +62,7 @@ CDVDMenuInterface::~CDVDMenuInterface ()
 
 void CDVDMenuInterface::initMe ()
 {
+        uint t;
 	bModified                 = false;
 	bIsSubMenu                = false;
 	bMovieBackgroundHasSound  = false;
@@ -80,6 +76,9 @@ void CDVDMenuInterface::initMe ()
 	iFormat                   = FORMAT_NONE;
 	iWidth                    = 0;
 	iHeight                   = 0;
+	qsRatio                   = QString ("4:3");
+	iTitleset                 = -1;
+	iMenu                     = -1;
 	pgcColors[0]              = QColor (TRANSPARENT_COLOR);
 	pgcColors[1]              = QColor (START_HIGHLIGHTED_COLOR);
 	pgcColors[2]              = QColor (START_SELECTED_COLOR);
@@ -87,6 +86,12 @@ void CDVDMenuInterface::initMe ()
 	timeDuration              = timeDuration.fromString ("00:00:01");
 	qsSelectedMaskFileName    = QString ("");
 	qsHighlightedMaskFileName = QString ("");
+	for (t=0;t< listIntroVobs.count();t++)
+	  delete listIntroVobs[t];
+	listIntroVobs.clear ();
+	for (t=0;t< listExtroVobs.count();t++)
+	  delete listExtroVobs[t];
+	listExtroVobs.clear ();
 }
 
 ///////////////////////////////////////////////
@@ -103,6 +108,13 @@ bool CDVDMenuInterface::readProjectFile (QDomNode &theNode)
 	QString tagName;// = theElement.tagName();
 	QString nodeText;// = theElement.text ();
 
+	QDomAttr a = theElement.attributeNode ( MENU_TITLESET_NR );
+	if ( ! a.value().isEmpty() )
+	  iTitleset = a.value().toInt();
+	a = theElement.attributeNode ( MENU_MENU_NR );
+	if ( ! a.value().isEmpty() )
+	  iMenu = a.value().toInt();
+
 	listSoundEntries.clear();
 	QDomNode xmlMenuVariables = theNode.firstChild();
 	while ( !xmlMenuVariables.isNull () )	{
@@ -129,7 +141,7 @@ bool CDVDMenuInterface::readProjectFile (QDomNode &theNode)
 		else if (tagName == MENU_BACKGROUND)	{
 			int iOffsetX, iOffsetY;
 			iOffsetX = iOffsetY = 0;
-			QDomAttr a = theElement.attributeNode ( MENU_RESIZE_ALGO );
+			a = theElement.attributeNode ( MENU_RESIZE_ALGO );
 			qsResizeAlgo = a.value();
 			if (qsResizeAlgo.isEmpty())
 				qsResizeAlgo = QString ( QT_RESIZE_ALGO );
@@ -154,6 +166,22 @@ bool CDVDMenuInterface::readProjectFile (QDomNode &theNode)
 		}
 		else if (tagName == MENU_NAME)
 			qsMenuName = nodeText;
+		else if (tagName == MENU_PRE)
+			qsPre = nodeText;
+		else if (tagName == MENU_PAUSE)
+			qsPause = nodeText;
+		else if (tagName == MENU_POST)
+			qsPost = nodeText;
+		else if (tagName == MENU_INTRO) {
+		  CXmlDVDAuthor::vob_struct *pVob = new CXmlDVDAuthor::vob_struct;
+		  pVob->readXml ( &theElement );
+		  listIntroVobs.append ( pVob );
+		}
+		else if (tagName == MENU_EXTRO) {
+		  CXmlDVDAuthor::vob_struct *pVob = new CXmlDVDAuthor::vob_struct;
+		  pVob->readXml ( &theElement );
+		  listExtroVobs.append ( pVob );
+		}
 		// So lets get the next sibling ... until we hit hte end of DVDMenu ...
 		xmlMenuVariables = xmlMenuVariables.nextSibling();
 	}
@@ -169,6 +197,14 @@ bool CDVDMenuInterface::writeProjectFile (QDomElement &rootDVDMenu)
 	QDomElement tag;
 	QString qsFormat ("hh:mm:ss.zzz");
 	QDomText t;
+
+	tag = xmlDoc.createElement( MENU_BACKGROUND );
+	rootDVDMenu.appendChild( tag );
+
+	t = xmlDoc.createTextNode(qsBackgroundFileName);
+	tag.setAttribute ( MENU_TITLESET_NR, QString ("%1").arg(iTitleset));
+	tag.setAttribute ( MENU_MENU_NR, QString ("%1").arg(iMenu));
+	
 	if (!qsHighlightedMaskFileName.isEmpty())	{
 		tag = xmlDoc.createElement( MENU_HIGHLIGHTED_MASK );
 		rootDVDMenu.appendChild( tag );
@@ -229,6 +265,36 @@ bool CDVDMenuInterface::writeProjectFile (QDomElement &rootDVDMenu)
 		t = xmlDoc.createTextNode(qsMenuName);
 		tag.appendChild( t );
 	}
+	if (!qsPre.isEmpty())	{
+		tag = xmlDoc.createElement( MENU_PRE );
+		rootDVDMenu.appendChild( tag );
+		t = xmlDoc.createTextNode(qsPre);
+		tag.appendChild( t );
+	}
+	if (!qsPause.isEmpty())	{
+		tag = xmlDoc.createElement( MENU_PAUSE );
+		rootDVDMenu.appendChild( tag );
+		t = xmlDoc.createTextNode(qsPause);
+		tag.appendChild( t );
+	}
+	if (!qsPost.isEmpty())	{
+		tag = xmlDoc.createElement( MENU_POST );
+		rootDVDMenu.appendChild( tag );
+		t = xmlDoc.createTextNode(qsPost);
+		tag.appendChild( t );
+	}
+	if ( listIntroVobs.count() > 0 ) {
+		tag = xmlDoc.createElement( MENU_INTRO );
+		rootDVDMenu.appendChild( tag );
+		for (i=0;i<listIntroVobs.count();i++)
+		  listIntroVobs[i]->writeXml (&xmlDoc, &tag);
+	}
+	if ( listExtroVobs.count() > 0 ) {
+		tag = xmlDoc.createElement( MENU_EXTRO );
+		rootDVDMenu.appendChild( tag );
+		for (i=0;i<listExtroVobs.count();i++)
+		  listExtroVobs[i]->writeXml (&xmlDoc, &tag);
+	}
 	// Here we take care of the mask colors
 	QString qsColors;
 	for (int t=0;t<MAX_MASK_COLORS;t++)
@@ -255,9 +321,12 @@ VMGMenu::VMGMenu ()
 VMGMenu::VMGMenu (QDVDAuthor *pDVDAuthor)
 	: DVDMenu (pDVDAuthor)
 {
-	CreateToolBar	(pDVDAuthor);
-	CreateMenuEntry	(pDVDAuthor);
-	slotUpdateStructure();
+  // Main Menu VMGM is always at thir location ...
+  getInterface     ( )->iTitleset = 0;
+  getInterface     ( )->iMenu     = 0;
+  CreateToolBar	   ( pDVDAuthor );
+  CreateMenuEntry  ( pDVDAuthor );
+  slotUpdateStructure ( );
 }
 
 VMGMenu::~VMGMenu ()
@@ -282,9 +351,9 @@ VMGMenu::~VMGMenu ()
 
 void VMGMenu::CreateToolBar (QDVDAuthor *pDVDAuthor)
 {
-	QIconSet iconToDVD  = QIconSet (QPixmap::fromMimeSource( "to_dvd.png" ));
-	QIconSet iconToVCD  = QIconSet (QPixmap::fromMimeSource( "to_vcd.png" ));
-	QIconSet iconToSVCD = QIconSet (QPixmap::fromMimeSource( "to_svcd.png" ));
+	QIconSet iconToDVD  = QIconSet (QPixmap().fromMimeSource( "to_dvd.png" ));
+	QIconSet iconToVCD  = QIconSet (QPixmap().fromMimeSource( "to_vcd.png" ));
+	QIconSet iconToSVCD = QIconSet (QPixmap().fromMimeSource( "to_svcd.png" ));
 //	iconSet.setIconSize (QIconSet::Large, QSize (70, 70));
 	iconToDVD.setIconSize (QIconSet::Small, QSize (70, 70));
 	iconToVCD.setIconSize (QIconSet::Small, QSize (70, 70));
@@ -416,8 +485,8 @@ DVDMenu::DVDMenu (QDVDAuthor *pDVDAuthor)
 	m_iTotalFramesToRender = 0;
 	m_iCurrentFrameToRender= 0;
 
-	CreateTab 	(pDVDAuthor->m_pTabWidgetMain);
-	slotUpdateStructure ();
+	CreateTab 	    ( pDVDAuthor->m_pTabWidgetMain );
+	slotUpdateStructure ( );
 }
 
 DVDMenu::~DVDMenu ()
@@ -456,20 +525,21 @@ bool DVDMenu::isEmpty ()
 	// Checks if the menu has more then the default values.
 	CDVDMenuInterface *p = getInterface();
 	if (	(p->bModified == false) && 
-		(p->listSoundEntries.count() < 1) && 
-		(p->qsMovieFileName.isEmpty()) &&
-		(p->qsBackgroundFileName.isEmpty()) && 
-		(p->qsSelectedMaskFileName.isEmpty()) && 
+		(p->listSoundEntries.count() < 1)         && 
+		(p->qsMovieFileName.isEmpty())            &&
+		(p->qsBackgroundFileName.isEmpty())       && 
+		(p->qsSelectedMaskFileName.isEmpty())     && 
 		(p->qsHighlightedMaskFileName.isEmpty ()) &&
-		(p->iStretchType == 0) && 
-		(p->posOffset.width() == 0) && 
-		(p->posOffset.height() == 0) && 
-		(p->iFormat == 0) &&
-		(p->iWidth == 0) && 
-		(p->iHeight == 0) && 
-		(p->backgroundImage.isNull()) && 
-		(p->highlightedMask.isNull()) && 
-		(p->selectedMask.isNull()) &&
+		(p->iStretchType          == 0) && 
+		(p->posOffset.width()     == 0) && 
+		(p->posOffset.height()    == 0) && 
+		(p->iFormat               == 0) &&
+		(p->iWidth                == 0) && 
+		(p->iHeight               == 0) && 
+		(p->qsRatio == QString ("4:3")) &&
+		(p->backgroundImage.isNull () ) && 
+		(p->highlightedMask.isNull () ) && 
+		(p->selectedMask.isNull    () ) &&
 		(getMenuPreview()->objectCount() == 0)	)
 		return true;
 	/* Not checked ...
@@ -493,9 +563,12 @@ bool DVDMenu::readProjectFile  (QDomNode &theNode)
 	QDomAttr a = theElement.attributeNode ( MENU_FORMAT );
 	m_DVDMenuInterface.iFormat = a.value().toInt();
 	a = theElement.attributeNode ( MENU_WIDTH );
-	m_DVDMenuInterface.iWidth = a.value().toInt();
+	m_DVDMenuInterface.iWidth  = a.value().toInt();
 	a = theElement.attributeNode ( MENU_HEIGHT );
 	m_DVDMenuInterface.iHeight = a.value().toInt();
+	a = theElement.attributeNode ( MENU_RATIO );
+	if ( ! a.value().isEmpty() )
+	  m_DVDMenuInterface.qsRatio = a.value();
 	
 	QDomNode xmlMenu = theNode.firstChild();
 	while (!xmlMenu.isNull())	{
@@ -549,6 +622,7 @@ bool DVDMenu::writeProjectFile (QDomElement &rootElement)
 	rootDVDMenu.setAttribute ( MENU_FORMAT, QString("%1").arg(m_DVDMenuInterface.iFormat) );
 	rootDVDMenu.setAttribute ( MENU_WIDTH,  QString("%1").arg(m_DVDMenuInterface.iWidth)  );
 	rootDVDMenu.setAttribute ( MENU_HEIGHT, QString("%1").arg(m_DVDMenuInterface.iHeight) );
+	rootDVDMenu.setAttribute ( MENU_RATIO,  m_DVDMenuInterface.qsRatio );
 
 	// We encapsulate the Previe, and the DVDMenu variables from each other so the reading is uniform.
 	rootDVDMenu.appendChild ( dvdMenu );
@@ -632,7 +706,7 @@ void DVDMenu::setTabLabel(QString &qsNewLabel)
 	if (VMGM_LABEL == qsNewLabel)
 		bIsSubMenu = false;
 
-	m_pPixmapMenu->setIsSubMenu (bIsSubMenu);
+	m_pPixmapMenu->setIsSubMenu    (bIsSubMenu);
 	m_DVDMenuInterface.bIsSubMenu = bIsSubMenu;
 }
 
@@ -701,10 +775,10 @@ void DVDMenu::modifyColor(uint iWhichColor, QColor theColor, bool bCalledFromDia
 // Standard initialization Functions.
 void DVDMenu::CreateTab (QTabWidget *pTabWidgetMain)
 {
-	QPixmap backgroundPixmap = QPixmap::fromMimeSource (QString ("checkered.png"));
+	QPixmap backgroundPixmap = QPixmap().fromMimeSource ("checkered.png");
 
 	m_pDVDMenuTab = new QWidget( pTabWidgetMain, "m_pDVDMenuTab" );
-	m_pTabLayout = new QGridLayout( m_pDVDMenuTab, 1, 1, 11, 6, "m_pTabLayout");
+	m_pTabLayout  = new QGridLayout( m_pDVDMenuTab, 1, 1, 11, 6, "m_pTabLayout");
 
 	m_pLayout1 = new QGridLayout( 0, 1, 1, 0, 6, "m_pLayout1");
 	m_pLayout2 = new QHBoxLayout( 0, 0, 6, "m_pLayout2");
@@ -732,11 +806,11 @@ void DVDMenu::CreateTab (QTabWidget *pTabWidgetMain)
 	if ( (iScreenHeight <= 768) || (iScreenWidth <= 1024) )	{
 		bUseScrollView = true;
 		// Here we embed the MenuPreview into a ScrollView object ...
-		m_pScrollView = new QScrollView( m_pDVDMenuTab, "usingScrollView", iFlags);// Dont change the name. Used in ButtonPreview !
-		m_pPixmapMenu = new MenuPreview (m_pScrollView, "m_pPixmapMenu", iFlags);
+		m_pScrollView = new QScrollView ( m_pDVDMenuTab, "usingScrollView", iFlags );// Dont change the name. Used in ButtonPreview !
+		m_pPixmapMenu = new MenuPreview ( m_pScrollView, "m_pPixmapMenu", iFlags   );
 	}
 	else
-		m_pPixmapMenu = new MenuPreview (m_pDVDMenuTab, "m_pPixmapMenu", iFlags);
+		m_pPixmapMenu = new MenuPreview ( m_pDVDMenuTab, "m_pPixmapMenu", iFlags   );
 
 	m_pPixmapMenu->setFrameShape( QLabel::Box );
 	m_pPixmapMenu->setFrameShadow( QLabel::Raised );
@@ -769,14 +843,14 @@ void DVDMenu::CreateTab (QTabWidget *pTabWidgetMain)
 	m_pLayout1->addLayout( m_pLayout2, 1, 0 );
 
 	m_pTabLayout->addLayout( m_pLayout1, 0, 0 );
-	// Insert the tab as the third from the back (xml/preview/subpictures are last).
-	pTabWidgetMain->insertTab( m_pDVDMenuTab, QString(VMGM_LABEL), pTabWidgetMain->count()-3);
+	// Insert the tab as the second from the back (xml/subpictures are last).
+	pTabWidgetMain->insertTab( m_pDVDMenuTab, QString(VMGM_LABEL), pTabWidgetMain->count() - 2);
 
 	m_pButtonAddBackground->setText( tr( "Add Background" ) );
 	m_pButtonAddSound->setText( tr( "Add Sound" ) );
 	m_pButtonShowHighlightedMask->setText( tr( "Show H-Layer" ) );
 	m_pButtonShowSelectedMask->setText( tr( "Show S-Layer" ) );
-	pTabWidgetMain->setCurrentPage (pTabWidgetMain->count()-4);
+	pTabWidgetMain->setCurrentPage (pTabWidgetMain->count()-3);
 
 	connect( m_pButtonAddBackground, SIGNAL( clicked() ),        this, SLOT( slotAddBackground       () ) );
 	connect( m_pButtonAddSound, SIGNAL( clicked() ),             this, SLOT( slotAddSound            () ) );
@@ -793,6 +867,8 @@ void DVDMenu::CreateTab (QTabWidget *pTabWidgetMain)
 	connect( m_pPixmapMenu, SIGNAL(signalCreatedMovieObject(MovieObject *, bool)),this, SLOT(slotCreatedMovieObject(MovieObject *, bool)) );
 }
 
+// Public slots. Here are the main actors from the GUI.
+
 void DVDMenu::slotDroppedSomething(uint iWhatDidIDrop)
 {
 	// This function is initiated by m_pPixmapMenu::signalDroppedSomething, meaning we know
@@ -896,24 +972,29 @@ void DVDMenu::slotMaskColorChanged(QColor theColor, QColor oldColor)
 	modifyColor (iWhichColor, theColor, true);
 }
 
-// Public slots. Here are the main actors from the GUI.
-void DVDMenu::slotAddBackground()
+// This function is called from the MovieDialog, when the [change Size ...] button is pressed.
+void DVDMenu::changeSize ()
+{
+  QString fileName = getInterface()->qsBackgroundFileName;
+
+  if (fileName.isNull()) {
+    fileName = getInterface()->qsMovieFileName;
+    
+    if (fileName.isNull())
+      return;
+    readBackgroundFile ( fileName );
+  }
+
+  addBackground ( fileName, NULL, true );
+}
+
+// This function is called from the [Add Background] - button.
+void DVDMenu::readBackgroundFile( QString &fileName )
 {
 	Utils theUtil;
 	QString qsExtensions;
-	if (!m_pDVDAuthor->checkForNewProject ())
-		return;
-
-	QString qsFilter = m_pDVDAuthor->getImageFilter ();
-	qsFilter += m_pDVDAuthor->getMovieFilter ();
-	QString fileName = QFileDialog::getOpenFileName ( m_pDVDAuthor->currentPath(), QString ("Images/Movies (") + qsFilter + QString (")"));
-	if (fileName.isNull())
-		return;
-
 	QTime zeroTime;
 	QFileInfo backgroundInfo (fileName);
-	QString qsPath = backgroundInfo.dirPath ( TRUE );
-	Global::qsCurrentPath = qsPath;
 	MediaInfo *pMediaInfo = m_pDVDAuthor->getMediaInfo ();
 	qsExtensions = pMediaInfo->getExtensions (true);
 	if (qsExtensions.find ("."+backgroundInfo.extension()) > -1)	{
@@ -923,20 +1004,48 @@ void DVDMenu::slotAddBackground()
 		QImage theImage = pMediaInfo->getScreenshot(0);
 		getInterface ()->timeOffset = zeroTime;
 		getInterface ()->timeDuration = zeroTime.addMSecs (pMediaInfo->getLength());
-		// The we save the screenshot in the temp dir
+		// Then we save the screenshot in the temp dir
 		fileName = theUtil.getTempFile(backgroundInfo.baseName())+QString (".png");
 		theImage.save (fileName, "PNG");
 	}
 	else	// Not a movie file, then we should reset this ...
 		getInterface()->qsMovieFileName = QString();
-	addBackground(fileName);
 }
 
-void DVDMenu::addBackground (QString &fileName, QString *pResizeAlgo)
+// This function is called from the [Add Background] - button.
+void DVDMenu::slotAddBackground()
+{
+  Utils theUtil;
+  QString qsExtensions;
+  if (!m_pDVDAuthor->checkForNewProject ())
+    return;
+  
+  QString qsFilter = m_pDVDAuthor->getImageFilter ();
+  qsFilter += m_pDVDAuthor->getMovieFilter ();
+  QString fileName = QFileDialog::getOpenFileName ( Global::qsCurrentPath, QString ("Images/Movies (") + qsFilter + QString (")"));
+  if (fileName.isNull())
+    return;
+
+  QFileInfo fileInfo  ( fileName );
+  QString qsPath = fileInfo.dirPath ( TRUE );
+  Global::qsCurrentPath = qsPath;
+
+  initBackground ( fileName );
+}
+
+void DVDMenu::initBackground ( QString & fileName )
+{
+  if ( fileName.isEmpty () )
+    return;
+  readBackgroundFile ( fileName );
+  addBackground      ( fileName );
+}
+
+void DVDMenu::addBackground (QString &fileName, QString *pResizeAlgo, bool bForceDialog)
 {
 	QString qsResizeAlgo(QT_RESIZE_ALGO);
 
-	QPixmap theBackground;// = QPixmap (fileName);
+	QPixmap theBackground = QPixmap (fileName);
 	// Now we check if the image has already the right format for PAL / NTSC / SECAM
 	int iHeight = theBackground.height();
 	int iWidth  = theBackground.width();
@@ -944,13 +1053,15 @@ void DVDMenu::addBackground (QString &fileName, QString *pResizeAlgo)
 	// And we might need those ...
 	int iStretchType = m_DVDMenuInterface.iStretchType;
 	QSize posOffset  = m_DVDMenuInterface.posOffset;
+	QString qsRatio  = m_DVDMenuInterface.qsRatio;
 	if ( (pResizeAlgo) && (iFormat == FORMAT_NONE) )	{
 		iWidth        = m_DVDMenuInterface.iWidth;
 		iHeight       = m_DVDMenuInterface.iHeight;
+		iFormat       = getFormat ( iWidth,iHeight );
 		qsResizeAlgo  = *pResizeAlgo;
-//		theBackground = QPixmap (1,1);
+		theBackground = QPixmap (1,1);
 	}
-	else if (iFormat == FORMAT_NONE)	{
+	else if ( (iFormat == FORMAT_NONE) || ( bForceDialog ) ) {
 		int iReturn = QMessageBox::warning (NULL, tr ("Wrong IMAGE size"),
 			tr ("This image is neither PAL, nor NTSC. For a DVD the size has to fit either :\n"
 			"NTSC -> 720x480, 704x480, 352x480, 352x240 (29.97 Hz)\n"
@@ -959,15 +1070,17 @@ void DVDMenu::addBackground (QString &fileName, QString *pResizeAlgo)
 			), QMessageBox::Yes ,  QMessageBox::No);
 			if (iReturn == QMessageBox::Yes)	{
 				// save some memory while doing all the resize work etc.
-//				theBackground = QPixmap (1,1);
+				theBackground = QPixmap (1,1);
 				CResizeDialog resizeDialog;
 				resizeDialog.m_posOffset = posOffset;
 				resizeDialog.m_iStretchType = iStretchType;
 				resizeDialog.setFilename(fileName);
+				resizeDialog.m_pComboAspect->setCurrentText ( qsRatio );
 				if (resizeDialog.exec () == QDialog::Rejected)
 					return;
 				iWidth       = resizeDialog.m_pEditWidth ->text().toInt();
 				iHeight      = resizeDialog.m_pEditHeight->text().toInt();
+				qsRatio      = resizeDialog.m_pComboAspect->currentText();
 				iFormat      = resizeDialog.m_iFormat;
 				iStretchType = resizeDialog.m_iStretchType;
 				posOffset    = resizeDialog.m_posOffset;
@@ -981,6 +1094,8 @@ void DVDMenu::addBackground (QString &fileName, QString *pResizeAlgo)
 				m_pPixmapMenu->setPixmap ( (const QPixmap &) theBackground);
 			}
 	}
+	else
+		m_pPixmapMenu->setPixmap ( (const QPixmap &) theBackground);
 	m_pPixmapMenu->undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::NEW_BACKGROUND, (QPixmap &) *m_pPixmapMenu->paletteBackgroundPixmap(), &m_DVDMenuInterface));
 	
 	// This has to be done AFTER the undo-object has been created.
@@ -990,6 +1105,7 @@ void DVDMenu::addBackground (QString &fileName, QString *pResizeAlgo)
 	m_DVDMenuInterface.iFormat              = iFormat;
 	m_DVDMenuInterface.iWidth               = iWidth;
 	m_DVDMenuInterface.iHeight              = iHeight;
+	m_DVDMenuInterface.qsRatio              = qsRatio;
 	m_DVDMenuInterface.qsResizeAlgo         = qsResizeAlgo;
 	m_DVDMenuInterface.iStretchType         = iStretchType;
 	m_DVDMenuInterface.posOffset            = posOffset;
@@ -1044,7 +1160,7 @@ void DVDMenu::slotAddSound()
 	}
 	QString qsFilter = m_pDVDAuthor->getSoundFilter ();
 
-	QStringList listFileNames = QFileDialog::getOpenFileNames ( tr ("Sound Files (")+qsFilter+QString(")"), m_pDVDAuthor->currentPath());
+	QStringList listFileNames = QFileDialog::getOpenFileNames ( tr ("Sound Files (")+qsFilter+QString(")"), Global::qsCurrentPath);
 	if (listFileNames.count() < 1)
 		return;
 	if (iCounter+listFileNames.count() > 7)	{
@@ -1200,7 +1316,7 @@ void DVDMenu::slotAddHighlightedMask()
 		return;
 
 	QString qsFilter = m_pDVDAuthor->getImageFilter ();
-	QString fileName = QFileDialog::getOpenFileName ( m_pDVDAuthor->currentPath(), tr ("Images (")+qsFilter+QString(")"));
+	QString fileName = QFileDialog::getOpenFileName ( Global::qsCurrentPath, tr ("Images (")+qsFilter+QString(")"));
 	if (fileName.isNull())
 		return;
 
@@ -1218,7 +1334,7 @@ void DVDMenu::slotAddSelectedMask()
 		return;
 
 	QString qsFilter = m_pDVDAuthor->getImageFilter ();
-	QString fileName = QFileDialog::getOpenFileName ( m_pDVDAuthor->currentPath(), tr ("Images (")+qsFilter+QString(")"));
+	QString fileName = QFileDialog::getOpenFileName ( Global::qsCurrentPath, tr ("Images (")+qsFilter+QString(")"));
 	if (fileName.isNull())
 		return;
 
@@ -1232,11 +1348,10 @@ void DVDMenu::slotAddSelectedMask()
 
 void DVDMenu::setMask (QString & fileName, uint iWhichMask)
 {
-//	QImage theImage = QImage (fileName, 0);
 	QImageHelper theMask (fileName, 0);
 	// Sanity check ...
 	uint iColorCount = theMask.countColors (); //theMask);
-//printf ("iColorCount=%d\n", iColorCount);
+
 	if ( iColorCount > MAX_MASK_COLORS )	{
 		int iReturn = QMessageBox::warning (NULL, tr ("Image has too many colors"),
 			tr ("This mask has too many colors. Only 4 colors are allowed for the mask.\n\n"
@@ -1296,25 +1411,37 @@ void DVDMenu::setMask (QString & fileName, uint iWhichMask)
 void DVDMenu::createMask(QString &qsFileName, int iWhichMask, bool bForceDrawing)
 {
 	// Called from QDVDAuthor::createDVD()
-	uint t;
+        uint t, iWidth, iHeight;
 	// This function is called from QDVDAuthor::createMenuXml() and will first create the
 	// 4 colored mask and then store it to a file.
 	QPixmap theMask;
 	QPainter thePainter;
 	ButtonObject *pButton, tempButton;
 
+	iWidth  = 720;
+	iHeight = 480;
+	if ( ! m_DVDMenuInterface.backgroundImage.isNull() ) {
+	  iWidth  = m_DVDMenuInterface.backgroundImage.width ();
+	  iHeight = m_DVDMenuInterface.backgroundImage.height();
+	}
+	
 	switch (iWhichMask)	{
 	case BACKGROUND_IMG:
 		// The background image is generated by using the background and overlaying all MenuObject
-		theMask = QPixmap (m_DVDMenuInterface.backgroundImage);
+  	        if ( m_DVDMenuInterface.backgroundImage.isNull() ) {
+		  theMask = QPixmap ( iWidth, iHeight );
+		  theMask.fill ( m_DVDMenuInterface.pgcColors[0] );
+		}
+		else
+		  theMask = QPixmap (m_DVDMenuInterface.backgroundImage);
 	break;
 	case HIGHLIGHTED_MASK:
-		theMask = QPixmap (m_DVDMenuInterface.backgroundImage.width(), m_DVDMenuInterface.backgroundImage.height());
-		theMask.fill (m_DVDMenuInterface.pgcColors[0]);
+	        theMask = QPixmap  ( iWidth, iHeight );
+		theMask.fill ( m_DVDMenuInterface.pgcColors[0] );
 	break;
 	case SELECTED_MASK:
-		theMask = QPixmap (m_DVDMenuInterface.backgroundImage.width(), m_DVDMenuInterface.backgroundImage.height());
-		theMask.fill (m_DVDMenuInterface.pgcColors[0]);
+		theMask = QPixmap ( iWidth, iHeight );
+		theMask.fill ( m_DVDMenuInterface.pgcColors[0] );
 	break;
 	}
 	// Here we draw the appropriate mask.
@@ -1341,40 +1468,26 @@ void DVDMenu::createMask(QString &qsFileName, int iWhichMask, bool bForceDrawing
 
 	// Okay all's in, so we should be good to write to the temp drive ...
 	thePainter.end();
-	QImageHelper theImage((const QImageHelper &)theMask.convertToImage());
 	// The following two lines are a propsed patch to a GCC 4 problem with the line above.(07/07/2005)
-//	QImage img = theMask.convertToImage();
-//	QImageHelper theImage(*((const QImageHelper *)&img));
+	QImage img = theMask.convertToImage();
+	QImageHelper theImage(*((const QImageHelper *)&img));
 	
 	QRgb colors[4];
-	colors[0] = m_DVDMenuInterface.pgcColors[0].rgb();
-	colors[1] = m_DVDMenuInterface.pgcColors[1].rgb();
-	colors[2] = m_DVDMenuInterface.pgcColors[2].rgb();
-	colors[3] = m_DVDMenuInterface.pgcColors[3].rgb();
+	colors[0] = m_DVDMenuInterface.pgcColors[0].rgb() & 0x00FFFFFF;
+	colors[1] = m_DVDMenuInterface.pgcColors[1].rgb() & 0x00FFFFFF;
+	colors[2] = m_DVDMenuInterface.pgcColors[2].rgb() & 0x00FFFFFF;
+	colors[3] = m_DVDMenuInterface.pgcColors[3].rgb() & 0x00FFFFFF;
+	
+	// The following lines take care of the case where a layer has LESS then 4 colors.
+	// This caused a failure of spumux "Cannot pick button masks"
+       	theImage.setPixel (0,                  0,                   colors[0]);
+	theImage.setPixel (theImage.width()-1, 0,                   colors[1]);
+	theImage.setPixel (theImage.width()-1, theImage.height()-1, colors[2]);
+	theImage.setPixel (0,                  theImage.height()-1, colors[3]);
 
-	(QImage &)theImage = theImage.convertDepthWithPalette (8, (QRgb *)&colors, MAX_MASK_COLORS, Qt::ThresholdDither);
-	// Note: After this conversion we might have up to 8 colors in the palette, thus I should correct this.
-	// Note2: Trolltech wants this to be corrected in Qt version 4.0
-	QRgb theNearestColor;
-	QRgb *pTheColors = theImage.colorTable ();
-	int iNumColors   = theImage.numColors  ();
-	if (iNumColors > MAX_MASK_COLORS)	{
-		Utils theUtils;
-		// First we look for the nearest color of the upper 4+ colors
-		for (t=4;(int)t<iNumColors;t++)	{
-			theNearestColor = theUtils.nearestColor (colors, 4, pTheColors[t]);
-			theImage.setColor (t, theNearestColor & 0x00ffffff);
-		}
-		// This final step will reduce the palette to 4 color only !
-//		(QImage &)theImage = theImage.convertDepthWithPalette (8, (QRgb *)&colors, MAX_MASK_COLORS, Qt::ThresholdDither);
-	}
-/*
-printf ("Searching : <%d> <%X>\n", iNumColors, pTheColors);
-for (t=0;t<iNumColors;t++)
-	printf (" <%d> = <%X>\n", t, pTheColors[t]);
-printf ("\n");
-*/
-//	theImage.dither (MAX_MASK_COLORS, m_DVDMenuInterface.pgcColors);
+	//theImage.dither (MAX_MASK_COLORS, m_DVDMenuInterface.pgcColors);
+	Utils theUtils;
+	theUtils.reduceColors ( (QImage &) theImage, 4, (QRgb *)&colors );
 	theImage.save (qsFileName, "PNG", 100);
 }
 
@@ -1500,7 +1613,7 @@ void DVDMenu::slotRenderFrame ()
 	if (m_pDialogRenderPreview)
 		m_pDialogRenderPreview->setProgressData (&thePixmap, m_iCurrentFrameToRender, m_iTotalFramesToRender);
 
-//	printf ("Rendering Frame <%d> of <%d> File <%s>\n", m_iCurrentFrameToRender, m_iTotalFramesToRender, (const char *)qsFileName);
+	//	printf ("Rendering Frame <%d> of <%d> File <%s>\n", m_iCurrentFrameToRender, m_iTotalFramesToRender, (const char *)qsFileName);
 	thePixmap.save (qsFileName, "PNG", 100); //"PNG");
 	if (m_iCurrentFrameToRender <= m_iTotalFramesToRender-1)
 		QTimer::singleShot (0, this, SLOT(slotRenderFrame()));
@@ -1649,30 +1762,33 @@ QValueList<SourceFileEntry *> &DVDMenu::getSourceFileEntries()
 				}
 			}
 			//If SourceEntry not found then insert it.
-			if (!bFound)
+			if ( ! bFound && pEntry )
 				listReturn.append(pEntry);
 		}
 	}
 	return listReturn;
 }
-/*
-QValueList<SourceFileEntry *> &DVDMenu::getSourceFileEntries()
+
+QValueList<SourceFileInfo *> &DVDMenu::getSourceFileInfos()
 {
-	// This function will return all SourceFileEntries actually used in this Menu.
-	static QValueList<SourceFileEntry *> listReturn;
-	listReturn.clear();
-	ButtonObject tempButton;
-	ButtonObject *pButton;
-	uint t;
-	for (t=0;t<m_pPixmapMenu->objectCount();t++)	{
-		if (m_pPixmapMenu->menuObject(t)->objectType() == tempButton.objectType())	{
-			pButton = (ButtonObject *)m_pPixmapMenu->menuObject(t);
-			listReturn.append(pButton->sourceFileEntry());
-		}
-	}
-	return listReturn;
+  // This function will return all SourceFileEntries actually used in this Menu.
+  static QValueList<SourceFileInfo *> listReturn;
+  listReturn.clear();
+  SourceFileInfo *pInfo = NULL;
+  ButtonObject tempButton;
+  ButtonObject *pButton;
+  uint t;
+  for (t=0;t<m_pPixmapMenu->objectCount();t++)	{
+    if (m_pPixmapMenu->menuObject(t)->objectType() == tempButton.objectType())	{
+      pButton = (ButtonObject *)m_pPixmapMenu->menuObject(t);
+      pInfo = pButton->sourceFileInfo();
+      if ( pInfo )
+	listReturn.append( pInfo );
+    }
+  }
+  return listReturn;
 }
-*/
+
 void DVDMenu::displayMask (uint iWhichMask)
 {
 	QPixmap *pMask;
@@ -1729,8 +1845,8 @@ printf ("DisplayMask <%d>\n", iWhichMask);
 	// And finally set the pixmap back again ...
 	m_pPixmapMenu->setPixmap(oldPixmap);
 }
-
 */
+
 void DVDMenu::slotStructureClicked(QListViewItem *pItem)
 {
 	if (!pItem)
@@ -1751,21 +1867,6 @@ void DVDMenu::slotStructureClicked(QListViewItem *pItem)
 	}
 }
 
-/*
-void DVDMenu::slotCreateMenu()
-{
-	// This function is invoked when the user wants to create the menu structure.
-	// THus this function does the following
-	// create /tmp/spumux.xml
-	// create /tmp/dvdauthor.xml
-	// invoke spumux -> output to dialog
-	// invoke dvdauthor, but use dummy vob files rather then the original (hiuge) ones.
-	createMenuXml ();		// /tmp/spumux.xml
-	createDvdauthorXml ();	// /tmp/dvdauthor.xml
-	// And then we create the script to generate all those funcky files ...
-	createDVD ();
-}
-*/
 int DVDMenu::getFormat (int iWidth, int iHeight)
 {
 	int iFormat = FORMAT_NONE;
@@ -1830,10 +1931,28 @@ void DVDMenu::updateDVDMenu ()
 	if (m_DVDMenuInterface.qsBackgroundFileName.isEmpty())
 		return;
 	// If we have, then lets check if the file exists.
-	QFileInfo fileInfo (m_DVDMenuInterface.qsBackgroundFileName);
-	if (!fileInfo.exists())	{
+	QString qsFileName = m_DVDMenuInterface.qsBackgroundFileName;
+	QFileInfo fileInfo (qsFileName);
+	if (!fileInfo.exists())	{	// So most likely the Background was generated from a movie background
+		if ( ! m_DVDMenuInterface.qsMovieFileName.isEmpty())	{
+			qsFileName = m_DVDMenuInterface.qsMovieFileName;
+			fileInfo.setFile (qsFileName);
+			if (fileInfo.exists())	{
+				// So now we're talking. The movie file exists
+				// All we have to do is to re-generate the backgfround file.
+				Utils theUtil;
+				MediaInfo *pMediaInfo = m_pDVDAuthor->getMediaInfo ();
+				pMediaInfo->setFileName(qsFileName);
+				QImage theImage = pMediaInfo->getScreenshot(0);
+				// Then we save the screenshot in the temp dir
+				m_DVDMenuInterface.qsBackgroundFileName = theUtil.getTempFile(fileInfo.baseName())+QString (".png");
+				theImage.save (m_DVDMenuInterface.qsBackgroundFileName, "PNG");
+				updateDVDMenu (m_DVDMenuInterface.qsBackgroundFileName);
+				return;
+			}
+		}
 		QMessageBox::warning (NULL, tr ("File not found !"),
-			tr ("Warning, could not find file %1.").arg(m_DVDMenuInterface.qsBackgroundFileName), QMessageBox::Ok ,  QMessageBox::Cancel);
+			tr ("Warning, could not find file %1.").arg(qsFileName), QMessageBox::Ok, QMessageBox::NoButton);
 		return;
 	}
 	updateDVDMenu (m_DVDMenuInterface.qsBackgroundFileName);
@@ -2013,7 +2132,7 @@ QListViewItem *DVDMenu::createStructure (QListViewItem *pMainItem)
 	QListViewItem *pMaskItem;
 	QListViewItem *pButtonItem;
 
-	pMainMenuItem = new QListViewItem(pMainItem, m_DVDMenuInterface.qsMenuName);
+	pMainMenuItem = new StructureItem(getMenuPreview(), pMainItem, m_DVDMenuInterface.qsMenuName);
 	pMainMenuItem->setExpandable (TRUE);
 	pMainMenuItem->setOpen (TRUE);
 
@@ -2073,15 +2192,15 @@ QListViewItem *DVDMenu::createStructure (QListViewItem *pMainItem)
 //printf ("<%d>\n", m_DVDMenuInterface.listSoundFiles.count());
 	for (t=m_DVDMenuInterface.listSoundEntries.count();t>0;t--)	{
 		qsFileName = QFileInfo (m_DVDMenuInterface.listSoundEntries[t-1]).fileName ();
-		new QListViewItem(pMainMenuItem, tr ("Sound file(s) %1").arg(t-1), qsFileName);
+		new StructureItem(getMenuPreview(), pMainMenuItem, tr ("Sound file(s) %1").arg(t-1), qsFileName);
 	}
 	if (!m_DVDMenuInterface.qsMovieFileName.isNull())	{
 		qsFileName = QFileInfo (m_DVDMenuInterface.qsMovieFileName).fileName ();
-		new QListViewItem(pMainMenuItem, tr ("Background"), qsFileName);
+		new StructureItem(getMenuPreview(), pMainMenuItem, tr ("Background"), qsFileName);
 	}
 	else if (!m_DVDMenuInterface.qsBackgroundFileName.isEmpty())	{
 		qsFileName = QFileInfo (m_DVDMenuInterface.qsBackgroundFileName).fileName ();
-		new QListViewItem(pMainMenuItem, tr ("Background"), qsFileName);
+		new StructureItem(getMenuPreview(), pMainMenuItem, tr ("Background"), qsFileName);
 	}
 
 	return pMainMenuItem;
