@@ -90,10 +90,10 @@ void Execute::createDialog(bool bKeep)
 	m_pDialog->show();
 	m_pDialog->editCommandText->clear ();
 	m_pDialog->setCloseDelay(m_iSeconds);
-	connect ( m_pDialog, SIGNAL(destroyed()), this, SLOT(slotDialogClosed()));
+	connect ( m_pDialog, SIGNAL(destroyed()), this, SLOT(slotDialogClosed  ()) );
 	connect( this, SIGNAL(readyReadStderr()), this, SLOT(slotReadFromStderr()) );
 	connect( this, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
-	connect( this, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
+	connect( this, SIGNAL(processExited  ()), this, SLOT(slotProcessExited ()) );
 }
 
 int Execute::system( QStringList &commandList, QStringList *pListEnv)
@@ -171,7 +171,7 @@ int Execute::startCommand ()
 	QFile file(Global::qsTempPath + QString("/execute.sh"));
 	if ( file.open( IO_WriteOnly ) ) {
 		QTextStream stream( &file );
-		stream << BASH_STRING << m_commandList[m_iCurrentCommand];
+		stream << Global::qsBashString << m_commandList[m_iCurrentCommand];
 		file.close();
 	}
 	// And here we grant read/write/execute permission.
@@ -520,7 +520,7 @@ int Execute::system( QString &commandString, QStringList *pListEnv)
 	QFile file("/tmp/execute.sh");
 	if ( file.open( IO_WriteOnly ) ) {
 		QTextStream stream( &file );
-		stream << "#!/bin/bash\n\n" << "$*\n" << "echo $* > /tmp/out.txt";
+stream << "#!/bin/bash\n\n" << "$*\n" << "echo $* > /tmp/" << getlogin() << "_out.txt";
 		file.close();
 	}
 	chmod ("/tmp/execute.sh", S_IEXEC | S_IRUSR | S_IWRITE);
