@@ -1,19 +1,18 @@
 /****************************************************************************
-** ImagePreview class
+** FrameObject class
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
+** This class is the encapsulation of the FrameObject.
+**
+** A FrameObject is a visible frame on a DVD menu.  
 **
 ****************************************************************************/
 #include <qpainter.h>
 #include <qwmatrix.h>
 #include <qpixmap.h>
 #include <qpopupmenu.h>
-#include <qlistview.h>
 #include <qlineedit.h>
 #include <qmessagebox.h>
 
@@ -23,6 +22,7 @@
 #include "frameobject.h"
 #include "dialogframe.h"
 #include "dialogmatrix.h"
+#include "structuretoolbar.h"
 
 FrameObject::FrameObject (QWidget *pParent)
 	: MenuObject (pParent)
@@ -109,7 +109,7 @@ void FrameObject::drawContents (QPainter *painter)
 	theMatrix.rotate (modifiers()->fRotate);
 	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
 	
-	// Here we draw the rect that encompasses thebutton (think of rotated)
+	// Here we draw the rect that encompasses the button (think of rotated)
 	QRect r (theMatrix.mapRect(theRect));
 	if (m_bDrawRect)
 		painter->drawRect(r);
@@ -117,9 +117,6 @@ void FrameObject::drawContents (QPainter *painter)
 	r = QRect (theRect.x()-(int)(width()/2.0), theRect.y()-(int)(width()/2.0), theRect.width()+width(), theRect.height()+width());
 	m_boundingRect = theMatrix.mapRect(r);
 
-// Here we add the frameWidth to the boundingRect
-//	m_boundingRect = QRect (r.x()-(int)(width()/2.0), r.y()-(int)(width()/2.0), r.width()+width(), r.height()+width());
-
 	painter->setWorldMatrix(theMatrix);
 
 	painter->drawRect(theRect);
@@ -160,35 +157,7 @@ bool FrameObject::mousePressEvent (QMouseEvent *pEvent)
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
 		QPoint globalPos = pEvent->globalPos();
-
-		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
-		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
-		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
-		pStackMenu->popup(globalPos, 1);
-
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = new QPopupMenu(m_pParent);
-		m_pContextMenu->insertItem ( tr ("Edit ...")  , this, SLOT(slotEdit()));
-		m_pContextMenu->insertItem ( tr ("Matrix ..."), this, SLOT(slotMatrix()));
-		m_pContextMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( tr ("Add Text")   , this, SLOT(slotAddText()));
-		m_pContextMenu->insertItem ( tr ("Add Image")  , this, SLOT(slotAddImage()));
-		m_pContextMenu->insertItem ( tr ("Add Movie")  , this, SLOT(slotAddMovie()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
-		m_pContextMenu->exec(pEvent->globalPos(), 4);
-
-		delete pStackMenu;
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = NULL;
-		// Here we mark that the user called a menu item thus we don't want the
-		// base classes to continue with the mouse event
-//		if (iReturn != -1)
-			return true;
+		return createContextMenu ( globalPos );
 	}
 	else
 		m_bDrawRect = true;
@@ -290,10 +259,43 @@ bool FrameObject::writeProjectFile (QDomElement &theElement)
 	return MenuObject::writeProjectFile( frameNode );
 }
 
+bool FrameObject::createContextMenu (QPoint globalPos)
+{
+        QPoint globalPos2 = globalPos;
+	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	pStackMenu->popup(globalPos, 1);
+
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = new QPopupMenu(m_pParent);
+	m_pContextMenu->insertItem ( tr ("Edit ...")  , this, SLOT(slotEdit()));
+	m_pContextMenu->insertItem ( tr ("Matrix ..."), this, SLOT(slotMatrix()));
+	m_pContextMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Add Text")   , this, SLOT(slotAddText()));
+	m_pContextMenu->insertItem ( tr ("Add Image")  , this, SLOT(slotAddImage()));
+	m_pContextMenu->insertItem ( tr ("Add Movie")  , this, SLOT(slotAddMovie()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
+	m_pContextMenu->exec(globalPos2, 4);
+
+	delete pStackMenu;
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = NULL;
+	// Here we mark that the user called a menu item thus we don't want the
+	// base classes to continue with the mouse event
+//	if (iReturn != -1)
+		return true;
+}
+
 void FrameObject::createStructure (QListViewItem *pParentItem)
 {
-	QListViewItem *pFrameItem;
-	QListViewItem *pModifierItem;
+	StructureItem *pFrameItem;
+	StructureItem *pModifierItem;
 
 	QString qsName (tr("Frame (%2, %3, %4)").
 			arg(m_colorFrame.red  ()).
@@ -307,32 +309,32 @@ void FrameObject::createStructure (QListViewItem *pParentItem)
 			arg(m_colorFrame.green()).
 			arg(m_colorFrame.blue ());
 
-	pFrameItem = new QListViewItem(pParentItem, qsName, qsInfo);
+	pFrameItem = new StructureItem(this, pParentItem, qsName, qsInfo);
 	pFrameItem->setExpandable (TRUE);
 
 	// And finally we create the modifiers info ...
 	if ( !((m_modifiers.fRotate == 0.0) && (m_modifiers.fShearX == 0.0) && (m_modifiers.fShearY == 0.0) &&
 		   (m_modifiers.fZoom   == 1.0) && (m_modifiers.fScaleX == 1.0) && (m_modifiers.fScaleY == 1.0)) )	{
-		pModifierItem = new QListViewItem(pFrameItem, tr ("Modifiers"), NULL);
+	  pModifierItem = new StructureItem(this, pFrameItem, tr ("Modifiers"), NULL);
 		pFrameItem->setExpandable (TRUE);
 
-		new QListViewItem(pModifierItem, tr ("Shear (x, y)"),
+		new StructureItem(this, pModifierItem, tr ("Shear (x, y)"),
 			QString ("%1, %2").arg(m_modifiers.fShearX).arg(m_modifiers.fShearY));
-		new QListViewItem(pModifierItem, tr ("Zoom"),
+		new StructureItem(this, pModifierItem, tr ("Zoom"),
 			QString ("%1").arg(m_modifiers.fZoom));
-		new QListViewItem(pModifierItem, tr ("Rotate"),
+		new StructureItem(this, pModifierItem, tr ("Rotate"),
 			tr ("%1 deg").arg(m_modifiers.fRotate));
 	}
 
-	new QListViewItem(pFrameItem, tr ("Frame Color"),
+	new StructureItem(this, pFrameItem, tr ("Frame Color"),
 		tr ("color(%1, %2, %3)").
 			arg(m_colorFrame.red()).
 			arg(m_colorFrame.green()).
 			arg(m_colorFrame.blue()));
 
-	new QListViewItem(pFrameItem, tr ("Frame Width"), QString ("%1").arg (width()));
+	new StructureItem(this, pFrameItem, tr ("Frame Width"), QString ("%1").arg (width()));
 
-	new QListViewItem(pFrameItem, tr ("Geometry"),
+	new StructureItem(this, pFrameItem, tr ("Geometry"),
 		QString ("%1, %2, %3, %4").
 		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
 
