@@ -2,6 +2,7 @@
 #define GLOBAL_H
 
 #include <qstring.h>
+// Include the logging facilities ...
 #include "log.h"
 
 #define DEBUG_INFO 1
@@ -9,6 +10,7 @@
 // Here we define all external tools neccesary
 // Format = executable, Display Name, Explanation of function
 #define EXTERNAL_TOOLS \
+		{"bash",          "Linux",          "Mandatory !\n\nYou need bash in order to execute the generated scripts."}, \
 		{"dvdauthor",     "DVDAuthor",      "Mandatory !\n\nThis is the main application needed to create a Movie DVD.\nhttp://dvdauthor.sf.net"}, \
 		{"spumux",        "Spumux",         "Mandatory !\n\nThis program is part of the dvdauthor package.\nhttp://dvdauthor.sf.net"}, \
 		{"mplex",         "MPlex",          "Mandatory !\n\nThis program is part of the dvdauthor package.\nhttp://dvdauthor.sf.net"}, \
@@ -46,15 +48,12 @@
 // Here we define the dpeth of the undo buffer ... maybe later we can adjust this value in the setup dialog ...
 #define MAX_UNDO_DEPTH 250
 
-// This variable tells us where the bash shell is located. Needed for the generated scripts
-#define BASH_STRING "#!/bin/bash\n\n" 
-
 // Here are the defines for the different video modes
 #define FORMAT_NONE		0
-#define FORMAT_NTSC1	1
-#define FORMAT_NTSC2	2
-#define FORMAT_NTSC3	3
-#define FORMAT_NTSC4	4
+#define FORMAT_NTSC1		1
+#define FORMAT_NTSC2		2
+#define FORMAT_NTSC3		3
+#define FORMAT_NTSC4		4
 #define FORMAT_PAL1		5
 #define FORMAT_PAL2		6
 #define FORMAT_PAL3		7
@@ -98,18 +97,13 @@
 #define PI 3.14
 #endif
 
-// Here we define the macro to handle logging.
-#define dLOG( x ) Global::pLogObject->line (__FILE__, __FUNCTION__, __LINE__, Log::logDebug); Global::pLogObject->log x;
-#define iLOG( x ) Global::pLogObject->line (__FILE__, __FUNCTION__, __LINE__, Log::logInfomation); Global::pLogObject->log x;
-#define wLOG( x ) Global::pLogObject->line (__FILE__, __FUNCTION__, __LINE__, Log::logWarning); Global::pLogObject->log x;
-#define fLOG( x ) Global::pLogObject->line (__FILE__, __FUNCTION__, __LINE__, Log::logFatal); Global::pLogObject->log x;
-
 class Global
 {
 public:
 	 Global ();
 	~Global ();
 	static Log    *pLogObject;
+	static QString qsBashString;
 	static QString qsProjectFileName;
 	static QString qsProjectName;
 	static QString qsTempPath;
