@@ -1,12 +1,12 @@
 /****************************************************************************
-** ImagePreview class
+** ImageObject class
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
+** This class is the encapsulation of the ImageObject.
+**
+** AN ImageObject is a visible object in a DVD Menu.
 **
 ****************************************************************************/
 #include <qmessagebox.h>
@@ -25,9 +25,11 @@
 #include "menuobject.h"
 #include "frameobject.h"
 #include "imageobject.h"
+#include "dialogmovie.h"
 #include "dialogmatrix.h"
 #include "dialoggeometry.h"
 #include "dialoganimation.h"
+#include "structuretoolbar.h"
 
 ImageObject::ImageObject (QWidget *pParent)
 	: MenuObject (pParent)
@@ -143,7 +145,7 @@ void ImageObject::drawContents (QPainter *painter)
 		return;
 
 	if (!m_bDrawRect)	{
-		int x, y;
+		int t, x, y;
 		QRgb thePixel;
 		int iSourceHeight = pixmap().height();
 		int iSourceWidth  = pixmap().width ();
@@ -152,11 +154,11 @@ void ImageObject::drawContents (QPainter *painter)
 		int iTargetStartX = painter->viewport().x() + m_boundingRect.x();
 		int iTargetStartY = painter->viewport().y() + m_boundingRect.y();
 		// Use the fast method whenever possible
-		if ((	(manipulator().fRotate ==   0.0) || (manipulator().fRotate ==  90.0) ||
-			(manipulator().fRotate == 180.0) || (manipulator().fRotate == 270.0) ) &&
-			( (manipulator().fShearX == 0.0) && (manipulator().fShearY ==   0.0) && 
-			  (manipulator().fTransparency == 0.0) )
-		   )
+		if (	(manipulator().fRotate       == 0.0) && 
+			(manipulator().fShearX       == 0.0) && 
+			(manipulator().fShearY       == 0.0) &&
+			(manipulator().fTransparency == 0.0) && 
+			(manipulator().listColorKeys.count() < 1) )
 			bitBlt (painter->device(), iTargetStartX, iTargetStartY, &pixmap(), iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
 		// Okay if we can not use bitBlt we have to go through the exact calculations ...
 		else	{
@@ -183,20 +185,46 @@ void ImageObject::drawContents (QPainter *painter)
 			// in the painter and thus we can substract them here.
 			iTargetStartX -= painter->viewport().x();
 			iTargetStartY -= painter->viewport().y();
+			
+			// Next we create the min/max Color keys, to check if we ought to filter the pixel out or not
+			QValueList<QColor *>listColorKeyMin;
+			QValueList<QColor *>listColorKeyMax;
+			QColor *pColorMin, *pColorMax;
+			if (manipulator().listColorKeys.count() > 0)	{
+				int iDelta, iRed, iGreen, iBlue;
+				for (t=0;t<(int)manipulator().listColorKeys.count();t++)	{
+					iDelta = (int)(manipulator().listColorKeys[t]->fDeltaColor * 255.0);
+					theColor = QColor (manipulator().listColorKeys[t]->theColor);
+					iRed = theColor.red() - iDelta; iGreen = theColor.green() - iDelta; iBlue = theColor.blue() - iDelta;
+					iRed = (iRed < 0) ? 0 : iRed; iGreen = (iGreen < 0) ? 0 : iGreen; iBlue = (iBlue < 0) ? 0 : iBlue;
+					pColorMin = new QColor (iRed, iGreen, iBlue);
+					iRed = theColor.red() + iDelta; iGreen = theColor.green() + iDelta; iBlue = theColor.blue() + iDelta;
+					iRed = (iRed > 255) ? 255 : iRed; iGreen = (iGreen > 255) ? 255 : iGreen; iBlue = (iBlue > 255) ? 255 : iBlue;
+					pColorMax = new QColor (iRed, iGreen, iBlue);
+
+					listColorKeyMin.append (pColorMin);
+					listColorKeyMax.append (pColorMax);
+				}
+			}
 			for (y=0; y < iSourceHeight; y++)	{
 				for (x=0; x < iSourceWidth; x++)	{
 					thePixel = theImage.pixel(x+iSourceStartX, y+iSourceStartY);
-					thePixel &= 0x00ffffff;			// filter out the transparency part of the color
+					thePixel &= 0x00ffffff;			// filter out the transparency part of the color (not used in Qt 3.x)
 					if (thePixel != 0x000000)	{	// And check if this is a pixel we need to handle ...
-						if (fTargetTrans != 0.0)	{		// If there is a transparency part, we need to 
+						// If there is a transparency part, or some color we need to filter out, 
+						// then  we need to go through this slow loop.
+						if ( (fTargetTrans != 0.0) || (manipulator().listColorKeys.count ()) )	{ 
 							sourcePixel = sourceImg.pixel(x, y);	// calculate the mix of background and foreground.
 							sourceColor = QColor (sourcePixel);
 							targetColor = QColor ( thePixel );
-							theColor = QColor (
-								(int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
-								(int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
-								(int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
-							);
+							if (filterColorKey ( &targetColor, &listColorKeyMin, &listColorKeyMax ))
+								theColor = sourceColor;
+							else
+								theColor = QColor (
+									(int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
+									(int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
+									(int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
+								); 
 							painter->setPen ( theColor );
 						}
 						else	// No transparency is slightly easier ...
@@ -205,8 +233,15 @@ void ImageObject::drawContents (QPainter *painter)
 					}
 				}
 			}
+			if (manipulator().listColorKeys.count() > 0)	{
+				for (t=0;t<(int)manipulator().listColorKeys.count();t++)	{
+					delete listColorKeyMin[t];
+					delete listColorKeyMax[t];
+				}
+			}
 		}
 	}
+	// Phew ... This funtion has grow over time ...
 }
 
 void ImageObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
@@ -214,85 +249,28 @@ void ImageObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 	// Next is to set the AnimationAttributes
 	for (uint t=0;t<m_listAnimationAttributes.count();t++)
 		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
-//printf ("<%ld>X1=<%d> Y1=<%d> trans=<%03f>\n", iRenderFrameNumber, m_rect.x(), m_rect.y(), m_imageManipulator.fTransparency);
-
+	// And then we can go ahead and draw the contents with the newly set attributes.
 	drawContents (pPainter);
 }
 
-/* Without transparency ...
-void ImageObject::drawContents (QPainter *painter)
+// This function checks if pColor is within the min/max of one of the color keys.
+bool ImageObject::filterColorKey ( QColor *pColor, QValueList<QColor *> *pListColorMin, QValueList<QColor *>*pListColorMax )
 {
-	QWMatrix theMatrix;
-	// Here we calculate the center point of gravity (rotation)
-	QPoint centerPos;
-	centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));
-	centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));
-	// Here we define the cenetered rect.
-	QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
-
-	QPen thePen (QColor (255,0,0), 2, Qt::DashDotLine);
-	painter->setPen(thePen);
-
-	// From the Qt documentation ...
-	// This transformation engine is a three-step pipeline
-	// The first step uses the world transformation matrix.
-	// The second step uses the window.
-	// The third step uses the viewport.
-
-	// First we translate to the appropriate location,
-	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
-
-	//. then we apply the other modifications ...
-//	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
-	theMatrix.rotate (manipulator().fRotate);
-	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
-
-	// Here we get the rect that encompasses the button for this object.
-	m_boundingRect = theMatrix.mapRect(theRect);
-
-	if (m_bDrawRect)
-		painter->drawRect(m_boundingRect);
-
-	painter->setWorldMatrix(theMatrix);
-
-	// Here we re-set the world matrix and translate the newly drawn ... thing ...
-	if (m_bDrawRect)
-		painter->drawRect(theRect);
-
-	theMatrix.reset();
-	painter->setWorldMatrix(theMatrix);
-	if (!m_bDrawRect)	{
-		int x, y;
-		QRgb thePixel;
-		int iSourceHeight = pixmap().height();
-		int iSourceWidth  = pixmap().width ();
-		int iSourceStartX = 0;
-		int iSourceStartY = 0;
-		int iTargetStartX = painter->viewport().x() + m_boundingRect.x();
-		int iTargetStartY = painter->viewport().y() + m_boundingRect.y();
-		if (( (manipulator().fRotate ==   0.0) || (manipulator().fRotate ==  90.0) ||
-			  (manipulator().fRotate == 180.0) || (manipulator().fRotate == 270.0) ) &&
-			( (manipulator().fShearX == 0.0) && (manipulator().fShearY ==   0.0) )
-		   )
-			bitBlt (painter->device(), iTargetStartX, iTargetStartY, &pixmap(), iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
-		else	{
-			QImage theImage = pixmap().convertToImage();
-			// Okay if the rotation is any angle, then we get black background even with background image enabled.
-			// Here we copy only those pixel over, which are part of the rotated image.
-			for (y=0; y < iSourceHeight; y++)	{
-				for (x=0; x < iSourceWidth; x++)	{
-					thePixel = theImage.pixel(x+iSourceStartX, y+iSourceStartY);
-					thePixel &= 0x00ffffff;	// filter out the transparency part
-					if (thePixel != 0x000000)	{
-						painter->setPen (QColor (thePixel));
-						painter->drawPoint(x+iTargetStartX, y+iTargetStartY);
-					}
-				}
-			}
-		}
+	int iRed, iGreen, iBlue, t, iColorKeyCount;
+	iColorKeyCount = manipulator().listColorKeys.count ();
+	if ( ( iColorKeyCount < 1 ) || ( ! pListColorMin ) || ( ! pListColorMax ) )
+		return false;
+	iRed = pColor->red(); iGreen = pColor->green(); iBlue = pColor->blue ();
+	for (t=0;t<iColorKeyCount;t++)	{
+//printf ("RGB<%02x%02x%02x> MIN<%02x%02x%02x> MAX<%02x%02x%02x> - ", iRed, iGreen, iBlue, (*pListColorMin)[t]->red  (), (*pListColorMin)[t]->green  (), (*pListColorMin)[t]->blue  (), (*pListColorMax)[t]->red(),(*pListColorMax)[t]->green(), (*pListColorMax)[t]->blue());
+		if (	(iRed   >= (*pListColorMin)[t]->red  () && iRed   <= (*pListColorMax)[t]->red  ()) && 
+			(iGreen >= (*pListColorMin)[t]->green() && iGreen <= (*pListColorMax)[t]->green()) &&
+			(iBlue  >= (*pListColorMin)[t]->blue () && iBlue  <= (*pListColorMax)[t]->blue ()) )
+			return true;
 	}
+	return false;
 }
-*/
+
 void ImageObject::updatePixmap()
 {
 	// This function will take the input image and pass it through the whole modifications pipeline,
@@ -377,55 +355,8 @@ bool ImageObject::readProjectFile  (QDomNode &theNode)
 	QDomNode manNode = theNode.firstChild();
 	while (!manNode.isNull())	{
 		QDomElement manElement = manNode.toElement();
-		if (manElement.tagName() == MANIPULATOR)	{
-			attribute = manElement.attributeNode ( MANIPULATOR_FILE_NAME );
-			if (!attribute.isNull())
-				manipulator().backgroundFileName = attribute.value();
-
-			attribute = manElement.attributeNode ( MANIPULATOR_SHOW_BACKGROUND );
-			if (!attribute.isNull())
-				 manipulator().bShowBackground = (attribute.value() == QString ("yes"));
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_STARTX );
-			if (!attribute.isNull())
-				 manipulator().iStartX = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_STARTY );
-			if (!attribute.isNull())
-				 manipulator().iStartY = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_XRES );
-			if (!attribute.isNull())
-				 manipulator().iXRes = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_YRES );
-			if (!attribute.isNull())
-				 manipulator().iYRes = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_TRANSFORMATION_MODE );
-			if (!attribute.isNull())
-				 manipulator().iTransformationMode = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_ASPECT_RATIO );
-			if (!attribute.isNull())
-				 manipulator().fAspectRatio = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_RED );
-			if (!attribute.isNull())
-				 manipulator().fRed = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_GREEN );
-			if (!attribute.isNull())
-				 manipulator().fGreen = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_BLUE );
-			if (!attribute.isNull())
-				 manipulator().fBlue = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_BRIGHTNESS );
-			if (!attribute.isNull())
-				 manipulator().fBrightness = attribute.value().toFloat();
-		}
+		if (manElement.tagName() == MANIPULATOR)
+			manipulator().readProjectFile (manNode);
 		else if (manElement.tagName() == MENU_OBJECT)
 			MenuObject::readProjectFile( theNode );
 
@@ -443,48 +374,7 @@ bool ImageObject::writeProjectFile (QDomElement &theElement)
 	if (!m_qsFileName.isNull())
 		imageNode.setAttribute( IMAGE_OBJECT_FILE_NAME, m_qsFileName );
 
-	// Store the ImageManipulator - cariables (if neccesarry) ...
-	ImageManipulator initialValues;
-	if ((!manipulator().backgroundFileName.isEmpty())                                ||
-		(manipulator().bShowBackground != initialValues.bShowBackground)         ||
-		(manipulator().iStartX != initialValues.iStartX)                         ||
-		(manipulator().iStartY != initialValues.iStartY)                         ||
-		(manipulator().iXRes != initialValues.iXRes)                             ||
-		(manipulator().iYRes != initialValues.iYRes)                             ||
-		(manipulator().iTransformationMode != initialValues.iTransformationMode) ||
-		(manipulator().fAspectRatio != initialValues.fAspectRatio)               ||
-		(manipulator().fRed != initialValues.fRed)                               ||
-		(manipulator().fGreen != initialValues.fGreen)                           ||
-		(manipulator().fBlue != initialValues.fBlue)                             ||
-		(manipulator().fBrightness != initialValues.fBrightness) )                {
-
-		QDomElement manipulatorNode = xmlDoc.createElement ( MANIPULATOR );
-		if (!manipulator().backgroundFileName.isEmpty())
-			manipulatorNode.setAttribute( MANIPULATOR_FILE_NAME, manipulator().backgroundFileName );
-		if (manipulator().bShowBackground != initialValues.bShowBackground)
-			manipulatorNode.setAttribute( MANIPULATOR_SHOW_BACKGROUND, manipulator().bShowBackground ? QString ("yes") : QString ("no"));
-		if (manipulator().iStartX != initialValues.iStartX)
-			manipulatorNode.setAttribute( MANIPULATOR_STARTX, QString ("%1").arg(manipulator().iStartX) );
-		if (manipulator().iStartY != initialValues.iStartY)
-			manipulatorNode.setAttribute( MANIPULATOR_STARTY, QString ("%1").arg(manipulator().iStartY) );
-		if (manipulator().iXRes != initialValues.iXRes)
-			manipulatorNode.setAttribute( MANIPULATOR_XRES, QString ("%1").arg(manipulator().iXRes) );
-		if (manipulator().iYRes != initialValues.iYRes)
-			manipulatorNode.setAttribute( MANIPULATOR_YRES, QString ("%1").arg(manipulator().iYRes) );
-		if (manipulator().iTransformationMode != initialValues.iTransformationMode)
-			manipulatorNode.setAttribute( MANIPULATOR_TRANSFORMATION_MODE, QString ("%1").arg(manipulator().iTransformationMode) );
-		if (manipulator().fAspectRatio != initialValues.fAspectRatio)
-			manipulatorNode.setAttribute( MANIPULATOR_ASPECT_RATIO, QString ("%1").arg(manipulator().fAspectRatio) );
-		if (manipulator().fRed != initialValues.fRed)
-			manipulatorNode.setAttribute( MANIPULATOR_RED, QString ("%1").arg(manipulator().fRed) );
-		if (manipulator().fGreen != initialValues.fGreen)
-			manipulatorNode.setAttribute( MANIPULATOR_GREEN, QString ("%1").arg(manipulator().fGreen) );
-		if (manipulator().fBlue != initialValues.fBlue)
-			manipulatorNode.setAttribute( MANIPULATOR_BLUE, QString ("%1").arg(manipulator().fBlue) );
-		if (manipulator().fBrightness != initialValues.fBrightness)
-			manipulatorNode.setAttribute( MANIPULATOR_BRIGHTNESS, QString ("%1").arg(manipulator().fBrightness) );
-		imageNode.appendChild( manipulatorNode );
-	}
+	manipulator().writeProjectFile (imageNode);
 
 	theElement.appendChild( imageNode );
 	// And here we write the base class ...
@@ -493,58 +383,20 @@ bool ImageObject::writeProjectFile (QDomElement &theElement)
 
 void ImageObject::createStructure (QListViewItem *pParentItem)
 {
-	QListViewItem *pButtonItem;
-	QListViewItem *pModifierItem;
+	StructureItem *pButtonItem;
 	QFileInfo fileInfo(m_qsFileName);
 	QString qsName;
 	
 	qsName = QString ("Image Object");
 
-	pButtonItem = new QListViewItem(pParentItem, qsName, fileInfo.fileName());
+	pButtonItem = new StructureItem(this, pParentItem, qsName, fileInfo.fileName());
 	pButtonItem->setExpandable (TRUE);
 
-	ImageObject initialValues;
-	// And finally we create the modifiers info ...
-	if ( !(	(manipulator().fRotate     == initialValues.manipulator().fRotate) &&
-			(manipulator().fShearX       == initialValues.manipulator().fShearX) &&
-			(manipulator().fShearY       == initialValues.manipulator().fShearY) &&
-			(manipulator().fZoom         == initialValues.manipulator().fZoom)   &&
-			(manipulator().fBrightness   == initialValues.manipulator().fBrightness) &&
-			(manipulator().fTransparency == initialValues.manipulator().fTransparency) &&
-			(manipulator().fRed          == initialValues.manipulator().fRed)    &&
-			(manipulator().fGreen        == initialValues.manipulator().fGreen)  &&
-			(manipulator().fBlue         == initialValues.manipulator().fBlue)
-			) )	{
-		pModifierItem = new QListViewItem(pButtonItem, QString ("Modifiers"), NULL);
-		pButtonItem->setExpandable (TRUE);
+	manipulator ().createStructure (pButtonItem);
 
-		if ((manipulator().fRed        != initialValues.manipulator().fRed)   ||
-			(manipulator().fGreen      != initialValues.manipulator().fGreen) ||
-			(manipulator().fBlue       != initialValues.manipulator().fBlue) )
-			new QListViewItem(pModifierItem, QString ("Color Adjust"),
-				QString ("%1, %2, %3").arg(manipulator().fRed).arg(manipulator().fGreen).arg(manipulator().fBlue));
-		if (manipulator().fBrightness  != initialValues.manipulator().fBrightness)
-			new QListViewItem(pModifierItem, QString ("Brightness"),
-				QString ("%1").arg(manipulator().fBrightness));
-		if (manipulator().fTransparency  != initialValues.manipulator().fTransparency)
-			new QListViewItem(pModifierItem, QString ("Transparency"),
-				QString ("%1").arg(manipulator().fTransparency));
-		if ((manipulator().fShearX  != initialValues.manipulator().fShearX) ||
-			(manipulator().fShearY  != initialValues.manipulator().fShearY)  )
-			new QListViewItem(pModifierItem, QString ("Shear (x, y)"),
-				QString ("%1, %2").arg(manipulator().fShearX).arg(manipulator().fShearY));
-		if (manipulator().fZoom  != initialValues.manipulator().fZoom)
-			new QListViewItem(pModifierItem, QString ("Zoom"),
-				QString ("%1").arg(manipulator().fZoom));
-		if (manipulator().fRotate  != initialValues.manipulator().fRotate)
-			new QListViewItem(pModifierItem, QString ("Rotate"),
-				QString ("%1 deg").arg(manipulator().fRotate));
-	}
-
-	new QListViewItem(pButtonItem, QString ("Geometry"),
+	new StructureItem(this, pButtonItem, QString ("Geometry"),
 		QString ("%1, %2, %3, %4").
 		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
-
 }
 
 bool ImageObject::mouseMoveEvent (QMouseEvent *pEvent)
@@ -571,44 +423,47 @@ bool ImageObject::mousePressEvent (QMouseEvent *pEvent)
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
 		QPoint globalPos = pEvent->globalPos();
-		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
-		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
-		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
-		pStackMenu->popup(globalPos, 1);
-
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = new QPopupMenu(m_pParent);
-		m_pContextMenu->insertItem ( QString ("Edit ...")      , this, SLOT(slotEdit()));
-		m_pContextMenu->insertItem ( QString ("Properties ..."), this, SLOT(slotProperties()));
-		m_pContextMenu->insertItem ( QString ("Matrix ...")    , this, SLOT(slotMatrix()));
-		m_pContextMenu->insertItem ( QString ("Delete")        , this, SLOT(slotDelete()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( QString ("Rotate 90")     , this, SLOT(slotRotate90 ()));
-		m_pContextMenu->insertItem ( QString ("Rotate 180")    , this, SLOT(slotRotate180()));
-		m_pContextMenu->insertItem ( QString ("Rotate 270")    , this, SLOT(slotRotate270()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( QString ("Add Frame")     , this, SLOT(slotAddFrame()));
-		m_pContextMenu->insertItem ( QString ("Add Text")      , this, SLOT(slotAddText()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( QString ("Define as Button") , this, SLOT(slotDefineAsButton()));
-		// Blocking call.
-		m_pContextMenu->exec(pEvent->globalPos(), 6);
-		delete pStackMenu;
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = NULL;
-		// Here we mark that the user called a menu item thus we don't want the
-		// base classes to continue with the mouse event
-//		if (iReturn != -1)
-			return true;
+		return createContextMenu ( globalPos );
 	}
 	else
 		m_bDrawRect = true;
 	return false;
 }
 
+bool ImageObject::createContextMenu ( QPoint globalPos )
+{
+	QPoint globalPos2 = globalPos;
+	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	pStackMenu->popup(globalPos, 1);
+
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = new QPopupMenu(m_pParent);
+	m_pContextMenu->insertItem ( tr ("Edit ...")      , this, SLOT(slotEdit()));
+	m_pContextMenu->insertItem ( tr ("Properties ..."), this, SLOT(slotProperties()));
+	m_pContextMenu->insertItem ( tr ("Matrix ...")    , this, SLOT(slotMatrix()));
+	m_pContextMenu->insertItem ( tr ("Delete")        , this, SLOT(slotDelete()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Rotate 90")     , this, SLOT(slotRotate90 ()));
+	m_pContextMenu->insertItem ( tr ("Rotate 180")    , this, SLOT(slotRotate180()));
+	m_pContextMenu->insertItem ( tr ("Rotate 270")    , this, SLOT(slotRotate270()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Add Frame")     , this, SLOT(slotAddFrame()));
+	m_pContextMenu->insertItem ( tr ("Add Text")      , this, SLOT(slotAddText()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
+	// Blocking call.
+	m_pContextMenu->exec(globalPos2, 6);
+	delete pStackMenu;
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = NULL;
+	return true;
+}
+
 bool ImageObject::mouseReleaseEvent (QMouseEvent *)
 {
 	m_bDrawRect = false;
@@ -631,9 +486,10 @@ void ImageObject::slotEdit()
 
 void ImageObject::slotProperties()
 {
+	ImageManipulator *pMan= &manipulator();
 	DialogGeometry *pGeometry = new DialogGeometry ();
-	pGeometry->initMe(rect());
-	
+	pGeometry->initMe(rect(), pMan);
+
 	connect ( pGeometry->m_pButtonAnimation, SIGNAL(clicked()), this, SLOT(slotAnimation()) );
 	
 	if (pGeometry->exec() == QDialog::Accepted)	{
@@ -643,6 +499,28 @@ void ImageObject::slotProperties()
 		iWidth  = pGeometry->m_pEditWidth ->text().toInt();
 		iHeight = pGeometry->m_pEditHeight->text().toInt();
 		QRect rect (iX, iY, iWidth, iHeight);
+		
+		ImageManipulator::colorKeying *pColorKey;
+		ListViewColorItem *pItem;
+		uint t;
+		float  fDelta;
+		QColor theColor;
+
+		// First we should remove all entries in the color Key
+		for (t=0;t<pMan->listColorKeys.count();t++)
+			delete pMan->listColorKeys[t];
+		pMan->listColorKeys.clear();
+		// And then we add whats currently in the widget.
+		if ( pGeometry->m_pListViewCK->childCount() )	{
+			pItem = (ListViewColorItem *)pGeometry->m_pListViewCK->firstChild ();
+			while (pItem)	{
+				theColor.setNamedColor (pItem->text (0));	// The Color nam is stored in the first text
+				fDelta = pItem->text(1).toFloat();		// The delta value is stored in the second column.
+				pColorKey = new ImageManipulator::colorKeying ( theColor.rgb(), fDelta );
+				pMan->listColorKeys.append ( pColorKey );
+				pItem = (ListViewColorItem *)pItem->itemBelow ();
+			}
+		}
 		setRect (rect);
 		updatePixmap ();
 		emit (signalUpdatePixmap());
@@ -653,7 +531,7 @@ void ImageObject::slotProperties()
 void ImageObject::slotAnimation ()
 {
 	// This function gets the Animation Dialog
-	// Within this dialo, you can create a script
+	// Within this dialog, you can create a script
 	// (or hardcode) Attributes of the object.
 	// Before rendering the menu the script will 
 	// get executed and all data sent to stdout 
@@ -686,7 +564,6 @@ void ImageObject::slotRotate270()
 
 void ImageObject::rotate(float fRot)
 {
-//printf ("ImageObject::rotate (%f)<%f>\n", manipulator().fRotate, modifiers()->fRotate);
 	QWMatrix theMatrix;
 	theMatrix.rotate (fRot);
 	float fRotate = manipulator().fRotate + fRot;
@@ -735,11 +612,12 @@ MenuObject *ImageObject::clone()
 	// informations solely from the Normal State - objects ...
 	pNewObject->setRect(rect());
 	pNewObject->setManipulator(manipulator());
-//	pNewObject->setModifiers(*modifiers());
 
 	return pNewObject;
 }
 
+// Called from xyz, when creating the AnimationAttribute objects, which hold the list of valuers for the attribute to be set.
+// Note: only those AnimationAttribute objects are created which are modified during the animation (Menu - video).
 AnimationAttribute *ImageObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
 {
 	AnimationAttribute *pAnimAttr = NULL;
@@ -763,9 +641,9 @@ AnimationAttribute *ImageObject::getSpecificAttributes (long iMaxNumberOfFrames,
 	else if (qsProperty == "showBackground")
 		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.bShowBackground, &m_imageManipulator.bShowBackground);
 	else if (qsProperty == "startPos.x")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iStartX, &m_imageManipulator.iStartX);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fStartX, &m_imageManipulator.fStartX);
 	else if (qsProperty == "startPos.y")
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iStartY, &m_imageManipulator.iStartY);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fStartY, &m_imageManipulator.fStartY);
 	else if (qsProperty == "res.x")
 		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iXRes, &m_imageManipulator.iXRes);
 	else if (qsProperty == "res.y")
