@@ -30,9 +30,10 @@ public:
 	virtual bool mouseReleaseEvent     (QMouseEvent *);
 	virtual bool mouseDoubleClickEvent (QMouseEvent *);
 
-	virtual bool readProjectFile  (QDomNode &);
-	virtual bool writeProjectFile (QDomElement &);
-	virtual void createStructure (QListViewItem *);
+	virtual bool readProjectFile       (QDomNode &);
+	virtual bool writeProjectFile      (QDomElement &);
+	virtual void createStructure       (QListViewItem *);
+	virtual bool createContextMenu     (QPoint);
 	virtual MenuObject *clone();
 
 public:
@@ -54,18 +55,19 @@ signals:
 	
 protected:
 	virtual AnimationAttribute *getSpecificAttributes (long, QString);
+	bool filterColorKey ( QColor *, QValueList<QColor *>*, QValueList<QColor *>*);
 	void rotate (float);
 
 protected slots:
-	virtual void slotEdit       ();
-	virtual void slotProperties ();
-	virtual void slotRotate90   ();
-	virtual void slotRotate180  ();
-	virtual void slotRotate270  ();
-	virtual void slotMatrix     ();
-	virtual void slotAddFrame   ();
-	virtual void slotAddText    ();
-	virtual void slotAnimation  ();
+	virtual void slotEdit          ();
+	virtual void slotProperties    ();
+	virtual void slotRotate90      ();
+	virtual void slotRotate180     ();
+	virtual void slotRotate270     ();
+	virtual void slotMatrix        ();
+	virtual void slotAddFrame      ();
+	virtual void slotAddText       ();
+	virtual void slotAnimation     ();
 	virtual void slotDefineAsButton();
 
 protected:
