@@ -177,9 +177,9 @@ void ListViewItemMedia::drawButtonState (QPixmap *pPixmap)
 			bSelected = true;
 
 		if (bSelected)
-			theImage = QImage::fromMimeSource(arrayPressedButtonState[t]).smoothScale (iOffset, iThirdHeight);
+			theImage = QImage().fromMimeSource(arrayPressedButtonState[t]).smoothScale (iOffset, iThirdHeight);
 		else
-			theImage = QImage::fromMimeSource(arrayNormalButtonState[t]).smoothScale(iOffset, iThirdHeight);
+			theImage = QImage().fromMimeSource(arrayNormalButtonState[t]).smoothScale(iOffset, iThirdHeight);
 		theButton = theImage;
 		bitBlt (pPixmap, 0, t*iThirdHeight, &theButton, 0, 0, theButton.width(), theButton.height(),  Qt::CopyROP);
 	}
