@@ -1,12 +1,14 @@
 /****************************************************************************
-** ImagePreview class
+** MenuOject class
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
+** This class is the encapsulation of the MenuObject.
+**
+** A MenuObject is the base class for any visible object in a DVD menu.
+** A MenuObject itself is not visible and not used in itself. Only derived
+** classes are used in the DVD Menu.
 **
 ****************************************************************************/
 
@@ -108,6 +110,14 @@ bool MenuObject::readProjectFile  (QDomNode &theNode)
 					attribute = theElement.attributeNode ( MODIFIERS_TRANSPARENCY );
 					if (!attribute.isNull())
 						modifiers()->fTransparency = attribute.value().toFloat();
+					
+					attribute = theElement.attributeNode ( MODIFIERS_START_FRAME );
+					if (!attribute.isNull())
+						modifiers()->iStartFrame = attribute.value().toInt();
+					
+					attribute = theElement.attributeNode ( MODIFIERS_STOP_FRAME );
+					if (!attribute.isNull())
+						modifiers()->iStopFrame = attribute.value().toInt();
 
 					attribute = theElement.attributeNode ( MODIFIERS_ZOOM );
 					if (!attribute.isNull())
@@ -166,6 +176,7 @@ bool MenuObject::writeProjectFile (QDomElement &theElement)
 	if (	(modifiers()->fRotate != initialValues.fRotate) || (modifiers()->fShearX != initialValues.fShearX)  || 
 		(modifiers()->fShearY != initialValues.fShearX) || (modifiers()->fZoom != initialValues.fZoom)      || 
 		(modifiers()->fScaleX != initialValues.fScaleX) || (modifiers()->fScaleY != initialValues.fScaleY)  ||
+		(modifiers()->iStartFrame   != initialValues.iStartFrame) || (modifiers()->iStopFrame != initialValues.iStopFrame)  ||
 		(modifiers()->fTransparency != initialValues.fTransparency) )	{
 
 		QDomElement modifiersNode = xmlDoc.createElement ( MODIFIERS );
@@ -181,6 +192,10 @@ bool MenuObject::writeProjectFile (QDomElement &theElement)
 			modifiersNode.setAttribute( MODIFIERS_SCALEX, QString ("%1").arg(modifiers()->fScaleX) );
 		if (modifiers()->fScaleY != initialValues.fScaleY)
 			modifiersNode.setAttribute( MODIFIERS_SCALEY, QString ("%1").arg(modifiers()->fScaleY) );
+		if (modifiers()->iStartFrame != initialValues.iStartFrame)
+			modifiersNode.setAttribute( MODIFIERS_START_FRAME, QString ("%1").arg(modifiers()->iStartFrame) );
+		if (modifiers()->iStopFrame != initialValues.iStopFrame)
+			modifiersNode.setAttribute( MODIFIERS_STOP_FRAME, QString ("%1").arg(modifiers()->iStopFrame) );
 		if (modifiers()->fTransparency != initialValues.fTransparency)
 			modifiersNode.setAttribute( MODIFIERS_TRANSPARENCY, QString ("%1").arg(modifiers()->fTransparency) );
 		objectNode.appendChild( modifiersNode );
@@ -233,13 +248,7 @@ Modifiers *MenuObject::modifiers()
 
 void MenuObject::setModifiers(Modifiers &theModifiers)
 {
-	modifiers()->fRotate       = theModifiers.fRotate;
-	modifiers()->fZoom         = theModifiers.fZoom;
-	modifiers()->fTransparency = theModifiers.fTransparency;
-	modifiers()->fScaleX       = theModifiers.fScaleX;
-	modifiers()->fScaleY       = theModifiers.fScaleY;
-	modifiers()->fShearX       = theModifiers.fShearX;
-	modifiers()->fShearY       = theModifiers.fShearY;
+	*modifiers() = theModifiers;
 }
 
 QPoint   &MenuObject::currentMousePos()
@@ -426,6 +435,12 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
 					FunctionCallback<QRect> *callMeBack = new FunctionCallback<QRect>(m_rect, &QRect::setHeight);
  					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_rect.height(), callMeBack);
 				}
+				else if (qsProperty == "visibleFromTo.startFrame")
+					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.iStartFrame, &m_modifiers.iStartFrame);
+				else if (qsProperty == "visibleFromTo.stopFrame")
+					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.iStopFrame, &m_modifiers.iStopFrame);
+				else if (qsProperty == "transparency")
+					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fTransparency, &m_modifiers.fTransparency);
 				else if (qsProperty == "zoom")
 					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fZoom, &m_modifiers.fZoom);
 				else if (qsProperty == "rotate")
@@ -438,8 +453,6 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
  					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fScaleX, &m_modifiers.fScaleX);
 				else if (qsProperty == "scale.y")
  					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fScaleY, &m_modifiers.fScaleY);
-				else if (qsProperty == "transparency")
-					pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_modifiers.fTransparency, &m_modifiers.fTransparency);
 			}
 			if (pAnimAttr)
 				m_listAnimationAttributes.append ( pAnimAttr );
@@ -450,26 +463,4 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
 	file.close();
 }
 
-/*
-	if (listAnimationAttributes.count() < 1)
-		return;
-	// This part in the MenuPreview or ButtonPreview - class
-	iMaxNumberOfFrames = listAnimationAttributes[0]->maxFrames();
-	for (i=0;i<iMaxNumberOfFrames;i++)	{
-		for (t=0;t<listAnimationAttributes.count();t++)	{
-			listAnimationAttributes[t]->setValue (i);
-printf ("<%d : %ld>X1=<%d> Y1=<%d> trans=<%03f>\n", t, i, m_rect.x(), m_rect.y(), m_modifiers.fTransparency);
-		}
-	}
-}
-
-
-	QRect	    m_rect;
-	QRect       m_boundingRect;
-	QWidget    *m_pParent;
-	bool        m_bDrawRect;
-	Modifiers   m_modifiers;
-	QString     m_qsAnimation;	// script or dataset holds also the datafilename
-	QPoint      m_currentMousePos;
-*/
 
