@@ -1,17 +1,22 @@
 /****************************************************************************
-** ImagePreview class
+** MenuPreview class
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
+** This class is the encapsulation of the MenuPreview.
+**
+** The MenuPreview is derived off the ButtonPreview and used 
+** to display a DVD Menu.
+** The ButtonPreview is the preview class used in the ButtonObject
+** to display the different levels of a buttonObject.
+**
 **
 ****************************************************************************/
 
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <stdlib.h>
 
 #include <qfiledialog.h>
 #include <qmessagebox.h>
@@ -146,6 +151,11 @@ void MenuPreview::mousePressEvent (QMouseEvent *pEvent)
 	setCursor(myCursor);
 	m_bActiveCursor = false;
 
+	createContextMenu ( pEvent->globalPos () );
+}
+
+bool MenuPreview::createContextMenu ( QPoint globalPos )
+{
 	QPopupMenu *pMenu = new QPopupMenu (this);
 	pMenu->insertItem ( tr ("Add Frame"), this, SLOT(slotAddFrameObject()));
 	pMenu->insertItem ( tr ("Add Text") , this, SLOT(slotAddTextObject()));
@@ -161,9 +171,10 @@ void MenuPreview::mousePressEvent (QMouseEvent *pEvent)
 		pMenu->insertItem (tr ("Rename Menu"), this, SLOT(slotRenameMenu()));
 		pMenu->insertItem (tr ("Delete Menu"), this, SLOT(slotDeleteMenu()));
 	}
-	pMenu->exec(pEvent->globalPos());
+	pMenu->exec(globalPos);
 
 	delete pMenu;
+	return true;
 }
 
 void MenuPreview::mouseReleaseEvent (QMouseEvent *pEvent)
@@ -235,13 +246,45 @@ void MenuPreview::mouseMoveEvent (QMouseEvent *pEvent)
 	// Here we draw the dynamicly changing size of the rect.
 
 	// First we clear the contents of the previous rectangle
-	repaint(m_rectCurrentObject, FALSE);
+	//	repaint(m_rectCurrentObject, FALSE);
+	int iX, iY, iX1, iY1, iX2, iY2;
+	iX  = pEvent->pos ( ).x ( );
+	iY  = pEvent->pos ( ).y ( );
+	iX1 = m_rectCurrentObject.x();
+	iY1 = m_rectCurrentObject.y();
+	
+	if ( iX1 > iX ) {
+	  iX2 = iX1 + 50;
+	  iX1 = iX  - 5;
+	}
+	else
+	  iX2 = iX  + 50;
+	if ( iY1 > iY ) {
+	  iY2 = iY1 + 20;
+	  iY1 = iY  - 5;
+	}
+	else
+	  iY2 = iY  + 20;
+	// give some extra space to be erased ...
+	iX1 -= 20;
+	iY1 -= 20;
+	iX2 += 50;
+	iY2 += 20;
+	// ensure it is within the boundaries ...
+	iX1 = ( iX1 < 0 ) ? 0 : iX1;
+	iY1 = ( iY1 < 0 ) ? 0 : iY1;
+	iX2 = ( iX2 > width  () ) ? width  () : iX2;
+	iY2 = ( iY2 > height () ) ? height () : iY2;
+	repaint ( iX1, iY1, iX + 50, iY + 20, FALSE ); 
+	//	repaint( FALSE );
 	QPainter thePainter (this);
 	QPen thePen (QColor (255, 30,30), 2, Qt::DashDotLine);
-	thePainter.setPen(thePen);
-	m_rectCurrentObject.setRight(pEvent->pos().x());
-	m_rectCurrentObject.setBottom(pEvent->pos().y());
+	thePainter.setPen( thePen );
+	
+	m_rectCurrentObject.setRight  ( iX );
+	m_rectCurrentObject.setBottom ( iY );
 	thePainter.drawRect (m_rectCurrentObject);
+	thePainter.drawText ( iX+5, iY+15, QString ( "%1 : %2" ).arg( m_rectCurrentObject.width ( ) ).arg( m_rectCurrentObject.height ( ) ) );
 }
 
 void MenuPreview::slotEditTimeline ()
@@ -300,9 +343,15 @@ MenuObject *MenuPreview::insertDraggedObject (QDropEvent *pDropEvent, QImage &th
 		ListViewMedia *pListViewMedia = (ListViewMedia *)pDropEvent->source();
 		SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry();
 		SourceFileInfo  *pSourceFileInfo  = pListViewMedia->draggingSourceFileInfo();
-		if (pSourceFileEntry->bSoundSource)	// No adding of a sound source !
+		if ( pSourceFileEntry->bSoundSource )  {	// No adding of a sound source !
+			QMessageBox::warning (NULL, tr("Can not add."), tr ("This is a sound source.\nI can currently not add this type of source.\n"), QMessageBox::Ok, QMessageBox::NoButton);
 			return NULL;
-		if (pSourceFileInfo)	// Okay here we split between adding one button
+		}
+		if ( pSourceFileEntry->bIsSlideshow )	{
+			QMessageBox::warning (NULL, tr("Can not add."), tr ("The slideshow is still beeing created.\nI can not add it at this moment.\n"), QMessageBox::Ok, QMessageBox::NoButton);
+			return NULL;
+		}
+		if ( pSourceFileInfo)	// Okay here we split between adding one button
 			pMenuObject = insertDraggedSourceInfo  (pDropEvent, theImage);	// ButtonObject
 		else	// Or we dragged the full SourceEntry and will use the defined Layout
 			if (pSourceFileEntry->listFileInfos.count() == 1)	// Now only one movie in the Entry ... Booooring ...
@@ -1026,10 +1075,10 @@ void MenuPreview::slotDefineAsButton(MenuObject *pTheObject)
 	QColor colorSelected    (START_SELECTED_COLOR);
 	QColor colorSpare       (TRANSPARENT_COLOR);
 	if (m_pPgcColors)	{
-		colorTransparent 	= m_pPgcColors[0];
- 		colorHighlighted	= m_pPgcColors[1];
-		colorSelected		= m_pPgcColors[2];
-		colorSpare			= m_pPgcColors[3];
+		colorTransparent = m_pPgcColors[0];
+ 		colorHighlighted = m_pPgcColors[1];
+		colorSelected	 = m_pPgcColors[2];
+		colorSpare       = m_pPgcColors[3];
 	}
 
 	pNewSelected = pNewHighlighted = NULL;
@@ -1212,8 +1261,8 @@ void MenuPreview::slotModifyObject(MenuObject *pObject)
 	*pManipulator = pImage->manipulator();
 	// Note that we store the fRealZoom under fStartZoom in the ImagePreview.
 	pManipulator->fZoom   = 1.0;
-	pManipulator->iStartX = pImage->rect().x();
-	pManipulator->iStartY = pImage->rect().y();
+	pManipulator->fStartX = ((float)pImage->rect().x() / width ());
+	pManipulator->fStartY = ((float)pImage->rect().y() / height());
 //	pManipulator->backgroundFileName = qsBackgroundImage;
 
 	DialogImage imageDialog(this);
