@@ -1,12 +1,14 @@
 /****************************************************************************
-** ImagePreview class
+** MovieObject class
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
+** This class is the encapsulation of the MovieObject.
+**
+** The MovieObject is a DVD Menu object which displays a short animation/
+** sequence of the movie to be played.
+**
 **
 ****************************************************************************/
 #include <stdlib.h>
@@ -14,7 +16,6 @@
 #include <qmessagebox.h>
 #include <qfileinfo.h>
 #include <qlineedit.h>
-#include <qlistview.h>
 #include <qpainter.h>
 #include <qtimer.h>
 #include <qdir.h>
@@ -24,6 +25,7 @@
 #include "dvdmenu.h"
 #include "movieobject.h"
 #include "dragndropcontainer.h"
+#include "structuretoolbar.h"
 #include "dialogmovie.h"
 #include "qplayer/mediacreator.h"
 #include "qrender/startmenurender.h"
@@ -43,6 +45,9 @@ MovieObject::~MovieObject ()
 		m_pConvertTimer->stop();
 		delete m_pConvertTimer;
 	}
+	// To make sure that there is no background task 
+	// which wants to create the preview for this object
+	MediaCreator::unregisterFromMediaScanner (this);
 }
 
 void MovieObject::setOffset   (QTime &timeOffset)
@@ -119,7 +124,7 @@ void MovieObject::setPixmap(QPixmap &thePixmap)
 	// Note that the real imagePreview is generated in a background thread and later on passed into this object
 	// in order to have the GUI active.
 	QString qsFileName = fileName ();
-	m_imagePreview = QImage (QImage::fromMimeSource("please_wait.jpg"));
+	m_imagePreview = QImage (QImage().fromMimeSource("please_wait.jpg"));
 	if ( (movieSize().width() > 5) && (movieSize().height() > 5) )
 		m_imagePreview = m_imagePreview.smoothScale (movieSize(), QImage::ScaleFree);
 	else
@@ -379,55 +384,8 @@ bool MovieObject::readProjectFile  (QDomNode &theNode)
 	QDomNode manNode = theNode.firstChild();
 	while (!manNode.isNull())	{
 		QDomElement manElement = manNode.toElement();
-		if (manElement.tagName() == MANIPULATOR)	{
-			attribute = manElement.attributeNode ( MANIPULATOR_FILE_NAME );
-			if (!attribute.isNull())
-				manipulator().backgroundFileName = attribute.value();
-
-			attribute = manElement.attributeNode ( MANIPULATOR_SHOW_BACKGROUND );
-			if (!attribute.isNull())
-				 manipulator().bShowBackground = (attribute.value() == QString ("yes"));
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_STARTX );
-			if (!attribute.isNull())
-				 manipulator().iStartX = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_STARTY );
-			if (!attribute.isNull())
-				 manipulator().iStartY = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_XRES );
-			if (!attribute.isNull())
-				 manipulator().iXRes = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_YRES );
-			if (!attribute.isNull())
-				 manipulator().iYRes = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_TRANSFORMATION_MODE );
-			if (!attribute.isNull())
-				 manipulator().iTransformationMode = attribute.value().toInt();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_ASPECT_RATIO );
-			if (!attribute.isNull())
-				 manipulator().fAspectRatio = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_RED );
-			if (!attribute.isNull())
-				 manipulator().fRed = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_GREEN );
-			if (!attribute.isNull())
-				 manipulator().fGreen = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_BLUE );
-			if (!attribute.isNull())
-				 manipulator().fBlue = attribute.value().toFloat();
-
-	 		attribute = manElement.attributeNode ( MANIPULATOR_BRIGHTNESS );
-			if (!attribute.isNull())
-				 manipulator().fBrightness = attribute.value().toFloat();
-		}
+		if (manElement.tagName() == MANIPULATOR)
+			manipulator().readProjectFile ( manElement );
 		else if (manElement.tagName() == MENU_OBJECT)
  			MenuObject::readProjectFile( theNode );
 		manNode = manNode.nextSibling();
@@ -454,110 +412,39 @@ bool MovieObject::writeProjectFile (QDomElement &theElement)
 	movieNode.setAttribute( MOVIE_OBJECT_SIZE, QString("%1x%2").arg(movieSize().width()).arg(movieSize().height()) );
 
 	// Store the ImageManipulator - variables (if neccesarry) ...
-	ImageManipulator initialValues;
-	if ((!manipulator().backgroundFileName.isEmpty())                                ||
-		(manipulator().bShowBackground != initialValues.bShowBackground)         ||
-		(manipulator().iStartX != initialValues.iStartX)                         ||
-		(manipulator().iStartY != initialValues.iStartY)                         ||
-		(manipulator().iXRes != initialValues.iXRes)                             ||
-		(manipulator().iYRes != initialValues.iYRes)                             ||
-		(manipulator().iTransformationMode != initialValues.iTransformationMode) ||
-		(manipulator().fAspectRatio != initialValues.fAspectRatio)               ||
-		(manipulator().fRed != initialValues.fRed)                               ||
-		(manipulator().fGreen != initialValues.fGreen)                           ||
-		(manipulator().fBlue != initialValues.fBlue)                             ||
-		(manipulator().fBrightness != initialValues.fBrightness) )                {
-
-		QDomElement manipulatorNode = xmlDoc.createElement ( MANIPULATOR );
-		if (!manipulator().backgroundFileName.isEmpty())
-			manipulatorNode.setAttribute( MANIPULATOR_FILE_NAME, manipulator().backgroundFileName );
-		if (manipulator().bShowBackground != initialValues.bShowBackground)
-			manipulatorNode.setAttribute( MANIPULATOR_SHOW_BACKGROUND, manipulator().bShowBackground ? QString ("yes") : QString ("no"));
-		if (manipulator().iStartX != initialValues.iStartX)
-			manipulatorNode.setAttribute( MANIPULATOR_STARTX, QString ("%1").arg(manipulator().iStartX) );
-		if (manipulator().iStartY != initialValues.iStartY)
-			manipulatorNode.setAttribute( MANIPULATOR_STARTY, QString ("%1").arg(manipulator().iStartY) );
-		if (manipulator().iXRes != initialValues.iXRes)
-			manipulatorNode.setAttribute( MANIPULATOR_XRES, QString ("%1").arg(manipulator().iXRes) );
-		if (manipulator().iYRes != initialValues.iYRes)
-			manipulatorNode.setAttribute( MANIPULATOR_YRES, QString ("%1").arg(manipulator().iYRes) );
-		if (manipulator().iTransformationMode != initialValues.iTransformationMode)
-			manipulatorNode.setAttribute( MANIPULATOR_TRANSFORMATION_MODE, QString ("%1").arg(manipulator().iTransformationMode) );
-		if (manipulator().fAspectRatio != initialValues.fAspectRatio)
-			manipulatorNode.setAttribute( MANIPULATOR_ASPECT_RATIO, QString ("%1").arg(manipulator().fAspectRatio) );
-		if (manipulator().fRed != initialValues.fRed)
-			manipulatorNode.setAttribute( MANIPULATOR_RED, QString ("%1").arg(manipulator().fRed) );
-		if (manipulator().fGreen != initialValues.fGreen)
-			manipulatorNode.setAttribute( MANIPULATOR_GREEN, QString ("%1").arg(manipulator().fGreen) );
-		if (manipulator().fBlue != initialValues.fBlue)
-			manipulatorNode.setAttribute( MANIPULATOR_BLUE, QString ("%1").arg(manipulator().fBlue) );
-		if (manipulator().fBrightness != initialValues.fBrightness)
-			manipulatorNode.setAttribute( MANIPULATOR_BRIGHTNESS, QString ("%1").arg(manipulator().fBrightness) );
-		movieNode.appendChild( manipulatorNode );
-	}
+	manipulator().writeProjectFile (movieNode);
 
 	theElement.appendChild( movieNode );
 	// And here we write the base class ...
 	return MenuObject::writeProjectFile( movieNode );
 }
 
+bool MovieObject::createContextMenu ( QPoint globalPos )
+{
+  return ImageObject::createContextMenu ( globalPos );
+}
+
 void MovieObject::createStructure (QListViewItem *pParentItem)
 {
-	QListViewItem *pButtonItem;
-	QListViewItem *pModifierItem;
+	StructureItem *pButtonItem;
 	QFileInfo fileInfo(m_qsFileName);
 	QString qsName;
 	
 	qsName = QString ("Movie Object");
 
-	pButtonItem = new QListViewItem(pParentItem, qsName, fileInfo.fileName());
+	pButtonItem = new StructureItem(this, pParentItem, qsName, fileInfo.fileName());
 	pButtonItem->setExpandable (TRUE);
 
 	ImageObject initialValues;
 	// And finally we create the modifiers info ...
-	if ( !(	(manipulator().fRotate     == initialValues.manipulator().fRotate) &&
-			(manipulator().fShearX       == initialValues.manipulator().fShearX) &&
-			(manipulator().fShearY       == initialValues.manipulator().fShearY) &&
-			(manipulator().fZoom         == initialValues.manipulator().fZoom)   &&
-			(manipulator().fBrightness   == initialValues.manipulator().fBrightness) &&
-			(manipulator().fTransparency == initialValues.manipulator().fTransparency) &&
-			(manipulator().fRed          == initialValues.manipulator().fRed)    &&
-			(manipulator().fGreen        == initialValues.manipulator().fGreen)  &&
-			(manipulator().fBlue         == initialValues.manipulator().fBlue)
-			) )	{
-		pModifierItem = new QListViewItem(pButtonItem, QString ("Modifiers"), NULL);
-		pButtonItem->setExpandable (TRUE);
+	manipulator().createStructure (pButtonItem);
 
-		if ((manipulator().fRed        != initialValues.manipulator().fRed)   ||
-			(manipulator().fGreen      != initialValues.manipulator().fGreen) ||
-			(manipulator().fBlue       != initialValues.manipulator().fBlue) )
-			new QListViewItem(pModifierItem, QString ("Color Adjust"),
-				QString ("%1, %2, %3").arg(manipulator().fRed).arg(manipulator().fGreen).arg(manipulator().fBlue));
-		if (manipulator().fBrightness  != initialValues.manipulator().fBrightness)
-			new QListViewItem(pModifierItem, QString ("Brightness"),
-				QString ("%1").arg(manipulator().fBrightness));
-		if (manipulator().fTransparency  != initialValues.manipulator().fTransparency)
-			new QListViewItem(pModifierItem, QString ("Transparency"),
-				QString ("%1").arg(manipulator().fTransparency));
-		if ((manipulator().fShearX  != initialValues.manipulator().fShearX) ||
-			(manipulator().fShearY  != initialValues.manipulator().fShearY)  )
-			new QListViewItem(pModifierItem, QString ("Shear (x, y)"),
-				QString ("%1, %2").arg(manipulator().fShearX).arg(manipulator().fShearY));
-		if (manipulator().fZoom  != initialValues.manipulator().fZoom)
-			new QListViewItem(pModifierItem, QString ("Zoom"),
-				QString ("%1").arg(manipulator().fZoom));
-		if (manipulator().fRotate  != initialValues.manipulator().fRotate)
-			new QListViewItem(pModifierItem, QString ("Rotate"),
-				QString ("%1 deg").arg(manipulator().fRotate));
-	}
-
-	new QListViewItem(pButtonItem, QString ("Geometry"),
+	new StructureItem(this, pButtonItem, QString ("Geometry"),
 		QString ("%1, %2, %3, %4").
 		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
 
-	new QListViewItem(pButtonItem, QString ("Duration"), m_timeDuration.toString ());
-	new QListViewItem(pButtonItem, QString ("Offset"),   m_timeOffset.toString   ());
-
+	new StructureItem(this, pButtonItem, QString ("Duration"), m_timeDuration.toString ());
+	new StructureItem(this, pButtonItem, QString ("Offset"),   m_timeOffset.toString   ());
 }
 
 MenuObject *MovieObject::clone()
@@ -661,11 +548,10 @@ void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int
 {
 	QString qsFullPath, qsFileName, qsMenuName;
 	int  iCurrentClipFile;
-//	uint t;
 
 	// Okay first step is get the fileName of the frame
 	qsMenuName = dvdMenu()->getInterface()->qsMenuName;
-	QFileInfo fileInfo (fileName());
+//	QFileInfo fileInfo (fileName());
 //	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(fileInfo.fileName ());
 	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(extractionPath());
 	QDir theDir (qsFullPath);
@@ -674,12 +560,11 @@ void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int
 //	// Next is to set the AnimationAttributes
 //	for (t=0;t<m_listAnimationAttributes.count();t++)
 //		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
-//printf ("<%ld>X1=<%d> Y1=<%d> trans=<%03f>\n", iRenderFrameNumber, m_rect.x(), m_rect.y(), m_imageManipulator.fTransparency);
 
 	// So we have the full list of the frames, now we pick the appropriate frame ...
 	iCurrentClipFile = (int)((float)theDir.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);
 	qsFileName = QString ("%1/%2").arg(qsFullPath).arg(theDir[iCurrentClipFile]);
-printf ("MovieObject::drawContents <%s> <%s> <%d> <%d>\n", (const char *)qsFileName, (const char *)qsFileName, theDir.count(), iCurrentClipFile);
+	//printf ("MovieObject::drawContents <%s> <%s> <%d> <%d>\n", (const char *)qsFileName, (const char *)qsFileName, theDir.count(), iCurrentClipFile);
 	loadPixmap (qsFileName);
 	//then we call 
 	ImageObject::drawContents(pPainter, iRenderFrameNumber, iTotalFramesToRender);
