@@ -1,16 +1,20 @@
 /****************************************************************************
-** ImagePreview class
+** ObjectCollection class 
 **
 ** Created: Tue Feb 02 22:06:51 2004
 **      by: Varol Okan using Kate
 **
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
+** This class is the encapsulation of the ObjectCollection.
+**
+** The ObjectCollection is not yet finished. It is intended to hold a list
+** of MenuObject's which are linked to each other. Meaning if you move 
+** the collection each member of it will move the same extend.
+**
+** Another use is to create a template which will fit the images/movies
+** into a fixed scheme.
 **
 ****************************************************************************/
 #include <qpopupmenu.h>
-#include <qlistview.h>
 #include <qpainter.h>
 #include <qwmatrix.h>
 #include <qpixmap.h>
@@ -20,6 +24,7 @@
 #include "menuobject.h"
 #include "buttonobject.h"
 #include "objectcollection.h"
+#include "structuretoolbar.h"
 
 ObjectCollection::ObjectCollection (QWidget *pParent)
 	: MenuObject (pParent)
@@ -102,35 +107,7 @@ bool ObjectCollection::mousePressEvent (QMouseEvent *pEvent)
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
 		QPoint globalPos = pEvent->globalPos();
-
-		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
-		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
-		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
-		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
-		pStackMenu->popup(globalPos, 1);
-
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = new QPopupMenu(m_pParent);
-		m_pContextMenu->insertItem ( tr ("Modify ..."), this, SLOT(slotEdit()));
-		m_pContextMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( tr ("Add Frame") , this, SLOT(slotAddFrame()));
-		m_pContextMenu->insertItem ( tr ("Add Text")  , this, SLOT(slotAddImage()));
-		m_pContextMenu->insertItem ( tr ("Add Image") , this, SLOT(slotAddImage()));
-		m_pContextMenu->insertItem ( tr ("Add Movie") , this, SLOT(slotAddImage()));
-		m_pContextMenu->insertSeparator();
-		m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
-		m_pContextMenu->exec(pEvent->globalPos(), 4);
-		
-		delete pStackMenu;
-		if (m_pContextMenu)
-			delete m_pContextMenu;
-		m_pContextMenu = NULL;
-		// Here we mark that the user called a menu item thus we don't want the
-		// base classes to continue with the mouse event
-//		if (iReturn != -1)
-			return true;
+		return createContextMenu ( globalPos );
 	}
 	else
 		m_bDrawRect = true;
@@ -158,13 +135,46 @@ bool ObjectCollection::writeProjectFile (QDomElement &)
 	return false;
 }
 
+bool ObjectCollection::createContextMenu (QPoint globalPos)
+{
+        QPoint globalPos2 = globalPos;
+	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	pStackMenu->popup(globalPos, 1);
+
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = new QPopupMenu(m_pParent);
+	m_pContextMenu->insertItem ( tr ("Modify ..."), this, SLOT(slotEdit()));
+	m_pContextMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Add Frame") , this, SLOT(slotAddFrame()));
+	m_pContextMenu->insertItem ( tr ("Add Text")  , this, SLOT(slotAddImage()));
+	m_pContextMenu->insertItem ( tr ("Add Image") , this, SLOT(slotAddImage()));
+	m_pContextMenu->insertItem ( tr ("Add Movie") , this, SLOT(slotAddImage()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
+	m_pContextMenu->exec(globalPos2, 4);
+		
+	delete pStackMenu;
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = NULL;
+	// Here we mark that the user called a menu item thus we don't want the
+	// base classes to continue with the mouse event
+//	if (iReturn != -1)
+		return true;
+}
+
 void ObjectCollection::createStructure (QListViewItem *pParentItem)
 {
 	// Creating teh ListView structure of this Button.
-	QListViewItem *pCollectionItem;
+	StructureItem *pCollectionItem;
 	QString qsCollection = tr("Collection of %1").arg(m_listObjectCollection.count());
 	
-	pCollectionItem = new QListViewItem(pParentItem, m_qsName, qsCollection);
+	pCollectionItem = new StructureItem(this, pParentItem, m_qsName, qsCollection);
 	pCollectionItem->setExpandable (TRUE);
 
 	uint t;
