@@ -1,5 +1,5 @@
 /****************************************************************************
-** Interface to the GUI.
+3** Interface to the GUI.
 **
 ** Created: Sun Dec 14 12:09:08 2003
 **      by: Varol Okan using kate editor
@@ -30,13 +30,19 @@ class ColorToolBar;
 class SourceToolBar;
 class StructureToolBar;
 class SourceFileEntry;
+class SourceFileInfo;
+class SubtitlesGui;
 class DVDMenu;
 class MediaInterface;
 class MediaInfo;
 class uiDialogRenderPreview;
 class DialogExecute;
 class TemplateWizard;
+class CXmlDVDAuthor;
+class CXmlSpumux;
+
 #define DVDAUTHOR_XML "dvdauthor.xml"
+#define SUBTITLES_TAB "Subtitles"
 
 #include "utils.h"
 #include "dragndropcontainer.h"
@@ -66,6 +72,7 @@ public slots:
 	virtual void helpContents();
 	virtual void helpAbout();
 
+	virtual void polish                       ();
 	virtual void slotAutosave                 ();
 	virtual void slotChangeLanguage        (int);
 	virtual void slotVisibleRegion        (bool);
@@ -80,6 +87,8 @@ public slots:
 	virtual void slotCreateSVCD               ();
 	virtual void slotCreateVCD                ();
 	virtual void slotAddSubMenu               ();
+	virtual void slotAddFiles                 ();
+	virtual void slotAddDirectory             ();
 	virtual void slotAddFromTemplate          ();
 	virtual void slotFeedback                 ();
 	virtual void slotTabChanged      (QWidget *);
@@ -95,17 +104,17 @@ public slots:
 	virtual void slotRenderMenu        (QString);
 	virtual void slotChangeStyle(const QString&);
 	virtual void slotCalculateSize            ();
-//	virtual void slotSetSlideshowEntry (QString);
-//	virtual void slotSlideshowDone     (QString);
+	virtual void slotImportKino               ();
+	virtual void slotImportDvdauthor          ();
 signals:
 	void signalVisibleRegion (bool);
 
 public:
-	void postInit             ();
-	void addDVDMenu           (DVDMenu *, bool b=false);
-	void createDvdauthorXml   (QString &);
-	void returnFromRenderMenu ();
-	bool checkForNewProject   ();
+	void fileOpen             ( QString );
+	void postInit             ( bool );
+	void addDVDMenu           ( DVDMenu *, bool b=false );
+	void returnFromRenderMenu ( );
+	bool checkForNewProject   ( );
 
 	int  getFreeSourceSlot();
 	void addMovieList (QStringList &, QString *p=NULL);
@@ -122,39 +131,42 @@ public:
 	MediaInfo *getMediaInfo ();
 	DragNDropContainer *getDragNDropContainer();
 	
-	DVDMenu         *getCurrentSubMenu  ();
+	DVDMenu         *getCurrentSubMenu  ( );
 	DVDMenu         *getSubMenuByName(QString);
-	QValueList<DVDMenu *> &getSubMenus  ();
-	QString &currentPath   ();
+	DVDMenu         *getVMGMenu         ( );
+	QValueList<DVDMenu *> &getSubMenus  ( );
+	void    importDvdauthor     (  void * );
 
 	QString getUniqueMenuTitle (QString, int i=0, DVDMenu *p=NULL);
-	QString getImageFilter ();
-	QString getMovieFilter ();
-	QString getSoundFilter ();
+	QString getImageFilter      ( );
+	QString getMovieFilter      ( );
+	QString getSoundFilter      ( );
 
 private: 	// Private functions ...
-	void initMe   ();
-	bool cleanUp  ();
-	void LoadIni  ();
-	void SaveIni  ();
-	void newWizard();
-	void fileOpen(QString);
-	void buildHistoryEntries           ();
-	void updateHistoryPix             ( );
-	void initLanguages              (   );
-	void initStyles               (     );
-	void addHistory             (QString);
-	bool readProjectFile     (QDomNode &);
-	bool writeProjectFile (QDomElement &);
-	void setAutosave      ( bool b=false);
-	void createTempDirStructure ();
-	void createDvdauthorXml ();
-	void createMenuXml ();
-	void createMenuXml (DVDMenu *pMenu);
-	void createDVD ();
-	bool checkHealth ();
-	QString getTempFile        (QString);
-	QString getButtonAction    (ButtonObject *, int, bool b=false);
+	void initMe                 ( );
+	bool cleanUp                ( );
+	void LoadIni                ( );
+	void SaveIni                ( );
+	void newWizard              ( );
+	void buildHistoryEntries    ( );
+	void updateHistoryPix       (  );
+	void initLanguages          (    );
+	void initStyles             (      );
+	void initSubtitlesTab       (        );
+	void addHistory             ( QString  );
+	bool readProjectFile        ( QDomNode & );
+	bool writeProjectFile       ( QDomElement &);
+	void setAutosave            ( bool b=false   );
+	void renderSubtitles        ( SourceFileInfo * );
+	QRect getSubtitlesRect      ( SourceFileInfo * );
+	bool buildFromDvdauthorXML  ( CXmlDVDAuthor *, QValueList<CXmlSpumux *> & );
+	void createTempDirStructure ( );
+	void createDvdauthorXml     ( );
+	void createSubtitlesXml     ( );
+	void createMenuXml          ( );
+	void createDVD              ( );
+	bool checkHealth            ( );
+	QString getTempFile         (QString);
 
 private:
 	// Here we store the path to the different tools required.
@@ -169,13 +181,16 @@ private:
 	int                     m_iMaxHistoryFiles;
 	int                     m_iAutosave;	// Autosave every x seconds ...
 	QString                 m_qsStyle;
+	QString                 m_qsLanguage;
 	QTimer                 *m_pTimerAutosave;
+	bool                    m_bAutosaving;
 	
 	ColorToolBar           *m_pColorToolbar;
 	SourceToolBar          *m_pSourceToolbar;
 	StructureToolBar       *m_pStructureToolbar;
+	SubtitlesGui           *m_pSubtitlesGui;
 	QPopupMenu             *m_pMenuHistory;
-		bool m_bModified;
+	bool                    m_bModified;
 	QTranslator            *m_pTranslator;
 	QPopupMenu             *m_pLanguagePopup;
 	QPopupMenu             *m_pStylesPopup;
