@@ -1429,7 +1429,7 @@ bool QXineWidget::GetAutoplayPluginMrl(const QString& plugin, QStringList& list)
 
 void QXineWidget::slotSetVolume(int vol)
 {
-  xine_set_param(xineStream, XINE_PARAM_AUDIO_VOLUME, -vol);
+  xine_set_param(xineStream, XINE_PARAM_AUDIO_VOLUME, vol);
 }
 
 
@@ -1745,7 +1745,7 @@ void QXineWidget::slotGetPosition()
   { 
     case PERCENT_PLAY:
     {
-      perc = pos/655,35;
+      perc = pos/65535.0;
       time = (int) (perc);
       if ( (time < 0) || (time > 100) )
       {
@@ -1769,6 +1769,7 @@ void QXineWidget::slotGetPosition()
         return;
       } 
       emit signalNewPosition( pos, msToTimeString(time) );
+      emit signalNewPosition( (long)time );
       break;
     }
   }
