@@ -126,6 +126,7 @@ void XineInfo::queryValues ()
 		else
 			m_qsRatio = QString ("<%1>").arg(iReturn);
 */
+
 		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_RATIO);
 		if (iReturn == 1)
 			m_qsRatio = QString ("1:1");
@@ -140,7 +141,7 @@ void XineInfo::queryValues ()
 		else if (iReturn == (int)(29.0/9.0*10000))
 			m_qsRatio = QString ("29:9");
 		else
-			m_qsRatio = QString ("<%1>").arg((float)iReturn/10000);
+			m_qsRatio = QString ("%1:1").arg((float)iReturn/10000);
 
 		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_FOURCC);
 		if (iReturn)
