@@ -152,7 +152,7 @@ MediaInterface *MediaCreator::createPreferredWidget(QWidget *pParent, const char
 	else if (m_qsPreferredEngine == QString("VLCWidget"))
 		pNewInterface = createVLCWidget (pParent, pName, pExistingEngine);
 	else if (m_qsPreferredEngine == QString("DummyWidget"))
-		pNewInterface = pNewInterface = (MediaInterface *) new DummyWidget (pParent, "DummyWidget", pExistingEngine);
+	        pNewInterface = (MediaInterface *) new DummyWidget (pParent, "DummyWidget", pExistingEngine);
 	if (!pNewInterface)	{
 		printf ("\nError could not create preferred MediaEngine.\nCreate Dummy MediaWidget with no functionality\n\n");
 		pNewInterface = (MediaInterface *) new DummyWidget (pParent, "DummyWidget", pExistingEngine);
@@ -248,6 +248,12 @@ void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, QString &qsFi
 	MediaCreator::pPreviewObject->append (pNewJob);
 }
 
+void MediaCreator::unregisterFromMediaScanner (QObject *pObject)
+{
+	if (MediaCreator::pPreviewObject)
+		MediaCreator::pPreviewObject->remove (pObject);
+}
+
 void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, SourceFileInfo *pSourceFileInfo, int iSecondsOffset)
 {
 	// THe first action to take is a sanity check ...
