@@ -1,5 +1,5 @@
 /****************************************************************************
-** Implementation of class XineInfo
+** Implementation of class MediaInfo
 **
 ** Created: Tue Nov 9 07:53:05 2004
 **      by: Varol Okan using the kate editor
@@ -10,29 +10,14 @@
 ****************************************************************************/
 
 #include <qfileinfo.h>
+#include <qobject.h>
+//#include <qapplication.h>
+//#include <qmessagebox.h>
+//#include <qdir.h>
 
 #include "../global.h"
 #include "mediainfo.h"
 
-
-/****************************************************************************
-** CreateMediaEngine class
-**
-** This class will create a MediaEngine (xine, MPlayer, or VLC) object 
-** in a background task.
-**
-** Usually to create and initialize a Media - object takes a few 
-** seconds. This is especially disturbing if you start a Dialog, or an
-** application and it takes too long to start up.
-**
-** With this class the object will be created in the background and 
-** initialized before returning it to its creator object.
-**
-*****************************************************************************/
-#include <qapplication.h>
-#include <qmessagebox.h>
-#include <qdir.h>
-
 MediaInfo::MediaInfo (void *pMediaEngine)
 {
 	m_pMediaEngine = NULL;
@@ -81,10 +66,8 @@ void MediaInfo::setFileName (QString qsStream)
 	// Next we check if the file exists ...
 	QFileInfo fileInfo (qsStream);
 	if (!fileInfo.exists())	{
-		wLOG ( ("File not found %s", (const char *)qsStream));
-//		Global::logObject ()->log ("%s:::%s:%d > File not found %s.", 
-//			__FILE__, __FUNCTION__,__LINE__, (const char *)qsStream);
-		return;
+	  wLOG ("File not found %s", (const char *)qsStream);
+	  return;
 	}
 
 	// Set the file size ...
@@ -160,7 +143,42 @@ QString MediaInfo::getLengthString ()
 
 QString MediaInfo::getRatio ()
 {
-	return m_qsRatio;
+  // here we process a bit if neccesary ...
+  // checking for something like 1.3333:1
+  if  ( ( m_qsRatio == "1:1" ) ||
+	( m_qsRatio == "4:3" ) ||
+	( m_qsRatio == "16:9" ) ||
+	( m_qsRatio == "2.21:1" ) )
+    return m_qsRatio;
+
+  QString qsRatio = m_qsRatio;
+  int iPos = qsRatio.find ( ":" );
+  float fValue;
+
+  if ( iPos ) {
+    QString qsVal1 = qsRatio.left  ( iPos );
+    QString qsVal2 = qsRatio.right ( qsRatio.length () - iPos-1 );
+    float fVal1 = qsVal1.toFloat ();
+    float fVal2 = qsVal2.toFloat ();
+    if ( fVal2 != 0.0 )
+      fValue = fVal1 / fVal2;
+  }
+  else 
+    fValue = qsRatio.toFloat ();
+
+  // Okay for sanity check ...
+  if ( fValue != 0.0 ) {
+    if ( ( fValue > 0.9 ) && ( fValue < 1.1 ) )
+      qsRatio= "1:1";
+    else if ( ( fValue > 1.23 ) && ( fValue < 1.43 ) )
+      qsRatio = "4:3";
+    else if ( ( fValue > 1.68 ) && ( fValue < 1.88 ) )
+      qsRatio = "16:9";
+    else if ( ( fValue > 2.11 ) && ( fValue < 2.31 ) )
+      qsRatio = "2.21:1";
+  }
+
+  return qsRatio;
 }
 
 int MediaInfo::getBits ()
