@@ -11,6 +11,7 @@
 #include <qfiledialog.h>
 #include <qmessagebox.h>
 #include <qpopupmenu.h>
+#include <qtoolbar.h>
 
 #include "xml_slideshow.h"
 #include "dialogfilter.h"
@@ -19,45 +20,51 @@
 
 void CSlideDialog::slotSelectImages()
 {
-	QString qsFilter ("*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP");
-	QStringList slideshowFiles = QFileDialog::getOpenFileNames(tr("Images for Slideshow (")+qsFilter+QString(")"), "./",
-                            this, tr("open files dialog Select one or more files to open" ));
-	if (slideshowFiles.isEmpty())
-		return;
-	// Here we check if there are already images in the structure ...
-	if (m_Slideshow.count() > 0)	{
-		// Ask if slideshow files should be appended or replace current selection.
-		if (QMessageBox::warning (NULL, tr ("List not empty!"),
-			tr ("Do you want do add the images to the existing list ?\n"),
-				QMessageBox::Yes, QMessageBox::No) == QMessageBox::No)	{
-					m_Slideshow.clear();		// The full entries
-					m_slideshowFiles.clear ();	// the short fileNames (without directories)
-					m_pListTable->clear ();		// the listTable widget.
-			}
-	}
+  QString qsFilter ("*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP");
+  QStringList slideshowFiles = QFileDialog::getOpenFileNames(tr("Images for Slideshow (")+qsFilter+QString(")"), "./",
+							     this, tr("open files dialog Select one or more files to open" ));
+  if (slideshowFiles.isEmpty())
+    return;
+  // Here we check if there are already images in the structure ...
+  if (m_Slideshow.count() > 0)	{
+    // Ask if slideshow files should be appended or replace current selection.
+    if (QMessageBox::warning (NULL, tr ("List not empty!"),
+			      tr ("Do you want do add the images to the existing list ?\n"),
+			      QMessageBox::Yes, QMessageBox::No) == QMessageBox::No)	{
+      m_Slideshow.clear      ();  // The full entries
+      m_slideshowFiles.clear ();  // the short fileNames (without directories)
+      m_pListTable->clear    ();  // the listTable widget.
+    }
+  }
+  
+  QString fileName;
+  QFileInfo fileInfo;
+  for (uint t=0;t<slideshowFiles.count();t++)	{
+    CXmlSlideshow::img_struct *pImg = m_Slideshow.addImg();
+    pImg->src=slideshowFiles[t];
+//    if (m_pCheckBackground->isChecked () )  {
+//	ImageManipulator *pImgMan   = new ImageManipulator;
+//	pImgMan->bShowBackground    = m_pCheckBackground->isChecked ();
+//	pImgMan->backgroundFileName = m_Slideshow.background;
+//	pImg   ->pModifier          = pImgMan;
+//    }
+    // And here we add the filenames to the table.
+    fileInfo = QFileInfo (slideshowFiles[t]);
+    fileName = fileInfo.fileName ();
+    m_pListTable->insertItem (fileName);
+  }
+  m_slideshowFiles += slideshowFiles;
+  // And finally, if there are files selected, then enable the Ok - button.
+  if (m_slideshowFiles.count())	{
+    m_pButtonOk->setEnabled(true);
+    m_pButtonFilter->setEnabled(true);
+    m_pButtonExport->setEnabled(true);
+  }
 
-	QString fileName;
-	QFileInfo fileInfo;
-	for (uint t=0;t<slideshowFiles.count();t++)	{
-		CXmlSlideshow::img_struct *pImg = m_Slideshow.addImg();
-		pImg->src=slideshowFiles[t];
-		// And here we add the filenames to the table.
-		fileInfo = QFileInfo (slideshowFiles[t]);
-		fileName = fileInfo.fileName ();
-		m_pListTable->insertItem (fileName);
-	}
-	m_slideshowFiles += slideshowFiles;
-	// And finally, if there are files selected, then enable the Ok - button.
-	if (m_slideshowFiles.count())	{
-		m_pButtonOk->setEnabled(true);
-		m_pButtonFilter->setEnabled(true);
-		m_pButtonExport->setEnabled(true);
-	}
-
-	m_pListTable->setSelected (m_pListTable->numRows()-1, TRUE);
-	previewImage(m_pListTable->numRows()-1);
-	m_bModified = true;
-	slotUpdateListInfo ();
+  m_pListTable->setSelected (m_pListTable->numRows()-1, TRUE);
+  previewImage(m_pListTable->numRows()-1);
+  m_bModified = true;
+  slotUpdateListInfo ();
 }
 
 void CSlideDialog::slotChooseBackground()
@@ -93,6 +100,7 @@ void CSlideDialog::slotExport()
 	QString qsExportSlideshow = QFileDialog::getSaveFileName("./", tr("Slideshow Files (*.slide)"), this, tr("Slideshow selection Dialog"), tr("Specify slideshow name."));
 	if (qsExportSlideshow.isNull())
 		return;
+	previewImage(m_pListTable->currentItem());
 	QFileInfo fileInfo (qsExportSlideshow);
 	if (fileInfo.extension(FALSE).isEmpty())	// Indication there is no extension ...
 		qsExportSlideshow += QString (".slide");
@@ -101,7 +109,7 @@ void CSlideDialog::slotExport()
 
 	// Here we handle the check if background should be used ...
 	QString qsTemp = m_Slideshow.background;
-	if (m_pCheckBackground->isChecked ())
+	if ( ! m_pCheckBackground->isChecked () )
 		m_Slideshow.background = QString ("");
 	if (m_pCheckFilter->isChecked())	{
 		CXmlSlideshow theSlideshow = createFilterSlideshow ();	// Here we insert additionally somefilters and save it.
@@ -202,6 +210,7 @@ void CSlideDialog::slotOk()
 		m_qsSlideshowFileName= m_qsTempPath + QString ("/slideshow.xml");
 
 	CXmlSlideshow execSlideshow;
+	previewImage (m_pListTable->currentItem());
 	m_Slideshow.delay = m_pEditDelay->text().toInt();
 	if (m_pCheckFilter->isChecked())
 		execSlideshow = createFilterSlideshow ();	// Here we insert additionally somefilters and save it.
@@ -215,15 +224,12 @@ void CSlideDialog::slotOk()
 	pDialog->setXmlSlideshow (&execSlideshow, m_qsTempPath);
 
 	// If this is called from DVDAuthor then we should connect to the application.
-	// TODO: 
-	// Check why the callback is not called when one oif this signals is emmited ...
-//printf ("CSlideDialog::slotOk <%x>\n", (void *)m_pSourceToolBar);
 	if (m_pSourceToolBar)	{	// Note that this OK Button only leads to the next dialog
-//printf ("  CSlideDialog::slotOk Connecting setSlideshowEntry / slideshowDone ...\n");
+	  QToolBar *pSourceToolbar = (QToolBar *)m_pSourceToolBar;
 		connect ((QObject *)pDialog,     SIGNAL (signalSetSlideshowEntry(QString)), 
-			(QObject *)m_pSourceToolBar, SLOT   (slotAddSlideshow       (QString)));
-		connect ((QObject *)pDialog,     SIGNAL (signalSlideshowDone    (QString)), 
-			(QObject *)m_pSourceToolBar, SLOT   (slotSlideshowDone      (QString)));
+			pSourceToolbar, SLOT   (slotAddSlideshow       (QString)));
+		connect ((QObject *)pDialog,     SIGNAL (signalSlideshowDone    (QString, QString)), 
+			 pSourceToolbar, SLOT   (slotSlideshowDone      (QString, QString)));
 	}
 
 //	int iRet = pDialog->exec();
@@ -239,16 +245,17 @@ void CSlideDialog::slotCancel()
 
 void CSlideDialog::slotHelp()
 {
-	// TestTestTestTestTestTestTestTestTestTest
-/*
-	// first we set up things so we don't need to click too often.
-	QString qsSlideshowFileName("/tmp/slideshow.slide");
-	m_Slideshow.readXml (qsSlideshowFileName);
-	m_pPreview->setImage (m_Slideshow.getImg(0));
-	m_pPreview->setBackground (m_Slideshow.background);
-	// This will finally open the edit dialog.
-	m_pPreview->slotEditImage ();
-*/
+  QMessageBox::information (NULL, tr ("Info :"),
+    tr ("[Use Background]  Allows you to set a background image. You can simply use \n"
+	"   a one colored image to improve the Look of your slideshow.\n"
+	"   Other nice backgrounds are landscapes, skies, ocean etc.\n\n"
+	"[General delay in seconds] Is she time the images will be displayed.\n\n"
+	"[Include Filter]  This will add filter between images (crossfading).\n"
+	"   You can specify the time in seconds for the filter to run through.\n"
+	"   Note: You can fine tune the settings afterwards when you press [Continue >>>].\n\n"
+	"[Continue >>>]  This will open the filter dialog to modify the global settings \n"
+	"   on a per image/filter basis.\n"
+	), QMessageBox::Ok ,  QMessageBox::NoButton);
 }
 
 void CSlideDialog::slotApplyFilter()
@@ -263,6 +270,7 @@ void CSlideDialog::slotApplyFilter()
 	}
 	else
 		m_Slideshow.filter_delay = 0;
+
 	pDialog->setImages(&m_Slideshow);
 	pDialog->show();
 }
@@ -326,7 +334,7 @@ void CSlideDialog::slotUpdateListInfo()
 	iSecs   = (int)((double)iTotalTime) - 60*iMins - 3600*iHours;
 	// Format  00:00:00.000
 	m_pLabelNrOfImages->setText(tr ("<p align=\"center\">%1 Images</P>").arg(m_Slideshow.countImg()));
-//	qsTimeString.sprintf ("<p align=\"center\">%1 = %02d:%02d:%02d.000</p>", iHours, iMins, iSecs);
+//	qsTimeString.sprintf  ("<p align=\"center\">%1 = %02d:%02d:%02d.000</p>", iHours, iMins, iSecs);
 	qsStartString = QString ("<p align=\"center\">" + tr("Duration"));
 	qsTimeString.sprintf (" = %02d:%02d:%02d.000</p>", iHours, iMins, iSecs);
 	m_pLabelDuration->setText(qsStartString + qsTimeString);
@@ -342,7 +350,10 @@ void CSlideDialog::initMe(void *pSourceToolBar, QString qsTempPath)
 	// Store the pointer for the signalSlideshowDone locally.
 	m_pSourceToolBar = pSourceToolBar;
 	m_qsTempPath = qsTempPath;
-	m_pPreview = new ImagePreview( m_pFramePreview, "m_pPreview" );
+	m_pPreview = new ImagePreview( m_pFramePreview );
+	if ( ! m_pPreview )
+		return;
+
 	m_pPreview->setMinimumSize( QSize( 150, 150 ) );
 	m_pPreview->setMaximumSize( QSize( 250, 32767 ) );
 
@@ -351,6 +362,7 @@ void CSlideDialog::initMe(void *pSourceToolBar, QString qsTempPath)
 	m_pButtonBackground->setEnabled(false);
 	m_pButtonFilter->setEnabled(false);
 	m_pButtonExport->setEnabled(false);
+	m_pPreview->setPaletteBackgroundPixmap ( QPixmap::fromMimeSource ("checkered.png") );
 }
 
 void CSlideDialog::previewImage(int iItem)
@@ -359,7 +371,10 @@ void CSlideDialog::previewImage(int iItem)
 	pImg = m_Slideshow.getImg (iItem);
 	if (pImg == NULL)
 		return;
-	m_pPreview->setBackground(m_Slideshow.background, false);	// false = no refresh, done int setImage
+
+	if ( m_pCheckBackground->isChecked() )
+		m_pPreview->setBackground(m_Slideshow.background, false);	// false = no refresh, done int setImage
+
 	m_pPreview->setImage (pImg);
 }
 
