@@ -100,6 +100,13 @@ void ImageLine::mousePressEvent (QMouseEvent *pEvent)
 	pMenu->insertItem ( tr ("Rotate Free ..."), this, SLOT(slotRotateFree()));
 	pMenu->insertSeparator ();
 	pMenu->insertItem ( tr ("Edit Image ..."), this, SLOT(slotEditImage()));
+	/**
+	 * F.J. Cruz - neke
+	 *18/10/04
+	 **/
+	pMenu->insertSeparator();
+	pMenu->insertItem( tr ("Add Subtittle..."), this, SLOT(slotInsertSubtittle()));
+	
 	pMenu->exec(pEvent->globalPos());
 }
 
@@ -132,6 +139,18 @@ int ImageLine::getImageByPos (int iMouseX)
 		return -1;
 	return t;
 }
+/**
+ * F.J.Cruz
+ * 18/10/04
+ **/
+void ImageLine::slotInsertSubtittle()
+{
+	CXmlSlideshow::time_object *pTimeObject = m_pSlideshow->getTimeObject(m_iHotObject);
+	if (pTimeObject->node_name != "img")
+		return;
+	CXmlSlideshow::filter_struct *pImage = (CXmlSlideshow::filter_struct *)pTimeObject;
+	pImage->subtitle = QInputDialog::getText (tr("Please type the subtitle."), tr ("Subtitle : "), QLineEdit::Normal, tr("My Subtitle"));
+}
 
 void ImageLine::rotate (float fRot, bool bClear)
 {
@@ -336,10 +355,12 @@ void ImageLine::createFrames()
 	float fTotalTime = m_pCurrentRange->fEndTime -  m_pCurrentRange->fStartTime;
 
 	// Because this can take quite some time, we will draw the outlines, and the filter first, and display them.
+	QBrush blackBrush (QColor (0, 0, 0));
 	QBrush theBrush (QColor (128, 128, 128), Qt::Dense6Pattern);
 	float fStartX, fWidthX;
 	m_pCurrentRange->listX.clear ();
 
+	thePainter.fillRect (0, 0, m_pCurrentRange->pixmapRangeThumbs.width(),  m_pCurrentRange->pixmapRangeThumbs.height(), blackBrush);
 	for (t=m_pCurrentRange->iStartObject;t<m_pCurrentRange->iEndObject;t++)	{
 		pTimeObject = m_pSlideshow->getTimeObject (t);
 		if (pTimeObject != NULL)	{
