@@ -22,30 +22,19 @@
 #include "imagepreview.h"
 #include "dialogimage.h"
 
-ImagePreview::ImagePreview (QWidget * parent, const char * name, WFlags f )
-	: QLabel (parent, name, f) // |WRepaintNoErase)
+ImagePreview::ImagePreview (QWidget *pParent, const char * name, WFlags f )
+	: QLabel (pParent, name, f) // |WRepaintNoErase)
 {
 	setScaledContents( TRUE );
-	m_iStartX = 0;
-	m_iStartY = 0;
-	m_iXRes = 720;
-	m_iYRes = 480;
-	m_iTransformationMode = 0;
-	m_fAspectRatio = 4.0 / 3.0;	// Letterbox
-	m_fShearX = 0.0;
-	m_fShearY = 0.0;
-	m_fZoom = 1.0;
-	m_fStartZoom = 1.0;
-	m_fRed = 1.0;
-	m_fGreen = 1.0;
-	m_fBlue = 1.0;
-	m_fBrightness = 0.0;
-	m_bShowBackground = true;
-	m_bFastPreview = false;
-	m_pImage = NULL;
-	m_bActiveCursor = false;
+	m_fStartZoom         = 1.0;
+	m_bFastPreview       = false; 
+	m_pImage             = NULL;
+	m_bActiveCursor      = false;
 	m_bNeedToAdjustColor = false;
-	show();
+	m_bShowBackground    = false;
+
+	if ( pParent )
+	  show();
 }
 
 ImagePreview::~ImagePreview ()
@@ -56,48 +45,52 @@ ImagePreview::~ImagePreview ()
 void ImagePreview::setResolution (int iXRes, int iYRes)
 {
 	// Okay for tomorrow ...
-	// resolution is the size of the image, where as
+	// resolution is the size of the image, whereas
 	// aspect ratio is the ratio to be displayed.
-	// Thus resize should follow aspwct ration and NOT resolutions.
+	// Thus resize should follow aspect ratio and NOT resolutions.
 
 	// aspect ratio, E.g. letterbox 4:3, widescreen 16:4 etc.
-	m_iXRes = iXRes;
-	m_iYRes = iYRes;
+	m_manipulator.iXRes = iXRes;
+	m_manipulator.iYRes = iYRes;
 	float fAspectRatio = (float)((float) iYRes/(float)iXRes);
 	resize (width(), (int)(width () * fAspectRatio));
 }
 
-void ImagePreview::setBackground (QString &fileName, bool bRefresh)
+void ImagePreview::setBackground ( QString &fileName, bool bRefresh )
 {
-	m_backgroundFileName = fileName;
-	QPixmap background;
-	if ( (!m_backgroundFileName.isEmpty()) && (m_bShowBackground) && (!m_bFastPreview))	{
-		QImage theImage (m_backgroundFileName);
-		// Load image and check health of image.
-		if (theImage.isNull ())	{
-//			background = QPixmap (pixmap()->width(),pixmap()->height());
-			background = QPixmap (width(), height());
-			background.fill (QColor (0, 0, 0));
-		}
-		else
+  m_backgroundFileName = fileName;
+  QPixmap background;
+  m_bShowBackground = !(fileName.isEmpty());
+  if ( (m_bShowBackground) && (!m_bFastPreview) )	{
+    QImage theImage (m_backgroundFileName);
+    // Load image and check health of image.
+    if (theImage.isNull ())	{
+//    background = QPixmap (pixmap()->width(),pixmap()->height());
+      background = QPixmap (width(), height());
+      background.fill (QColor (0, 0, 0));
+    }
+    else
+      background.convertFromImage(theImage.smoothScale(width(), height()));
 // Crashes when no pixmap yet set ...
-//			background.convertFromImage(theImage.smoothScale(pixmap()->width(),pixmap()->height()));
-			background.convertFromImage(theImage.smoothScale(width(), height()));
-	}
-	else	{	// no background image, lets create a black, empty background ...
-//		background = QPixmap (pixmap()->width(),pixmap()->height());
-		background = QPixmap (width(), height());
-		background.fill (QColor (0, 0, 0));
-	}
-	m_background = background.convertToImage();
-	setFixedSize(m_background.width(), m_background.height());
-	// Before we go on we should calculate the correct m_iStartX, and m_iStartY
-	if (m_background.width() > m_image.width())
-		m_iStartX = (int)((m_background.width()-m_image.width())/2.0);
-	if (m_background.height() > m_image.height())
-		m_iStartY = (int)((m_background.height()-m_image.height())/2.0);
-	if (bRefresh)
-		rotate (0.0);
+//    background.convertFromImage(theImage.smoothScale(pixmap()->width(),pixmap()->height()));
+    setPixmap (background);
+  }
+  else	{	// no background image, lets create a black, empty background ...
+    //		background = QPixmap (pixmap()->width(),pixmap()->height());
+    background = QPixmap (width(), height());
+    background.fill (QColor (0, 0, 0));
+  }
+  m_background = background.convertToImage();
+  setFixedSize(m_background.width(), m_background.height());
+  // Before we go on we should calculate the correct m_iStartX, and m_iStartY
+  if ( (m_manipulator.fStartX == 0.0 ) && (m_manipulator.fStartY == 0.0) ) {
+    if (m_background.width() > m_image.width())
+      m_manipulator.fStartX = ((m_background.width()-m_image.width())/2.0)/m_background.width();
+    if (m_background.height() > m_image.height())
+      m_manipulator.fStartY = ((m_background.height()-m_image.height())/2.0)/m_background.height();
+  }
+  if (bRefresh)
+    rotate (0.0);
 }
 
 void ImagePreview::setBackground (QPixmap &pix, bool bRefresh)
@@ -119,25 +112,29 @@ void ImagePreview::setBackground (QPixmap &pix, bool bRefresh)
 		rotate (0.0);
 }
 
-void ImagePreview::setImage (QPixmap &theImage)
+void ImagePreview::setImage (QPixmap &theImage, ImageManipulator *pManipulator)
 {
 	m_image = theImage.convertToImage();
+	if ( pManipulator ) {  // This is called when we want to render the 
+	  // image (rotate, zoom etc) before we deliver it to dvd-slideshow.
+	  m_pImage = NULL; // To make sure ...
+	  m_manipulator = *pManipulator;  
+	  adjustColor ();
+	  refreshPreview ();
+	  return;
+	}
 	rotate (0.0, false);
 }
 
 void ImagePreview::setImage (CXmlSlideshow::img_struct *pImg)
 {
+        // before we change the image, we should connect the current 
+        // ImageManipulator to the current image struct.
+	getModifier ();
 	m_pImage = pImg;
-	m_fShearX = 0.0;
-	m_fShearY = 0.0;
-	m_fZoom = 1.0;
-	m_fRed = 1.0;
-	m_fGreen = 1.0;
-	m_fBlue = 1.0;
-	m_fBrightness = 0.0;
-	m_fTransparency = 0.0;
 	setModifier ();	// get the additional infos for this image
 	preloadImage();
+	centerImage ();
 	if (!pImg->src.isEmpty())
 		rotate (0.0, false);
 }
@@ -182,8 +179,8 @@ void ImagePreview::mouseMoveEvent (QMouseEvent *pEvent)
 	// this one we move the object regardless of the cursor beeing in or out.
 	if (m_bActiveCursor)	{
 		bActive = true;
-		m_iStartX += pEvent->pos().x() - m_currentMousePos.x();
-		m_iStartY += pEvent->pos().y() - m_currentMousePos.y();
+		m_manipulator.fStartX += (float)(pEvent->pos().x() - m_currentMousePos.x())/width ();
+		m_manipulator.fStartY += (float)(pEvent->pos().y() - m_currentMousePos.y())/height();
 		m_currentMousePos = pEvent->pos();
 		refreshPreview();
 		bActive = false;
@@ -197,10 +194,10 @@ void ImagePreview::mouseDoubleClickEvent (QMouseEvent *)
 	slotEditImage();
 }
 
-void ImagePreview::resizeEvent (QResizeEvent *)
+void ImagePreview::resizeEvent (QResizeEvent *p)
 {
 	// Here we make sure the aspect ratio is taken care of.
-
+	QLabel::resizeEvent ( p );
 }
 
 void ImagePreview::rotate (float fRot, bool bClear)
@@ -228,13 +225,13 @@ void ImagePreview::drawContents(QPainter *pPainter)
 	if (m_bFastPreview)	{
 		QWMatrix matrix;
 		QRect startRect, boundingRect;
-		float fZoom = m_fZoom * m_fStartZoom;
+		float fZoom = m_manipulator.fZoom * m_fStartZoom;
 		// Next we move the Image but keep the moving point centered.
-		matrix.translate (m_iStartX+(int)((float)m_image.width()/2.0*fZoom), m_iStartY+(int)((float)m_image.height()/2.0*fZoom));
+		matrix.translate ((int)(m_manipulator.fStartX * pPainter->window().width())+(int)((float)m_image.width()/2.0*fZoom), (int)(m_manipulator.fStartY*pPainter->window().height())+(int)((float)m_image.height()/2.0*fZoom));
 
 		matrix.scale (fZoom, fZoom);
 		matrix.rotate(m_pImage->rotate);
-		matrix.shear( m_fShearX, m_fShearY);
+		matrix.shear( m_manipulator.fShearX, m_manipulator.fShearY);
 		// Fill in the rectangles to be drawn ...
 		startRect = QRect((int)-(m_image.width()/ 2.0), (int)-(m_image.height()/2.0), m_image.width(), m_image.height());
 		boundingRect = matrix.mapRect(startRect);
@@ -260,26 +257,34 @@ void ImagePreview::refreshPreview ()
 	if (m_background.isNull())
 		return;
 	// If the image is completely transparent we can simply exit here ... N'est pas ???
-	if (m_fTransparency == 1.0)
+	if (m_manipulator.fTransparency == 1.0)
 		return;
 
 	int iTargetStartX, iTargetStartY, iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight;
 	QRect startRect, boundingRect;
-	float fZoom = m_fZoom * m_fStartZoom;
+	float fZoom = m_manipulator.fZoom * m_fStartZoom;
 	QWMatrix matrix;
 	QPixmap background;
 	QImage theImage;
 
-	if (m_iTransformationMode == 1)
+	if (m_manipulator.iTransformationMode == 1)
 		matrix.setTransformationMode(QWMatrix::Areas);
-	matrix.translate (m_iStartX+(int)((float)m_image.width()/2.0*fZoom), m_iStartY+(int)((float)m_image.height()/2.0*fZoom));
-//	matrix.translate (m_iStartX, m_iStartY);
+	matrix.translate ((int)(m_manipulator.fStartX*m_background.width())+(int)((float)m_image.width()/2.0*fZoom), (int)(m_manipulator.fStartY*m_background.height())+(int)((float)m_image.height()/2.0*fZoom));
+//	matrix.translate (m_manipulator.iStartX, m_manipulator.iStartY);
 	matrix.scale (fZoom, fZoom);
-	matrix.rotate(m_pImage->rotate);
-	matrix.shear (m_fShearX, m_fShearY);
+	if ( m_pImage )
+	  matrix.rotate ( m_pImage->rotate );
+	else
+	  matrix.rotate ( m_manipulator.fRotate );
+	matrix.shear (m_manipulator.fShearX, m_manipulator.fShearY);
 
 	// First we obtain a background to write to ...
-	background.convertFromImage(m_background);
+	if ( m_bShowBackground )
+		background.convertFromImage(m_background);
+	else	{
+		background = QPixmap (m_background.width(), m_background.height());
+		background.fill (QColor (0, 0, 0));
+	}
 	// Now we twist and twitch the actual interesting image ...
 	// Note: we only need a QImage because we need to get access to the pixel, which we can't with a Pixmap.
 	theImage = m_imageColored.xForm ( matrix );
@@ -303,10 +308,10 @@ void ImagePreview::refreshPreview ()
 	QColor sourceColor, targetColor, theColor;
 	QRgb sourcePixel;
 	QImage sourceImg;
-	float fTargetTrans = 1.0 - m_fTransparency;
-	float fSourceTrans = m_fTransparency;
+	float fTargetTrans = 1.0 - m_manipulator.fTransparency;
+	float fSourceTrans = m_manipulator.fTransparency;
 
-	if (m_fTransparency != 0.0)	{
+	if (m_manipulator.fTransparency != 0.0)	{
 		// First we generate a QImage object of the size needed from the background Image ...
 		QPixmap sourcePix (iSourceWidth, iSourceHeight);
 		bitBlt (&sourcePix, 0, 0, thePainter.device(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
@@ -321,14 +326,14 @@ void ImagePreview::refreshPreview ()
 			thePixel = theImage.pixel(x+iSourceStartX, y+iSourceStartY);
 			thePixel &= 0x00ffffff;	// filter out the transparency part
 			if (thePixel != 0x000000)	{
-				if (m_fTransparency != 0.0)	{
+				if (m_manipulator.fTransparency != 0.0)	{
 					sourcePixel = sourceImg.pixel(x, y);
 					sourceColor = QColor (sourcePixel);
 					targetColor = QColor ( thePixel );
 					theColor = QColor (
-						(int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
+						(int)(fSourceTrans * sourceColor.red  () + (int)(fTargetTrans * targetColor.red  ())),
 						(int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
-						(int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
+						(int)(fSourceTrans * sourceColor.blue () + (int)(fTargetTrans * targetColor.blue ()))
 					);
 					thePainter.setPen ( theColor );
 				}
@@ -411,8 +416,6 @@ void ImagePreview::refreshPreview ()
 */
 void ImagePreview::adjustColor()
 {
-	if (!m_pImage)
-		return;
 	// m_image is the input,
 	// m_imageColored is the output ...
 	int iRed, iGreen, iBlue;
@@ -427,20 +430,20 @@ void ImagePreview::adjustColor()
 	// create empty image.
 	m_imageColored = QImage (m_image.width(), m_image.height(), m_image.depth());
 
-	if (m_fBrightness > 0.0)	{
+	if (m_manipulator.fBrightness > 0.0)	{
 		bLighter = true;
-		fAdjust = 100 + m_fBrightness * 300;
+		fAdjust = 100 + m_manipulator.fBrightness * 300;
 	}
 	else	{
 		bLighter = false;
-		fAdjust = 100 + m_fBrightness * -300;
+		fAdjust = 100 + m_manipulator.fBrightness * -300;
 	}
 	for (y=0;y<m_image.height();y++)	{
 		for (x=0;x<m_image.width();x++)	{
 			thePix = m_image.pixel(x, y);
-			iRed = (int)((float)qRed(thePix) * m_fRed);
-			iBlue = (int)((float)qBlue(thePix) * m_fBlue);
-			iGreen = (int)((float)qGreen(thePix) * m_fGreen);
+			iRed = (int)((float)qRed(thePix) * m_manipulator.fRed);
+			iBlue = (int)((float)qBlue(thePix) * m_manipulator.fBlue);
+			iGreen = (int)((float)qGreen(thePix) * m_manipulator.fGreen);
 
 			theColor = QColor (iRed, iGreen, iBlue);
 			if (bLighter)
@@ -456,17 +459,30 @@ void ImagePreview::adjustColor()
 	m_bNeedToAdjustColor = false;
 }
 
+void ImagePreview::centerImage ()
+{
+	if (m_image.isNull())
+		return;
+	if ( (m_manipulator.fStartX != 0.0) || (m_manipulator.fStartY != 0.0) )
+		return;
+	m_manipulator.fStartX = ((width () - m_image.width ()) / 2.0 )/width ();
+	m_manipulator.fStartY = ((height() - m_image.height()) / 2.0 )/height();
+}
+
 void ImagePreview::preloadImage ()
 {
 	if (m_pImage->src.isEmpty())
 		return;
 	m_image = QImage (m_pImage->src);
+//	int iWidth  = m_image.width ();
 	// adjust colors by scaling down to a manageable level.
-//	if (m_bFastPreview)
-//		m_image = m_image.scale((int)(width()/4.0), (int)(height()/4.0), QImage::ScaleMin);
-//	else
-//		m_image = m_image.smoothScale(width(), height(), QImage::ScaleMin);
+	if (m_bFastPreview)
+		m_image = m_image.scale((int)(width()/4.0), (int)(height()/4.0), QImage::ScaleMin);
+	else
+		m_image = m_image.smoothScale(width(), height(), QImage::ScaleMin);
 	// And here we create the right m_coloredImage;
+//	m_manipulator.fZoom = (float)((float) m_image.width () / iWidth);
+//	m_fStartZoom = (float)((float) m_image.width () / iWidth);
 	adjustColor ();
 }
 
@@ -493,11 +509,15 @@ void ImagePreview::slotRotateFree ()
 		return;
 	rotate (fRotate, true);
 }
-
 void ImagePreview::slotEditImage ()
 {
+	QString qsEmptyString;
 	DialogImage *pDialog = new DialogImage (this);
-	pDialog->initMe(m_pImage, m_backgroundFileName);
+	if (m_bShowBackground)
+		pDialog->initMe(m_pImage, m_backgroundFileName);
+	else
+		pDialog->initMe(m_pImage, qsEmptyString);
+
 	connect (pDialog, SIGNAL (signalDone(void *)), this, SLOT(slotImageDialogDone (void *)));
 }
 
@@ -514,34 +534,34 @@ void ImagePreview::slotImageDialogDone (void *)
 
 void ImagePreview::setStartX (int iStartX)
 {
-	m_iStartX = iStartX;
-	refreshPreview();
+  m_manipulator.fStartX = (float)iStartX/width();
+  refreshPreview();
 }
 void ImagePreview::setStartY (int iStartY)
 {
-	m_iStartY = iStartY;
-	refreshPreview();
+  m_manipulator.fStartY = (float)iStartY/height();
+  refreshPreview();
 }
 void ImagePreview::setShearX (float fShearX)
 {
-	m_fShearX = fShearX;
+	m_manipulator.fShearX = fShearX;
 	refreshPreview();
 }
 void ImagePreview::setShearY (float fShearY)
 {
-	m_fShearY = fShearY;
+	m_manipulator.fShearY = fShearY;
 	refreshPreview();
 }
 void ImagePreview::setAspectRatio (float fAspectRatio)
 {
-	m_fAspectRatio = fAspectRatio;
+	m_manipulator.fAspectRatio = fAspectRatio;
 	resize (width(), (int)(width () * fAspectRatio));
 	refreshPreview();
 }
 
 void ImagePreview::setZoom (float fZoom)
 {
-	m_fZoom = fZoom;
+	m_manipulator.fZoom = fZoom;
 	refreshPreview();
 }
 
@@ -553,27 +573,27 @@ void ImagePreview::setStartZoom (float fZoom)
 
 void ImagePreview::setRed (float fRed)
 {
-	m_fRed = fRed;
+	m_manipulator.fRed = fRed;
 	m_bNeedToAdjustColor = true;
 }
 void ImagePreview::setGreen (float fGreen)
 {
-	m_fGreen = fGreen;
+	m_manipulator.fGreen = fGreen;
 	m_bNeedToAdjustColor = true;
 }
 void ImagePreview::setBlue (float fBlue)
 {
-	m_fBlue = fBlue;
+	m_manipulator.fBlue = fBlue;
 	m_bNeedToAdjustColor = true;
 }
 void ImagePreview::setBrightness (float fBrightness)
 {
-	m_fBrightness = fBrightness;
+	m_manipulator.fBrightness = fBrightness;
 	m_bNeedToAdjustColor = true;
 }
 void ImagePreview::setTransparency (float fTransparency)
 {
-	m_fTransparency = fTransparency;
+	m_manipulator.fTransparency = fTransparency;
 	m_bNeedToAdjustColor = true;
 }
 
@@ -585,7 +605,7 @@ void ImagePreview::setRotation (float fRotation)
 
 void ImagePreview::setTransformationMode (int iTransformationMode)
 {
-	m_iTransformationMode = iTransformationMode;
+	m_manipulator.iTransformationMode = iTransformationMode;
 	refreshPreview();
 }
 
@@ -618,28 +638,20 @@ void ImagePreview::setModifier ()
 	if (!m_pImage)
 		return;
 	// Check if there are modifiers at all
-	if (!m_pImage->pModifier)
-		return;
+	if (!m_pImage->pModifier) {
+	  ImageManipulator initialManipulator;
+	  m_manipulator  = initialManipulator;
+	  // removed bc the QSlideshows filter Dlg returned rotate but did not set modifiers.
+//	  m_pImage->rotate = 0.0;
+	  return;
+	}
 	ImageManipulator *pManipulator = (ImageManipulator *)m_pImage->pModifier;
 	// Okay, there were some changes, so we should take care of them.
-	m_fRed                = pManipulator->fRed;
-	m_fBlue               = pManipulator->fBlue;
-	m_iXRes               = pManipulator->iXRes;
-	m_iYRes               = pManipulator->iYRes;
-	m_fZoom               = pManipulator->fZoom;
-	m_pImage->rotate      = pManipulator->fRotate;
-	m_fGreen              = pManipulator->fGreen;
-	m_iStartX             = pManipulator->iStartX;
-	m_iStartY             = pManipulator->iStartY;
-	m_fShearX             = pManipulator->fShearX;
-	m_fShearY             = pManipulator->fShearY;
-	m_fBrightness         = pManipulator->fBrightness;
-	m_fAspectRatio        = pManipulator->fAspectRatio;
-	m_fTransparency       = pManipulator->fTransparency;
-	m_iTransformationMode = pManipulator->iTransformationMode;
+	m_manipulator    = *pManipulator;
+	m_pImage->rotate =  pManipulator->fRotate;
 
 	// only if there is a background file name specified,
-	// otherwise keep the global baackkground image (if any)
+	// otherwise keep the global background image (if any)
 	if (!pManipulator->backgroundFileName.isEmpty())	{
 		m_backgroundFileName  = pManipulator->backgroundFileName;
 		m_bShowBackground     = pManipulator->bShowBackground;
@@ -659,46 +671,21 @@ void ImagePreview::getModifier ()
 	m_pImage->pModifier = NULL;
 
 	// We don't need such a modifier if nothing has changed ...
-	if (	(m_iXRes == 720) &&
-		(m_iYRes == 480) &&
-		(m_iTransformationMode == 0) &&
-		(m_fAspectRatio == 4.0 / 3.0) &&
-		(m_fShearX == 0.0) &&
-		(m_fShearY == 0.0) &&
-		(m_fZoom == 1.0) &&
-		(m_fRed == 1.0) &&
-		(m_fGreen == 1.0) &&
-		(m_fBlue == 1.0) &&
-		(m_fBrightness == 0.0) &&
-		(m_fTransparency == 0.0) &&
-		(m_bShowBackground == true) &&
-		(m_backgroundFileName.isEmpty())
-	   )	return;
+	if ( m_manipulator.isUnchanged () )
+	    return;
+
 	// Okay, there were some changes, so we should take care of them.
 	pManipulator = new ImageManipulator;
-	pManipulator->fRed                = m_fRed;
-	pManipulator->iXRes               = m_iXRes;
-	pManipulator->iYRes               = m_iYRes;
-	pManipulator->fZoom               = m_fZoom * m_fStartZoom;
-	pManipulator->fRotate             = m_pImage->rotate;
-	pManipulator->fBlue               = m_fBlue;
-	pManipulator->fGreen              = m_fGreen;
-	pManipulator->iStartX             = m_iStartX;
-	pManipulator->iStartY             = m_iStartY;
-	pManipulator->fShearX             = m_fShearX;
-	pManipulator->fShearY             = m_fShearY;
-	pManipulator->fBrightness         = m_fBrightness;
-	pManipulator->fTransparency       = m_fTransparency;
-	pManipulator->fAspectRatio        = m_fAspectRatio;
-	pManipulator->bShowBackground     = m_bShowBackground;
-	pManipulator->backgroundFileName  = m_backgroundFileName;
-	pManipulator->iTransformationMode = m_iTransformationMode;
+	*pManipulator = m_manipulator;
+	pManipulator->fZoom = m_manipulator.fZoom * m_fStartZoom;
+	pManipulator->fRotate = m_pImage->rotate;
+
 	m_pImage->pModifier = pManipulator;
 }
 
 QPixmap &ImagePreview::getPixmap (int iWidth, int iHeight)
 {
-	// HEre we return the whole Image including background and ImageObject.
+	// Here we return the whole Image including background and ImageObject.
 	// first the easy way ... if teh size is the same (or 0 is defined).
 	if	( ( (iWidth == 0) && (iHeight == 0) )	||
 		  ( (iWidth == pixmap()->width()) && (iHeight == pixmap()->height() ) )
@@ -715,16 +702,16 @@ QPixmap &ImagePreview::getPixmap (int iWidth, int iHeight)
 
 QPixmap &ImagePreview::getObject()
 {
-	float fZoom = m_fZoom * m_fStartZoom;
+	float fZoom = m_manipulator.fZoom * m_fStartZoom;
 	QWMatrix matrix;
 	QImage theImage;
 
-	if (m_iTransformationMode == 1)
+	if (m_manipulator.iTransformationMode == 1)
 		matrix.setTransformationMode(QWMatrix::Areas);
-	matrix.translate (m_iStartX+(int)((float)m_image.width()/2.0), m_iStartY+(int)((float)m_image.height()/2.0));
+	matrix.translate ((int)(m_manipulator.fStartX*width())+(int)((float)m_image.width()/2.0), (int)(m_manipulator.fStartY*height())+(int)((float)m_image.height()/2.0));
 	matrix.scale (fZoom, fZoom);
 	matrix.rotate(m_pImage->rotate);
-	matrix.shear (m_fShearX, m_fShearY);
+	matrix.shear (m_manipulator.fShearX, m_manipulator.fShearY);
 
 	// Now we twist and twitch the actual interesting image ...
 	// Note: we only need a QImage because we need to get access to the pixel, which we can't with a Pixmap.
@@ -736,8 +723,10 @@ QPixmap &ImagePreview::getObject()
 QRect ImagePreview::getRect()
 {
 	QRect theRect;
-	float fZoom = m_fZoom * m_fStartZoom;
-	theRect = QRect(m_iStartX, m_iStartY,
+	float fZoom = m_manipulator.fZoom * m_fStartZoom;
+	theRect = QRect((int)(m_manipulator.fStartX*width()), (int)(m_manipulator.fStartY*height()),
 		(int)(fZoom*m_image.width()), (int)(fZoom*m_image.height()));
 	return theRect;
 }
+
+ 
