@@ -13,18 +13,60 @@
 #define SOURCEFILEENTRY_H
 
 #include <qstringlist.h>
+#include <qfont.h>
 #include <qsize.h>
 
 class QDomNode;
 class QDomElement;
 class QImage;
 
+#define MAX_COLORS 4
+
+class Subtitles
+{
+public:
+  class entry {
+  public:
+    entry ();
+    entry &operator = ( entry & );
+
+    int iIndex;
+    QString qsTimeStart;// 00:00:00.000
+    QString qsTimeStop; // 00:00:00.000
+    long    iTimeStart; // in ms
+    long    iTimeStop;  // in ms
+    QString qsText;
+    QRect   rect;       // Note not stored as it is created when drawing the text.
+  };
+
+   Subtitles ();
+  ~Subtitles ();
+
+  Subtitles & operator =    ( Subtitles   & );
+  bool    readProjectFile   ( QDomNode    & );
+  bool    writeProjectFile  ( QDomElement & );
+  long    getTimeFromString ( QString     & );
+  QString getStringFromTime ( long          );
+  QString getXMLFileName    (               );
+    
+  QFont                font;
+  QRect                rect;
+  QPoint               alignment;
+  QValueList <entry *> listOfSubtitles;
+  // this is the file that is going to be created.
+  QString              qsTempFile; 
+  QColor               subColors[ MAX_COLORS ];
+  unsigned char        iTransparency; // 0 .. 255
+};
+
 class TranscodeInterface
 {
 public:
 	 TranscodeInterface ();
 	~TranscodeInterface ();
 	TranscodeInterface & operator = (TranscodeInterface &);
+	bool operator == (const TranscodeInterface &);
+	bool operator != (const TranscodeInterface &);
 	bool readProjectFile  (QDomNode &);
 	bool writeProjectFile (QDomElement &);
 
@@ -46,6 +88,7 @@ public:
 	// Note: once the transcoding part terminates, 
 	// o the transcoding interface is deleted, 
 	// o the original file-name is replaced with the generated mpeg2 movie file-name
+	QString     qsTempFile;
 };
 
 // the following class is filled with information after the source has been added to the SourceToolbar
@@ -56,6 +99,7 @@ public:
 	~SourceFileInfo ();
 
 	SourceFileInfo & operator = (SourceFileInfo &);
+	QString getFileName ();
 
 	QString qsFileName;	  // E.g. video.mpg
 	QString qsSize;		  // E.g. 2.2M
@@ -77,7 +121,9 @@ public:
 	QString     qsPreCommand; // The Pre  Command tag for dvdauthor
 	QString     qsPostCommand;// The Post command tag for dvdauthor
 	int         iPause;       // The pause attribute for dvdauthor (-1=inf)
+	int         iTitleset;    // In case the user wants to define the titleset number
 	TranscodeInterface *pTranscodeInterface;
+	Subtitles   *pSubtitles;
 };
 
 // Note if the entry is a dvd-slideshow, then the qsDisplayName will end in .xml
@@ -89,18 +135,22 @@ public:
 	~SourceFileEntry ();
 
 	bool readProjectFile  (QDomNode &);
-	bool writeProjectFile (QDomElement &);
+	bool writeProjectFile (QDomElement &, bool b=false);
 	SourceFileEntry & operator = (SourceFileEntry &);
 
 	QString qsDisplayName;          // The name that appears on the display
 	QValueList <SourceFileInfo *> listFileInfos;
 	QStringList listChapters;       // The chapters of this SourceFile entry
-	bool bIsSlideshow;
+	bool bIsSlideshow;              // Will be re-set, once the slideshow has been created into a mpeg2 movie.
 	bool bSoundSource;              // Indicates if this is a movie or a Sound source
 
 	int iTitleset;                  // Set when processing createDvdauthorXml () function
 	int iTitle;                     // Set when processing createDvdauthorXml () function
+	int iJumpStart;                 // Set when processing createDvdauthorXml () function
 	QSize sizeThumbnail;            // The size of the thumbnail
+	QString qsPre;
+	QString qsPost;
+	int     iPause;                 // The pause attribute for dvdauthor (-1=inf)
 };
 
 #endif // SOURCEFILEENTRY_H
