@@ -1,3 +1,4 @@
+
 /****************************************************************************
 ** StructureToolBar - class
 **
@@ -31,11 +32,11 @@
 #include <qpopupmenu.h>
 #include <qlistview.h>
 #include <qdockarea.h>
+#include <qcombobox.h>
 #include <qlistbox.h>
 #include <qcursor.h>
 #include <qheader.h>
 
-//#include "../bugs_workaround.h"
 #include "global.h"
 #include "sourcetoolbar.h"
 #include "dialogslide.h"
@@ -48,7 +49,6 @@
 
 #include "qplayer/mediainfo.h"
 #include "qplayer/mediacreator.h"
-//#include "qplayer/dialogchapters.h"
 #include "qplayer/sourcefiledialog.h"
 
 #define SOURCE_FILE_ENTRY_ID   0
@@ -57,11 +57,12 @@
 SourceToolBar::SourceToolBar (const QString &qsLabel, QMainWindow *pMainWindow, QWidget *pParent, bool bNewLine, const char *pName, WFlags f)
 	: QToolBar (qsLabel, pMainWindow, pParent, bNewLine, pName, f)
 {
-	m_pMediaInfo = NULL;
-	m_pDVDAuthor = (QDVDAuthor *)pMainWindow;
+	m_pMediaInfo   = NULL;
+	m_pSlideDialog = NULL;
+	m_pDVDAuthor   = (QDVDAuthor *)pMainWindow;
 
 	// Next is to create a MediaEngine in a separate thread to keep the application running and not stottering ...
-	m_pMediaInfo = MediaCreator::createInfo ();
+	m_pMediaInfo   = MediaCreator::createInfo ();
 
 	setResizeEnabled (true);
 	setMovingEnabled (true);
@@ -98,11 +99,14 @@ SourceToolBar::SourceToolBar (const QString &qsLabel, QMainWindow *pMainWindow,
 SourceToolBar::~SourceToolBar ()
 {
 	uint t;
+	MediaCreator::unregisterFromMediaScanner ( this );
 	for (t=0;t<m_listSourceFileEntries.count();t++)
 		delete m_listSourceFileEntries[t];
 	m_listSourceFileEntries.clear();
 	if (m_pMediaInfo)
 		delete m_pMediaInfo;
+	if ( m_pSlideDialog )
+		delete m_pSlideDialog;
 }
 
 QSize SourceToolBar::sizeHint () const
@@ -232,19 +236,23 @@ void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPo
 	// Here we find out if we can actually play the file ... Meaning slideshows can not be played !!!
 	uint t;
 	bool bShow = true;
+	SourceFileEntry *pSourceFileEntry = NULL;
 	for (t=0;t<m_listSourceFileEntries.count();t++)	{
 		if (pItem->text(SOURCE_FILE_ENTRY_NAME) == m_listSourceFileEntries[t]->qsDisplayName)	{
 			if (m_listSourceFileEntries[t]->bIsSlideshow)
 				bShow = false;
+			pSourceFileEntry = m_listSourceFileEntries[t];
 			break;
 		}
 	}
 
 	QPopupMenu *pMenu = new QPopupMenu(m_pListViewAllSources);
 	if (bShow)
-		pMenu->insertItem ( tr ("Play")    , this, SLOT(slotPlayMovie    ()));
-	pMenu->insertItem ( tr ("Properties ...")    , this, SLOT(slotEditMovie    ()));
-	pMenu->insertItem ( tr ("Delete")      , this, SLOT(slotDeleteSource ()));
+		pMenu->insertItem ( tr ("Play")             , this, SLOT(slotPlayMovie    ()));
+	pMenu->insertItem ( tr ("Properties ...")           , this, SLOT(slotEditMovie    ()));
+	if ( (pSourceFileEntry) && (pSourceFileEntry->listFileInfos.count() > 1) )
+		pMenu->insertItem ( tr ("Transcode All ..."), this, SLOT(slotTranscodeAll ()));
+	pMenu->insertItem ( tr ("Delete")                   , this, SLOT(slotDeleteSource ()));
 	pMenu->exec(thePoint, 2);
 	
 	delete pMenu;
@@ -264,6 +272,74 @@ void SourceToolBar::slotClickedOnVideoList(QListViewItem *pItem, const QPoint &t
 	}
 }
 
+void SourceToolBar::slotTranscodeAll()
+{
+	uint t;
+	bool bGood = true;
+	// Called when the user clicks on the SourceFileEntry - header.
+	// This function will transcode all associated SourceFiles into the same format.
+	SourceFileEntry *pSourceFileEntry = NULL;
+	SourceFileInfo  *pSourceFileInfo  = NULL;
+	SourceFileInfo  *pFirstFileInfo   = NULL;
+	QListViewItem *pItem = m_pListViewAllSources->currentItem (); //selectedItem (); // currentItem ();
+	if ( ! pItem ) 
+		return;
+	for (t=0;t<m_listSourceFileEntries.count();t++)	{
+		if (pItem->text(SOURCE_FILE_ENTRY_NAME) == m_listSourceFileEntries[t]->qsDisplayName)	{
+			pSourceFileEntry = m_listSourceFileEntries[t];
+			break;
+		}
+	}
+	if ( ! pSourceFileEntry )
+		return;
+
+	// Okay we only want to convert if the FileInfos have the same transcoding information (Either none, or all values the same.
+	pFirstFileInfo = pSourceFileEntry->listFileInfos[0];
+	
+	for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
+		pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+		if ( pFirstFileInfo->pTranscodeInterface)	{
+			if ( ! pSourceFileInfo )
+				bGood = false;
+			if ( (pSourceFileInfo->pTranscodeInterface) && (pFirstFileInfo->pTranscodeInterface) && 
+			   ( *pSourceFileInfo->pTranscodeInterface  != *pFirstFileInfo->pTranscodeInterface ) )
+				bGood = false;
+			else if ( ((   pSourceFileInfo->pTranscodeInterface) && ( ! pFirstFileInfo->pTranscodeInterface)) || 
+				( (( ! pSourceFileInfo->pTranscodeInterface) && (   pFirstFileInfo->pTranscodeInterface)) ))
+				bGood = false;
+		}
+	}
+	if ( ! bGood )
+		return;
+	
+	// Here we open the MovieDialog.
+	DialogMovie theDialog (this);
+	theDialog.initMe (pSourceFileEntry);
+	if (theDialog.exec () == QDialog::Rejected)
+		return;
+
+	// Check if there was a transcodeInterface created by the dialog.
+	if (theDialog.sourceFileInfo()->pTranscodeInterface)	{
+		for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
+			pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+			if ( ! pSourceFileInfo->pTranscodeInterface )
+			       pSourceFileInfo->pTranscodeInterface = new TranscodeInterface;
+			*pSourceFileInfo->pTranscodeInterface = *theDialog.sourceFileInfo()->pTranscodeInterface;
+		}
+	}
+	else	{	// If there is none then remove all transcodeInterfaces from the files.
+		for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
+			pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+			if ( pSourceFileInfo->pTranscodeInterface )	{
+				delete pSourceFileInfo->pTranscodeInterface;
+				pSourceFileInfo->pTranscodeInterface = NULL;
+			}
+		}
+	}
+	pSourceFileEntry->qsPre  = theDialog.m_pComboPreCommand->currentText  ( );
+	pSourceFileEntry->qsPost = theDialog.m_pComboPostCommand->currentText ( );
+}
+
 // This is without background task to get the info ...
 void SourceToolBar::slotAddMovie()
 {
@@ -271,7 +347,7 @@ void SourceToolBar::slotAddMovie()
 		return;
 	// Some one clicked the "Add Movie" button.
 	QString qsFilter = m_pDVDAuthor->getMovieFilter();
-	QStringList listAddMovies = QFileDialog::getOpenFileNames (tr("Movie Files (")+qsFilter+QString (")"), m_pDVDAuthor->currentPath(), this, tr("Open file dialog"), tr ("Add To Project ..."));
+	QStringList listAddMovies = QFileDialog::getOpenFileNames (tr("Movie Files (")+qsFilter+QString (")"), Global::qsCurrentPath, this, tr("Open file dialog"), tr ("Add To Project ..."));
 	// I tried to get the sorting of the names out of here but
 	// detailViewSelectionChanged and listBoxSelectionChanged
 	// are not flexible enough to handle this (yet).
@@ -298,13 +374,18 @@ void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
 		pInfo = new SourceFileInfo;
 		pInfo->qsFileName   = listAddMovies[t];
 		// Here we generate a dummy image as a place holder
-		pInfo->pPreview = new QImage (QImage::fromMimeSource( "please_wait.jpg" ));
+		pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
 		*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
 		// and then register to obtain the info in the background.
 		MediaCreator::registerWithMediaScanner (this, pInfo);
 
 		pEntry->listFileInfos.append(pInfo);
 	}
+	// Check if there is something in the Entry left to be added to the sourceToolbar.
+	if (pEntry->listFileInfos.count() == 0)	{
+		delete pEntry;
+		return;
+	}
 
 	if (pTitle)	{	// If a title has been 
 		pEntry->qsDisplayName = *pTitle;
@@ -328,8 +409,10 @@ void SourceToolBar::timerEvent(QTimerEvent *pTimerEvent)
 	uint t, i;
 	SourceFileEntry *pEntry = NULL;
 	SourceFileInfo  *pInfo  = NULL;
+
 	switch ( pTimerEvent->timerId() )	{
 	case MEDIASCANNER_EVENT:
+	        m_mutexThumbnails.lock ();
 		// We could simply call this function but it would be a brute force approach as the whole tree would get rebuild.
 		//refreshToolBarEntries ();
 		// So rather we check all SourceFIleInfo's for the flag bUpdateImage and do so singularily.
@@ -361,10 +444,12 @@ void SourceToolBar::timerEvent(QTimerEvent *pTimerEvent)
 					}
 					pInfo->bUpdateInfo = false;
 					m_pDVDAuthor->slotCalculateSize();
+					m_mutexThumbnails.unlock ();
 					return;
 				}
 			}
 		}
+		m_mutexThumbnails.unlock ();
 	break;
 	}
 }
@@ -428,7 +513,7 @@ void SourceToolBar::appendSourceFileEntry(SourceFileEntry *pEntry)
 		for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
 			SourceFileInfo *pInfo = pEntry->listFileInfos[t];
 			// Add the plaeas - wait image
-			pInfo->pPreview = new QImage (QImage::fromMimeSource( "please_wait.jpg" ));
+			pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
 			// and the request the preview from a background thread.
 			MediaCreator::registerWithMediaScanner (this, pInfo);
 			*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
@@ -444,7 +529,7 @@ void SourceToolBar::appendSourceFileEntry(SourceFileEntry *pEntry)
 			if (pInfo->qsStatus != QString ("Ok"))
 				statusColor = QColor (COLOR_SOUND_FILES_BAD);
 
-			pInfo->pPreview = new QImage (QImage::fromMimeSource( "sound_file.jpg" ));
+			pInfo->pPreview = new QImage (QImage().fromMimeSource( "sound_file.jpg" ));
 			*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
 			new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize, pInfo->qsStatus, pInfo->qsFileName);
 		}
@@ -455,7 +540,11 @@ void SourceToolBar::appendSourceFileEntry(SourceFileEntry *pEntry)
 
 void SourceToolBar::slotRemoveEntry(SourceFileEntry *pEntry)
 {
-	m_listSourceFileEntries.remove(pEntry);
+  m_listSourceFileEntries.remove(pEntry);
+  if ( m_pDVDAuthor )
+    // So the user has decided to delete this source, then we should change the associated
+    // buttons - action !!!
+    m_pDVDAuthor->removedSourceEntry( pEntry );
 }
 
 void SourceToolBar::slotAddSound()
@@ -464,7 +553,7 @@ void SourceToolBar::slotAddSound()
 	// QDVDMenu::slotAddSound()->DVDAuthor::addSound()->SourceToolBar::addSound()
 	QString qsFilter = m_pDVDAuthor->getSoundFilter();
 	// For now we assume this is slotEditAdd()
-	QStringList listAddSounds = QFileDialog::getOpenFileNames(tr("Sound Files (")+qsFilter+QString(")"), m_pDVDAuthor->currentPath(), this, tr("Open file dialog"), tr("Add To Project ..."));
+	QStringList listAddSounds = QFileDialog::getOpenFileNames(tr("Sound Files (")+qsFilter+QString(")"), Global::qsCurrentPath, this, tr("Open file dialog"), tr("Add To Project ..."));
 	if (listAddSounds.count() < 1)
 		return;
 	// Okay, now we should also add this into the list box ...
@@ -503,7 +592,7 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 		pInfo->qsFormat   = pMediaInfo->getFormat (false);
 		pInfo->qsStatus   = pMediaInfo->getStatus();
 		pInfo->qsFileName = listSoundNames[t];
-		pInfo->pPreview   = new QImage (QImage::fromMimeSource( "sound_file.jpg" ));
+		pInfo->pPreview   = new QImage (QImage().fromMimeSource( "sound_file.jpg" ));
 		*pInfo->pPreview  = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
 
 		if (pInfo->qsStatus != QString ("Ok"))
@@ -531,19 +620,17 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 void SourceToolBar::slotAddSlideshow()
 {
 	Utils theUtil;
-printf ("SourceToolBar::slotAddSlideshow\n");
 	if (!m_pDVDAuthor->checkForNewProject ())
 		return;
 	// First we pop up the slideshow generation dialog box
 	QString qsTempPath = theUtil.getTempFile(QString ());
-	CSlideDialog *pSlideDialog = new CSlideDialog;
-	pSlideDialog->initMe(this, qsTempPath);
-	pSlideDialog->show();
+	if ( ! m_pSlideDialog )  {
+		m_pSlideDialog = new CSlideDialog;
+		m_pSlideDialog->initMe(this, qsTempPath);
+	}
+	m_pSlideDialog->show();
 	// Note that the SourceFileEntry is generated  when we have given a name to the
 	// newly generated slideshow. This is then done SourceToolBar::slotAddSlideshow(QString);
-	
-	// FIXME: 
-	// How do we free the resources of this dialog after it has finished ?
 }
 
 void SourceToolBar::slotEditMovie()
@@ -556,8 +643,8 @@ void SourceToolBar::slotEditMovie()
 	if (pSourceFileInfo)	{
 		DialogMovie *pDialog = new DialogMovie (this);
 		pDialog->initMe (pSourceFileInfo, getMediaEngine(), m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail.width());
-		pDialog->exec ();
-		*pSourceFileInfo = *pDialog->sourceFileInfo();
+		if (pDialog->exec () == QDialog::Accepted)
+			*pSourceFileInfo = *pDialog->sourceFileInfo();
 		delete pDialog;
 		return;
 	}
@@ -773,7 +860,7 @@ void SourceToolBar::removeEntry (SourceFileEntry *pSourceFileEntry, bool bSource
 	// This is the case when we create a new entry. The first thing done is to remove all
 	// double entries but we want to leave the entries in the Menus intact.
 	if (m_pDVDAuthor && !bSourceOnly)
-		// So the user has decided to delete this source, then we should change the assoziated
+		// So the user has decided to delete this source, then we should change the associated
 		// buttons - action !!!
 		m_pDVDAuthor->removedSourceEntry(pSourceFileEntry);
 }
@@ -808,57 +895,109 @@ void SourceToolBar::slotPlayMovie()
 // the following two functions are called from CSlideDialog, if avail ...
 void SourceToolBar::slotAddSlideshow (QString qsSlideshowName)
 {
-printf ("SourceToolBar::slotAddSlideshow <%s>\n", (const char *)qsSlideshowName);
-	if (!m_pDVDAuthor->checkForNewProject ())
+	if ( ! m_pDVDAuthor->checkForNewProject () )
 		return;
 
 	// Lets create a new SourceFileEntry ...
 	SourceFileEntry *pEntry = new SourceFileEntry;
-	SourceFileInfo  *pInfo = new SourceFileInfo;
+	SourceFileInfo  *pInfo  = new SourceFileInfo;
 	// Here we create the temp image
 	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
-	pInfo->pPreview = new QImage (QImage::fromMimeSource( "create_slideshow.jpg" ));
+	pInfo->pPreview  = new QImage (QImage().fromMimeSource( "create_slideshow.jpg" ));
 	*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
 
 	pEntry->bIsSlideshow = true;
-	pInfo->qsFileName = qsSlideshowName;
+	pInfo->qsFileName    = qsSlideshowName;
 	pEntry->listFileInfos.append(pInfo);
 	pEntry->qsDisplayName.sprintf ("[%02d] - %s", getFreeSourceSlot (), (const char *)qsSlideshowName);
-//	pEntry->qsDisplayName = qsSlideshowName;	// E.g. slideshow.xml
 	m_listSourceFileEntries.append(pEntry);
 	// Okay, now we should also add this into the list box ...
 	new ListViewItemMedia (m_pListViewAllSources, pEntry, QColor (COLOR_SLIDE_FILES_OK));
 }
 
-void SourceToolBar::slotSlideshowDone(QString qsSlideshowName)
+void SourceToolBar::slotSlideshowDone(QString qsSlideshowName, QString qsFileName)
 {
 	Utils theUtil;
-printf ("SourceToolBar::slotSlideshowDone <%s>\n", (const char *) qsSlideshowName);
-	uint t, iListBoxPosition = 0;
+	uint t;
+	int iListBoxPosition = -1;
 	SourceFileEntry *pEntry;
-	QListViewItem *pItem = m_pListViewAllSources->firstChild();
+	QString qsItemText;
+	QFileInfo fileInfo;
+	QListViewItem *pItem, *pParentItem = m_pListViewAllSources->firstChild();
 	for (t=0;t <(uint)m_pListViewAllSources->childCount();t++)	{
-		if (pItem->text(SOURCE_FILE_ENTRY_NAME) == qsSlideshowName)	{
+		if ( ! pParentItem )
+			continue;
+		pItem = pParentItem->firstChild ();
+		if ( ! pItem )
+			continue;
+		qsItemText = pItem->text(SOURCE_FILE_ENTRY_NAME);
+		qsItemText.remove ("\n");
+		if (qsItemText == qsSlideshowName)	{
 			iListBoxPosition = t;
 			break;
 		}
-		pItem = pItem->nextSibling();
-	}	
+		pParentItem = pParentItem->nextSibling();
+	}
+	// Error ...
+	if ( ! pParentItem )
+		return;
+	
 	for (t=0;t<m_listSourceFileEntries.count();t++)	{
 		pEntry = m_listSourceFileEntries[t];
-		if (pEntry->qsDisplayName == qsSlideshowName)	{
-			// First thing we should modify the name displayed ...
-			pEntry->qsDisplayName = qsSlideshowName + QString (".mpeg");
-			// Next we determine the fileName of the generated mpeg video ...
+		if (pEntry->qsDisplayName.find(qsSlideshowName) != -1)	{
+			// First we determine the fileName of the generated mpeg video ...
 			QFileInfo fileInfo (pEntry->listFileInfos[0]->qsFileName);
-			pEntry->listFileInfos[0]->qsFileName = theUtil.getTempFile(fileInfo.fileName()+QString (".mpeg"));
+			pEntry->listFileInfos[0]->qsFileName = qsFileName; //theUtil.getTempFile(fileInfo.fileName()+QString (".mpeg"));
 			pEntry->bIsSlideshow = false;	// now we hold a mpeg and not a xml - file ...
 			pEntry->bSoundSource = false;
 
+			delete pParentItem;
 			new ListViewItemMedia (m_pListViewAllSources, pEntry,QColor (COLOR_MOVIE_FILES_OK));
+			SourceFileInfo *pInfo = pEntry->listFileInfos[0];
+			fileInfo.setFile ( qsFileName );
+			qsFileName = QString ("%1/%2.xml").arg(fileInfo.dirPath( TRUE )).arg(fileInfo.baseName ());
+			importChapters ( qsFileName, pInfo );
+			new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsFormat,
+				pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
+				pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
+			MediaCreator::registerWithMediaScanner (this, pInfo);
 			return;
 		}
 	}
+	m_pDVDAuthor->slotAutosave ();
+}
+
+void SourceToolBar::importChapters( QString qsChaptersFileName, SourceFileInfo *pInfo )
+{
+	int iRead;
+	uint t;
+	Utils theUtils;
+	QString qsChaptersString, qsChapters, qsFileName;
+
+	if (qsChaptersFileName.isNull ())
+		return;
+
+	QFile chaptersFile (qsChaptersFileName);
+	chaptersFile.open( IO_ReadOnly );
+	// Let us read in at max 16k of chapters ... Why 16k .. Just a guess !
+	iRead = chaptersFile.readLine (qsChaptersString, 16000);
+	// Error checking ...
+	if (iRead < 1)
+		return;
+	
+	// And finally we get to parse this string. Please note this is a very basic
+	// parser for a very basic syntax a la <vob chapters="0,0:0:14.0,0:0:22.0" file="/tmp/slideshow.mpeg.mpg"  />
+	qsChapters = theUtils.getAttribute("chapters", qsChaptersString);
+
+	// Now let us split some hair here ...
+	QStringList listChapters = QStringList::split (",", qsChapters);
+	if (listChapters.count() < 1)
+		return;
+	// Here we format the Chapter strings ...
+	for (t=0;t<listChapters.count();t++)	
+		listChapters[t] = theUtils.formatChapter(listChapters[t]);
+	// Note that this is called Import ... Thus we remove any older chapters or this entry ...
+	pInfo->listChapters = listChapters;
 }
 
 void SourceToolBar::clear ()
