@@ -30,6 +30,7 @@
 #define MOVIE_FILE_NAME_INDEX 7
 #define AUDIO_FILE_NAME_INDEX 7
 
+#include <qmutex.h>
 #include <qthread.h>
 
 #include "uisourcewidget.h"
@@ -37,33 +38,34 @@
 
 class QDVDAuthor;
 class MediaInfo;
+class CSlideDialog;
 
 class SourceToolBar : public QToolBar
 {
 	Q_OBJECT
 
 public:
-	 SourceToolBar (const QString &, QMainWindow *, QWidget *, bool b=FALSE, const char *n=0, WFlags f=0);
-	~SourceToolBar ();
+	 SourceToolBar     (const QString &, QMainWindow *, QWidget *, bool b=FALSE, const char *n=0, WFlags f=0);
+	~SourceToolBar     ();
 
-	void addMovie     (SourceFileEntry *);
-	void addMovieList (QStringList &, QString *p=NULL);
-	void addSound     (QStringList &);
-	void clear        ();
+	void addMovie      (SourceFileEntry *);
+	void addMovieList  (QStringList &, QString *p=NULL);
+	void addSound      (QStringList &);
+	void clear         ();
 	
-	int sourceFileCount();
-	SourceFileEntry *sourceFileEntry(uint);
-	SourceFileEntry *getCurrentSourceFileEntry();
-	SourceFileInfo  *getCurrentSourceFileInfo ();
-	void appendSourceFileEntry(SourceFileEntry *);
-	void removeEntry (QString &, bool b=true);
-	void removeEntry (SourceFileEntry *, bool b=true);
-	int  getFreeSourceSlot       ();
+	int sourceFileCount                        ();
+	int  getFreeSourceSlot                     ();
+	SourceFileEntry *sourceFileEntry           (uint);
+	SourceFileEntry *getCurrentSourceFileEntry ();
+	SourceFileInfo  *getCurrentSourceFileInfo  ();
+	void appendSourceFileEntry                 (SourceFileEntry *);
+	void removeEntry                           (QString &, bool b=true);
+	void removeEntry                           (SourceFileEntry *, bool b=true);
 
-	virtual QSize sizeHint () const;
-	QString convertFileSize(uint);
+	virtual QSize sizeHint                     () const;
+	QString convertFileSize                    (uint);
 
-	MediaInfo *getMediaInfo ();
+	MediaInfo *getMediaInfo                    ();
 
 protected:
 	virtual void  timerEvent      (QTimerEvent *);
@@ -71,6 +73,7 @@ protected:
 private:
 	void  refreshToolBarEntries   ();
 	void *getMediaEngine          ();
+	void  importChapters          ( QString, SourceFileInfo *);
 //	void  makeScreenshots         (SourceFileEntry *);
 
 public slots:
@@ -80,17 +83,20 @@ public slots:
 	virtual void slotPlayMovie    ();
 	virtual void slotEditMovie    ();
 	virtual void slotDeleteSource ();
+	virtual void slotTranscodeAll ();
 
 	virtual void slotAddMovie     ();
 	virtual void slotAddSound     ();
 	virtual void slotAddSlideshow ();
 	virtual void slotAddSlideshow (QString);
-	virtual void slotSlideshowDone(QString);
+	virtual void slotSlideshowDone(QString, QString);
 	virtual void slotRemoveEntry  (SourceFileEntry *);
 
 private:
 	uiSourceWidget    *m_pSourceWidget;
+	QMutex             m_mutexThumbnails;
 	MediaInfo         *m_pMediaInfo;
+	CSlideDialog      *m_pSlideDialog;
 	QDVDAuthor        *m_pDVDAuthor;
 	QListView         *m_pListViewAllSources;
 	QValueList<SourceFileEntry *>	m_listSourceFileEntries;
