@@ -28,6 +28,7 @@
 #include <qdir.h>
 #include <qtimer.h>
 #include <qcursor.h>
+#include <qlistbox.h>
 #include <qpainter.h>
 #include <qfileinfo.h>
 #include <qiconview.h>
@@ -44,6 +45,7 @@
 #include "qplayer/mediainfo.h"
 #include "qplayer/mediacreator.h"
 
+#include "sourcefileentry.h"
 #include "templatewizard.h"
 
 /****************************************************************************
@@ -52,9 +54,11 @@
 ** Simply there to emit a signal when some one clicks in it.
 **
 *****************************************************************************/
-TemplateFrame::TemplateFrame ( QWidget *pParent, const char *pName, WFlags flags )
+TemplateFrame::TemplateFrame ( TemplateWizard *pWizard, QWidget *pParent, const char *pName, WFlags flags )
 	: QFrame (pParent, pName, flags)
 {
+	m_pTemplateWizard = pWizard;
+	setAcceptDrops (TRUE);
 }
 
 TemplateFrame::~TemplateFrame ()
@@ -66,6 +70,39 @@ void TemplateFrame::mouseReleaseEvent ( QMouseEvent *pEvent )
 	emit (signalMouseReleaseEvent (pEvent));
 }
 
+void TemplateFrame::dropEvent (QDropEvent *pDropEvent)
+{
+	// Simply forward to the main object to handle this event.
+	if (m_pTemplateWizard)
+		m_pTemplateWizard->droppedSomething (pDropEvent);
+}
+
+void TemplateFrame::dragEnterEvent(QDragEnterEvent *pEvent)
+{
+	// Tell the Widget that we accept QTextDrops ...
+	// This is necessary otherwise the dropEvent does not occur.
+	pEvent->accept (QTextDrag::canDecode(pEvent));
+}
+
+ListBoxToolTip::ListBoxToolTip (QListBox* pListBox) : 
+	QToolTip(pListBox->viewport()), 
+	m_pListBox(pListBox) 
+{
+}
+
+void ListBoxToolTip::maybeTip(const QPoint& pos) 
+{
+	// get pointed item
+	QListBoxItem* pItem = m_pListBox->itemAt(pos);
+	if (pItem == 0)
+		return;
+	// show tooltip if item is not fully visible
+	QRect r = m_pListBox->itemRect(pItem);
+	r.setWidth(pItem->width(m_pListBox));
+	if (!m_pListBox->viewport()->rect().contains(r))
+		tip(r, pItem->text());
+}
+
 TemplateWizard::DropZone::DropZone (int i, QString s, QRect r)
 {
 	bMovie = false;
@@ -86,10 +123,11 @@ TemplateWizard::DropZone::~DropZone ()
 TemplateWizard::TemplateWizard( QWidget* parent, const char* name, WFlags fl )
     : uiTemplateWizard( parent, name, fl )
 {
-	m_pDVDAuthor = NULL;
-	m_pDVDMenu   = NULL;
-	m_fScale     = 0.0f;
-	m_bDontRestart = false;
+	m_pDVDAuthor      = NULL;
+	m_pDVDMenu        = NULL;
+	m_fScale          = 0.0f;
+	m_bDontRestart    = false;
+	m_pListBoxToolTip = NULL;
 }
 
 TemplateWizard::~TemplateWizard()
@@ -102,6 +140,8 @@ TemplateWizard::~TemplateWizard()
 		m_pMediaInterface->stop();
 		delete m_pMediaInterface;
 	}
+	if (m_pListBoxToolTip)
+		delete m_pListBoxToolTip;
 }
 
 void TemplateWizard::hide ()
@@ -124,11 +164,15 @@ void TemplateWizard::initMe (QDVDAuthor*pDVDAuthor)
 	initTab (QString ("animated"), m_pIconViewAnimated);
 	initTab (QString ("transition"), m_pIconViewTransition);
 
-	QGridLayout *WizardPageLayout_2 = new QGridLayout( WizardPage_2, 1, 1, 11, 6, "WizardPageLayout_2"); 
+	// Create the tooltips ...
+	m_pListBoxToolTip  = new ListBoxToolTip (m_pListBoxSources);
+
+	// Here we create the main templateFrame
+	QGridLayout *WizardPageLayout_2 = new QGridLayout( m_pOuterFrame, 1, 1, 11, 6, "WizardPageLayout_2"); 
 	QSpacerItem *spacer1 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
 	WizardPageLayout_2->addItem( spacer1, 0, 1 );
 
-	m_pFrameProperties = new TemplateFrame( WizardPage_2, "m_pFrameProperties" );
+	m_pFrameProperties = new TemplateFrame( this, m_pOuterFrame, "m_pFrameProperties" );
 	m_pFrameProperties->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 2, 2, m_pFrameProperties->sizePolicy().hasHeightForWidth() ) );
 	m_pFrameProperties->setFrameShape( QFrame::StyledPanel );
 	m_pFrameProperties->setFrameShadow( QFrame::Raised );
@@ -145,7 +189,8 @@ void TemplateWizard::initMe (QDVDAuthor*pDVDAuthor)
 	connect (m_pComboMenu, SIGNAL(activated (const QString &)), this, SLOT(slotTargetMenuChanged (const QString &)));
 	resize( QSize(739, 536).expandedTo(minimumSizeHint()) );
 	clearWState( WState_Polished );
-	initPreview ();
+	initPreview  ();
+	initDragList ();
 }
 
 void TemplateWizard::slotPlaybackFinished ()
@@ -195,6 +240,40 @@ void TemplateWizard::initPreview ()
 	m_pMediaInterface->initMediaEngine();
 }
 
+void TemplateWizard::initDragList ()
+{
+	// This function will initialize the ListBox to the left on the second page.
+	// It will take the images straight from SourceFileInfo objcts
+	uint t, i;
+	SourceFileEntry *pEntry;
+	SourceFileInfo  *pInfo;
+	int iWidth = 125;
+	if ( ! m_pDVDAuthor )
+		return;
+	m_listSourceFileDescriptions.clear ();
+	m_pListBoxSources->clear ();
+	for (t=0;(int)t<m_pDVDAuthor->sourceFileCount ();t++)	{
+		pEntry = m_pDVDAuthor->sourceFileEntry(t);
+		if ( ! pEntry )
+			continue;
+		if (pEntry->bSoundSource)
+			continue;
+		for (i=0;i<pEntry->listFileInfos.count (); i++)	{
+			pInfo = pEntry->listFileInfos[i];
+			if ( ( ! pInfo ) || ( ! pInfo->pPreview ) )
+				continue;
+			QImage tempImage ( *pInfo->pPreview );
+			m_pListBoxSources->insertItem (tempImage.smoothScale (iWidth, iWidth, QImage::ScaleMin), pInfo->qsFileName);
+			m_listSourceFileDescriptions.append (QString ("%1 : %2").arg(pInfo->qsFileName).arg(pInfo->qsSize));
+			
+		}
+	}
+	// And finally we connect the listBox to some event handler 
+	connect (m_pListBoxSources, SIGNAL(pressed (QListBoxItem *)), this , SLOT(slotListBoxClicked (QListBoxItem *)));
+	m_pListBoxSources->setHScrollBarMode(QScrollView::AlwaysOff);
+}
+
+
 void TemplateWizard::initTab (QString qsWhichTab, QIconView *pIconView)
 {
 	uint t;
@@ -285,6 +364,76 @@ void TemplateWizard::slotIconViewClicked (QIconViewItem *pIconViewItem)
 	setNextEnabled ( page (0), true );
 }
 
+void TemplateWizard::slotListBoxClicked (QListBoxItem *pItem)
+{
+	int iIndex;
+	iIndex = m_pListBoxSources->index (pItem);
+	if (iIndex < 0 || iIndex > (int)m_listSourceFileDescriptions.count () - 1)
+		return;
+	m_pLabelInfo->setText (m_listSourceFileDescriptions[iIndex]);
+	// Last we create a dragObject ...
+	QDragObject *d = new QTextDrag( m_listSourceFileDescriptions[iIndex], this );
+	d->setPixmap (QPixmap (*pItem->pixmap ()));
+	d->dragCopy();
+}
+
+void TemplateWizard::droppedSomething (QDropEvent *pDropEvent)
+{
+	uint t, i;
+	QImage  theImage;
+	QString theText;
+	QPoint  thePos;
+	DropZone *pDropZone = NULL;
+	SourceFileEntry *pEntry = NULL;
+	SourceFileInfo  *pInfo  = NULL;
+
+	if ( ! QTextDrag::decode(pDropEvent, theText) )
+		return;
+
+	// The first step is to verify that it was dropped over a DropZone.
+	thePos.setX ((int)(pDropEvent->pos().x () / m_fScale));
+	thePos.setY ((int)(pDropEvent->pos().y () / m_fScale));
+		
+	for (t=0;t<m_listDropZones.count();t++)	{
+		if (m_listDropZones[t]->rect.contains (thePos))	{
+			pDropZone = m_listDropZones[t];
+			break;
+		}
+	}
+	if ( ! pDropZone )
+		return;
+	// Get the previewImage ...
+	if (m_pDVDAuthor)	{
+		for (t=0;(int)t<m_pDVDAuthor->sourceFileCount(); t++)	{
+			pEntry = m_pDVDAuthor->sourceFileEntry ( t );
+			for (i=0;i<pEntry->listFileInfos.count();i++)	{
+				if ( (pEntry)  &&  (theText.contains (pEntry->listFileInfos[i]->qsFileName) > 0 ) )	{
+					pDropZone->qsFileName = pEntry->listFileInfos[i]->qsFileName;
+					pInfo = pEntry->listFileInfos[i];
+					// Exit both loops ...
+					t = m_pDVDAuthor->sourceFileCount();
+					i = pEntry->listFileInfos.count  ();
+				}
+			}
+		}
+	}
+	if (pInfo && pInfo->pPreview)
+		theImage = pInfo->pPreview->smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleMin);
+	else	{
+		theImage = QImage().fromMimeSource( "error.jpg" );
+		theImage = theImage.smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleMin);
+	}
+	// Set the DropZoneValues ...
+	// Note: theText is "$FileName : $size" so that does not work.
+	// pDropZone->qsFileName = theText;
+	pDropZone->bMovie = true;
+	if (pDropZone->pPixmap)
+		delete pDropZone->pPixmap;
+	pDropZone->pPixmap = new QPixmap;
+	pDropZone->pPixmap->convertFromImage (theImage);
+	refreshBackground ();
+}
+
 void TemplateWizard::slotTargetMenuChanged (const QString &qsMenuName)
 {
 	// Here we check if we have a new or an existing menu.
@@ -392,7 +541,7 @@ QString TemplateWizard::readProjectFile (QString qsFileName, bool bDescriptionOn
 		qsTemplateName = attribute.value();
 		m_qsCurrentTemplate = qsTemplateName;
 	}
-//printf ("TemplateWizard::getDescription <%s>\n", (const char *)attribute.value());
+
 	while( !xmlNode.isNull() ) {
 		QDomElement searchXMLTree = xmlNode.toElement();
 		// Okay, here we retain the stored data from the xml file.
@@ -433,6 +582,9 @@ QString TemplateWizard::readProjectFile (QString qsFileName, bool bDescriptionOn
 	return qsReturn;
 }
 
+/**
+ * This function is called when the user clicks on the next button.
+ */
 void TemplateWizard::next ()
 {
 	QString qsFileName;
@@ -498,6 +650,30 @@ DVDMenu *TemplateWizard::getMenu ()
 	return m_pDVDMenu;
 }
 
+QString TemplateWizard::getSourceEntryName (QString qsFileName)
+{
+	// This function will check if the file is already part of a SourceFileEntry.
+	uint t, i;
+	QString qsEntryName;
+	SourceFileEntry *pEntry;
+
+	if ( ! m_pDVDAuthor )
+		return qsEntryName;
+
+	for (t=0;(int)t<m_pDVDAuthor->sourceFileCount ();t++)	{
+		pEntry = m_pDVDAuthor->sourceFileEntry(t);
+		for (i=0;i<pEntry->listFileInfos.count();i++)	{
+			if (pEntry->listFileInfos[i]->qsFileName == qsFileName)	{
+				qsEntryName = pEntry->qsDisplayName;
+				// leave both for - loops.
+				t = m_pDVDAuthor->sourceFileCount ();
+				i = pEntry->listFileInfos.count   ();
+			}
+		}
+	}
+	return qsEntryName;
+}
+
 void TemplateWizard::reject ()
 {
 	if (m_pDVDMenu)
@@ -511,7 +687,7 @@ void TemplateWizard::accept ()
 	// First we are going to replace the DropZone placeholder and then create a DVDMenu.
 	uint t;
 	int i, iFreeSlot, iX, iY, iWidth, iHeight;
-	QString qsAction, qsEntryName, qsPrefixDir, qsMenuName, qsGeometry, qsCurrentPath;
+	QString qsAction, qsEntryName, qsEntry, qsPrefixDir, qsMenuName, qsGeometry, qsCurrentPath;
 	QFileInfo fileInfo;
 	QStringList listAddMovies;
  
@@ -554,10 +730,17 @@ void TemplateWizard::accept ()
 		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_BUTTON+").arg(i), QString ("ButtonObject"));
 		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_GEOMETRY+").arg(i), qsGeometry);
 		if (m_listDropZones[t]->bMovie)	{
-			qsAction = QString ("jump+-+%1+-+%2+-+00:00:00.000").arg(qsEntryName).arg(fileInfo.fileName());
+			// Note: if we find the file already in a SourceFIleEntry, then we do not need to add it again.
+			qsEntry = getSourceEntryName (m_listDropZones[t]->qsFileName);
+			if (qsEntry.isEmpty())	{ // If nothing has been found in the current SourceFileEntry list
+				qsEntry = qsEntryName;
+				listAddMovies.append (m_listDropZones[t]->qsFileName);
+			}
+			qsEntry.replace ("<", "&lt;");
+			qsEntry.replace (">", "&gt;");
+			qsAction = QString ("jump+-+%1+-+%2+-+00:00:00.000").arg(qsEntry).arg(fileInfo.fileName());
 			m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_OBJECT_TYPE+").arg(i), QString ("MovieObject"));
 			m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_MOVIE_SIZE+").arg(i), QString ("720x480"));
-			listAddMovies.append (m_listDropZones[t]->qsFileName);
 		}
 		else	{	// The image button should jump to the MainMenu  jump+-+vmgm+-+
 			qsAction = QString ("jump+-+vmgm+-+");
