@@ -15,7 +15,6 @@
 #include <qimage.h>
 #include <qpainter.h>
 #include <qpopupmenu.h>
-#include <qlistview.h>
 #include <qwmatrix.h>
 #include <qmessagebox.h>
 
@@ -25,6 +24,7 @@
 #include "dialogmatrix.h"
 #include "menuobject.h"
 #include "textobject.h"	// derived from menuobject
+#include "structuretoolbar.h"
 
 TextObject::TextObject (QWidget *pParent)
 	: MenuObject (pParent)
@@ -79,6 +79,11 @@ void TextObject::setStyleStrategy (int iStyleStrategy)
 	m_Font.setStyleStrategy ((QFont::StyleStrategy)iStyleStrategy);
 }
 
+int TextObject::getStyleStrategy ()
+{
+  return (int)m_iStyleStrategy;
+}
+
 void TextObject::replaceColor (QColor theColor, QColor oldColor)
 {
 	if (getForegroundColor () == oldColor)
@@ -318,6 +323,10 @@ bool TextObject::readProjectFile  (QDomNode &theNode)
 		setTextAlign (textAlign);
 	}
 
+	attribute = theElement.attributeNode ( TEXT_OBJECT_STYLE_STRATEGY );
+	if (!attribute.isNull())
+	        m_iStyleStrategy = attribute.value().toInt();
+
 	attribute = theElement.attributeNode ( TEXT_OBJECT_FONT);
 	if (!attribute.isNull())	{
 		QFont theFont;
@@ -352,6 +361,8 @@ bool TextObject::writeProjectFile (QDomElement &theElement)
 		textNode.setAttribute( TEXT_OBJECT_TEXT, m_qsText );
 	if (getTextAlign() != initialValues.getTextAlign())
 		textNode.setAttribute( TEXT_OBJECT_TEXT_ALIGN, QString("%1,%2").arg(getTextAlign().x()).arg(getTextAlign().y()) );
+	if (getStyleStrategy() != initialValues.getStyleStrategy())
+	        textNode.setAttribute( TEXT_OBJECT_STYLE_STRATEGY, QString("%1").arg(getStyleStrategy()) );
 	if (getFont() != initialValues.getFont())
 		textNode.setAttribute( TEXT_OBJECT_FONT, getFont().toString() );
 	if (getBackgroundColor() != initialValues.getBackgroundColor())
@@ -364,45 +375,78 @@ bool TextObject::writeProjectFile (QDomElement &theElement)
 	return MenuObject::writeProjectFile( textNode );
 }
 
+bool TextObject::createContextMenu (QPoint globalPos)
+{
+        QPoint globalPos2 = globalPos;
+	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+	pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+	globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+	pStackMenu->popup(globalPos, 1);
+
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = new QPopupMenu(m_pParent);
+	m_pContextMenu->insertItem ( tr ("Edit ...")  , this,  SLOT(slotEdit()));
+	m_pContextMenu->insertItem ( tr ("Matrix ..."), this,  SLOT(slotMatrix()));
+	m_pContextMenu->insertItem ( tr ("Delete")    , this,  SLOT(slotDelete()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Add Frame"), this,   SLOT(slotAddFrame()));
+	m_pContextMenu->insertItem ( tr ("Add Image"), this,   SLOT(slotAddImage()));
+	m_pContextMenu->insertItem ( tr ("Add Movie"), this,   SLOT(slotAddMovie()));
+	m_pContextMenu->insertSeparator();
+	m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
+	// Blocking call
+	m_pContextMenu->exec(globalPos2, 3);
+	// Here we mark that the user called a menu item thus we don't want the
+	// base classes to continue with the mouse event
+	delete pStackMenu;
+	// Note the menu might have been already deleted in slotToFront/slotToBack
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = NULL;
+	return true;
+}
+
 void TextObject::createStructure (QListViewItem *pParentItem)
 {
-	QListViewItem *pButtonItem;
-	QListViewItem *pModifierItem;
+	StructureItem *pButtonItem;
+	StructureItem *pModifierItem;
 
 	QString qsName = tr ("Text Object");
-	pButtonItem = new QListViewItem(pParentItem, qsName, m_qsText);
+	pButtonItem = new StructureItem(this, pParentItem, qsName, m_qsText);
 	pButtonItem->setExpandable (TRUE);
 
 	// And finally we create the modifiers info ...
 	if ( !((m_modifiers.fRotate == 0.0) && (m_modifiers.fShearX == 0.0) && (m_modifiers.fShearY == 0.0) &&
 		   (m_modifiers.fZoom   == 1.0) && (m_modifiers.fScaleX == 1.0) && (m_modifiers.fScaleY == 1.0)) )	{
-		pModifierItem = new QListViewItem(pButtonItem, tr ("Modifiers"), NULL);
+	  pModifierItem = new StructureItem(this, pButtonItem, tr ("Modifiers"), NULL);
 		pButtonItem->setExpandable (TRUE);
 
-		new QListViewItem(pModifierItem, tr ("Shear (x, y)"),
+		new StructureItem(this, pModifierItem, tr ("Shear (x, y)"),
 			QString ("%1, %2").arg(m_modifiers.fShearX).arg(m_modifiers.fShearY));
-		new QListViewItem(pModifierItem, tr ("Zoom"),
+		new StructureItem(this, pModifierItem, tr ("Zoom"),
 			QString ("%1").arg(m_modifiers.fZoom));
-		new QListViewItem(pModifierItem, tr ("Rotate"),
+		new StructureItem(this, pModifierItem, tr ("Rotate"),
 			QString ("%1 deg").arg(m_modifiers.fRotate));
 	}
 
 	if (m_colorBackground == QColor (TRANSPARENT_COLOR))
-		new QListViewItem(pButtonItem, tr ("Background"), tr ("Transparent"));
+	  new StructureItem(this, pButtonItem, tr ("Background"), tr ("Transparent"));
 	else
-		new QListViewItem(pButtonItem, tr ("Background"),
+	  new StructureItem(this, pButtonItem, tr ("Background"),
 			tr ("color(%1, %2, %3)").
 				arg(m_colorBackground.red()).
 				arg(m_colorBackground.green()).
 				arg(m_colorBackground.blue()));
 
-	new QListViewItem(pButtonItem, tr ("Foreground"),
+	new StructureItem(this, pButtonItem, tr ("Foreground"),
 		QString ("color(%1, %2, %3)").
 			arg(m_colorForeground.red()).
 			arg(m_colorForeground.green()).
 			arg(m_colorForeground.blue()));
 
-	new QListViewItem(pButtonItem, tr ("Geometry"),
+	new StructureItem(this, pButtonItem, tr ("Geometry"),
 		QString ("%1, %2, %3, %4").
 		arg(rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()));
 }
@@ -428,6 +472,17 @@ bool TextObject::mouseMoveEvent (QMouseEvent *pEvent)
 
 bool TextObject::mousePressEvent (QMouseEvent *pEvent)
 {
+	m_currentMousePos = pEvent->pos();
+	if (pEvent->button() == Qt::RightButton)	{
+		QPoint globalPos = pEvent->globalPos();
+		return createContextMenu ( globalPos );
+	}
+	else
+		m_bDrawRect = true;
+	return false;
+}
+
+/*
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
 		QPoint globalPos = pEvent->globalPos();
@@ -465,6 +520,7 @@ bool TextObject::mousePressEvent (QMouseEvent *pEvent)
 		m_bDrawRect = true;
 	return false;
 }
+*/
 
 bool TextObject::mouseReleaseEvent (QMouseEvent *)
 {
