@@ -29,37 +29,39 @@ public:
 	virtual bool mouseReleaseEvent     (QMouseEvent *);
 	virtual bool mouseDoubleClickEvent (QMouseEvent *);
 
-	virtual bool readProjectFile  (QDomNode &);
-	virtual bool writeProjectFile (QDomElement &);
-	virtual void createStructure (QListViewItem *);
-	virtual MenuObject *clone();
-	virtual void replaceColor(QColor, QColor);
+	virtual bool readProjectFile       (QDomNode &);
+	virtual bool writeProjectFile      (QDomElement &);
+	virtual void createStructure       (QListViewItem *);
+	virtual bool createContextMenu     (QPoint);
+	virtual MenuObject *clone          (  );
+	virtual void replaceColor          (QColor, QColor);
 
-	virtual void setFont            (QFont &);
-	virtual void setText            (QString &);
-	virtual void setTextAlign       (QPoint &);
-	virtual void setStyleStrategy   (int);
-	virtual void setForegroundColor (QColor &);
-	virtual void setBackgroundColor (QColor &);
-	virtual QFont   &getFont             ();
-	virtual QString &getText             ();
-	virtual QPoint  &getTextAlign        ();
-	virtual QColor  &getForegroundColor  ();
-	virtual QColor  &getBackgroundColor  ();
+	virtual void setFont               (QFont &);
+	virtual void setText               (QString &);
+	virtual void setTextAlign          (QPoint &);
+	virtual void setStyleStrategy      (int);
+	virtual void setForegroundColor    (QColor &);
+	virtual void setBackgroundColor    (QColor &);
+	virtual QFont   &getFont           ();
+	virtual QString &getText           ();
+	virtual QPoint  &getTextAlign      ();
+	virtual int      getStyleStrategy  ();
+	virtual QColor  &getForegroundColor();
+	virtual QColor  &getBackgroundColor();
 
 private:
-	void drawSemiTransparent        (QPainter *);
+	void drawSemiTransparent           (QPainter *);
 
 protected:
 	virtual AnimationAttribute *getSpecificAttributes (long, QString);
 
 public slots:
-	virtual void slotEdit           ();
-	virtual void slotMatrix         ();
-	virtual void slotAddFrame       ();
-	virtual void slotAddImage       ();
-	virtual void slotAddMovie       ();
-	virtual void slotDefineAsButton ();
+	virtual void slotEdit              ();
+	virtual void slotMatrix            ();
+	virtual void slotAddFrame          ();
+	virtual void slotAddImage          ();
+	virtual void slotAddMovie          ();
+	virtual void slotDefineAsButton    ();
 
 protected:
 	QString     m_qsText;
