@@ -20,6 +20,6 @@ void uiDialogRenderPreview::setProgressData (QPixmap *pPixmap, long iCurrentFram
 	m_pProgress->setProgress (iProgress);
 	m_pLabelPreview->setPaletteBackgroundPixmap (*pPixmap);
 //	m_pLabelPreview->setPixmap (*pPixmap);
-	qsFileName.sprintf ("<p align=\"center\">rendered_%08d.png</p>", iCurrentFrameNumber);
+	qsFileName.sprintf ("<p align=\"center\">rendered_%08ld.png</p>", iCurrentFrameNumber);
 	m_pLabelFileName->setText (qsFileName);
 }
