@@ -9,6 +9,7 @@
 ****************************************************************************/
 
 #include <stdlib.h>
+#include <unistd.h>
 
 #include <qmessagebox.h>
 #include <qfileinfo.h>
@@ -29,6 +30,40 @@ Utils::~Utils ()
 
 }
 
+QString Utils::formatChapter (QString qsInput)
+{
+	char cBuffer[20];
+	QString qsReturn ("00:00:00.000");
+	if (qsInput == QString ("0"))
+		return qsReturn;
+	// Here we tidy up the chapter. E.g. 0 gets converted to 00:00:00.000, 0.0.32 to 00:00:32.000 etc
+	QStringList listParts = QStringList::split(":", qsInput);
+	// SanityCheck ...
+	if (listParts.count() < 3)
+		return qsReturn;
+	int iInput = (int)listParts[2].toFloat();
+	sprintf (cBuffer, "%02d:%02d:%02d.%03d", listParts[0].toInt(), listParts[1].toInt(), iInput, (int)((listParts[2].toFloat() - iInput) * 1000));
+	qsReturn = QString (cBuffer);
+	return qsReturn;
+}
+
+QString Utils::getAttribute (QString qsAttrName, QString qsFullString)
+{
+	QString qsReturn;
+	int iStart, iEnd;
+	iStart = qsFullString.find (qsAttrName);
+	if (iStart < 1)
+		return qsReturn;
+	// increase iStart to skip e.g.[chapters="] and get to the start of the chapters.
+	iStart += qsAttrName.length() + 2;
+	// Now we find the end ...
+	iEnd = qsFullString.find ("\"", iStart);
+	if (iEnd < 1) 
+		return qsReturn;
+	qsReturn = qsFullString.mid (iStart, iEnd-iStart);
+	return qsReturn;
+}
+
 QRgb Utils::nearestColor (QRgb *rgbPalette, int iNumColors, QRgb rgbSeeking)
 {
 	QRgb rgbReturn = rgbPalette[0];
@@ -47,6 +82,7 @@ QRgb Utils::nearestColor (QRgb *rgbPalette, int iNumColors, QRgb rgbSeeking)
 		iSquare = iRed*iRed + iGreen*iGreen + iBlue*iBlue;
 		// Okay we are only interested in the total value (not +/-)
 		iCompare = iSquare - iSeeking;
+
 		if (iCompare < 0)
 			iCompare = -iCompare;
 		// Now let us check if we found a color closer then the previous one.
@@ -58,6 +94,75 @@ QRgb Utils::nearestColor (QRgb *rgbPalette, int iNumColors, QRgb rgbSeeking)
 	return rgbReturn;
 }
 
+
+/** 
+ * After a lot of frustration I decided to write this little (slow) routine, to 
+ * - reduce the used colors to 4 AND
+ * - merge all used colors to the lower parts of the palette
+ * - reduce the number of colors in the palette.
+ * This is needed for the button masks in QDVDAuthor. Max = 4 colors shared between
+ * selected and highlighted mask.
+ */
+void Utils::reduceColors ( QImage &theImage, int iNumColors, QRgb *pPalette )
+{
+  bool bFound;
+  uchar *pLine;
+  unsigned long iCounter = 0;
+  int x, y, t, iIndex, iImageColors;
+  QRgb theNearestColor, theColor, *pImageColors;
+
+  // First we have to ensure that we do have a color indexed image.
+  theImage = theImage.convertDepthWithPalette (8, (QRgb *)pPalette, MAX_MASK_COLORS, Qt::ThresholdDither);
+
+  // This will create a image which might have more then the requested colors.
+  // So we replace all colors with the nearest color of the four.
+  pImageColors = theImage.colorTable ();
+  iImageColors = theImage.numColors  ();
+
+  for (t=0;(int)t<iImageColors; t++) {
+    theNearestColor = nearestColor (pPalette, 4, pImageColors[t]);
+    //    theImage.setColor (t, theNearestColor & 0x00ffffff);
+    theImage.setColor (t, theNearestColor );
+  }
+  
+  // Here we are going to shift all colors down to the first iNumColors places
+  for (y=0;y<theImage.height();y++) {
+    pLine = theImage.scanLine ( y );
+    for (x=0;x<theImage.width();x++) {
+      iIndex = pLine[x];
+      theColor = theImage.color ( iIndex );
+      //      theColor &= 0x00ffffff; // disregard the alpha channel for now ...
+      pLine[x] = 0;
+      bFound = false;
+      for ( t=0;t<iNumColors;t++ ) {
+	// Okay we found the new color (and t = the new index)
+	if ( pPalette[t] == theColor ) {
+	  pLine[x] = t;
+	  bFound = true;
+	  t = iNumColors; // exit the inner most loop.
+	}
+      }
+      if ( ! bFound ) // too many output in case something goes wrong 
+	printf ( "Could not find color %X count <%ld>\n", (unsigned)theColor, ++iCounter );
+    }
+  }
+
+  //  printf ( "numColors=%d width=<%d> height=<%d>\n", iImageColors, theImage.width(), theImage.height());
+  //  for (t=0;t<iImageColors;t++) {
+  //    printf ( "Color[%d] = %X", t, theImage.color (t));
+  //    if ( t<iNumColors )
+  //      printf ( " - Palette[%d] = %X", t, pPalette[t]);
+  //    printf ("\n");
+  //  }
+
+  // Then we should cut down the number of colors used ...
+  theImage.setNumColors ( iNumColors );
+
+  // and then set the right colors ...
+  for (t=0;t<iNumColors;t++)
+    theImage.setColor ( t, pPalette [t] );
+}
+
 QString Utils::getVideoFormat (int iWidth, int iHeight)
 {
 	QString qsFormat = ("custom");
@@ -128,13 +233,13 @@ QString Utils::iso639 (QString qsCode, bool bReverse)
 QString Utils::checkForExe( QString qsExe )
 {
 	QString qsExePath;
-	QFileInfo fileInfo(QString ("%1/out.txt").arg(Global::qsTempPath));
+	QFileInfo fileInfo(QString ("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
 	// the next check is to see if we can find 
-	system ((const char *)QString ("which %1 > %2/out.txt 2>/dev/null").arg(qsExe).arg(Global::qsTempPath));
-	fileInfo.setFile(QString("%1/out.txt").arg(Global::qsTempPath));
+	system ((const char *)QString ("which %1 > %2/%3_out.txt 2>/dev/null").arg(qsExe).arg(Global::qsTempPath).arg(getlogin()));
+	fileInfo.setFile(QString("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
 	// Okay we can not find it, so we wont bother asking the user ...
 	if (fileInfo.size() > 4)	{
-		QFile theFile   (QString ("%1/out.txt").arg(Global::qsTempPath));
+	  QFile theFile   (QString ("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
 		theFile.open    (IO_ReadOnly);
 		theFile.readLine(qsExePath, 4096);
 		theFile.close();
@@ -292,15 +397,22 @@ QStringList Utils::getProjectsFromTempPath()
 	// under the temp path
 	uint t;
 	QStringList listOfProjects;
-	QDir tempDir (Global::qsTempPath);
-	QFile backgroundFile;
+	QDir mainMenuDir, tempDir (Global::qsTempPath);
+	QFile backgroundFile, menuBackgroundFile;
+	
 	// But we aree only interested in sub dirs ...
 	tempDir.setFilter (QDir::Dirs);
 	for (t=0;t<tempDir.count();t++)	{
+		// three criterias 
 		backgroundFile.setName(tempDir.absPath() + QString ("/%1/Main Menu VMGM/background.jpg").arg(tempDir[t]));
-//		backgroundFile.setName(tempDir.absPath() + QString ("/%1/background.jpg").arg(tempDir[t]));
+		menuBackgroundFile.setName(tempDir.absPath() + QString ("/%1/background.jpg").arg(tempDir[t]));
+		mainMenuDir.setPath (tempDir.absPath() + QString ("/%1/Main Menu VMGM").arg(tempDir[t]));
 		if (backgroundFile.exists ())
 			listOfProjects.append (tempDir[t]);
+		else if (menuBackgroundFile.exists ())
+			listOfProjects.append (tempDir[t]);
+		else if (mainMenuDir.exists ())
+			listOfProjects.append (tempDir[t]);
 	}
 	return listOfProjects;
 }
@@ -449,3 +561,17 @@ QString Utils::getStringFromMs(int iInput)
 // 	qsReturn.sprintf ("%02d:%02d:%02d.%03d", iHours, iMinutes, iSeconds, (int)fMilliSeconds);
 // 	return qsReturn;
 }
+
+int Utils::getWHFromResolution ( QString qsResolution, bool bWidth )
+{
+  int iXPos;
+  QString qsWidth, qsHeight;
+
+  iXPos = qsResolution.find ("x");
+  if ( bWidth ) {
+    qsWidth  = qsResolution.left (iXPos);
+    return qsWidth.toInt ();
+  }
+  qsHeight = qsResolution.right(iXPos);
+  return qsHeight.toInt ();
+}
