@@ -27,7 +27,9 @@ public:
 
 	 Utils ();
 	~Utils ();
-	
+
+	QString formatChapter        (QString);
+	QString getAttribute         (QString, QString);
 	bool    recRmdir(const QString &, const char *p=NULL) const;
 	QString iso639 (QString, bool b=false);
 	QString checkForExe          (QString);
@@ -39,14 +41,16 @@ public:
 	QString getToolByIndex       (uint);
 	bool    isMandatory          (uint);
 	QValueList<Utils::toolsPaths *> scanSystem ();
-	QRgb    nearestColor (QRgb *, int, QRgb);
+	QRgb    nearestColor         ( QRgb *, int, QRgb );
+	void    reduceColors         ( QImage &, int, QRgb * );
 
 	QImage  convertStringToImage (QString &);
 	QString convertImageToString (QImage  &);
 	QString getVideoFormat       (int,  int);
 
-	int      getMsFromString(QString);
-	QString  getStringFromMs(int);
+	int      getMsFromString     ( QString );
+	QString  getStringFromMs     ( int  );
+	int      getWHFromResolution ( QString, bool );
 
 };
 
