@@ -11,8 +11,8 @@
 #define THE_PROJECT_NAME "ProjectName"
 
 // The following version number is used for the xml - ProjectFile
-#define QDVDAUTHOR_VERSION		"XMLVersion"
-#define QDVDAUTHOR_VERSION_NUMBER	"0.0.9"
+#define QDVDAUTHOR_VERSION                     "XMLVersion"
+#define QDVDAUTHOR_VERSION_NUMBER              "0.1.0"
 
 // Here we goof around with the Templates
 // Nodes
@@ -42,6 +42,11 @@
 // Here are the defines for teh DVDMenu - Interface.
 //#define DVD_MENU                                "DVDMenu"
 #define MENU_NAME                               "MenuName"
+#define MENU_PAUSE                              "MenuPause"
+#define MENU_PRE                                "MenuPre"
+#define MENU_POST                               "MenuPost"
+#define MENU_INTRO                              "MenuIntro"
+#define MENU_EXTRO                              "MenuExtro"
 #define MENU_SOUND                              "MenuSound"
 #define MENU_MOVIE                              "MenuMovie"
 #define MENU_BACKGROUND                         "MenuBackround"
@@ -58,6 +63,9 @@
 #define MENU_FORMAT                             "MenuFormat"
 #define MENU_WIDTH                              "MenuWidth"
 #define MENU_HEIGHT                             "MenuHeight"
+#define MENU_RATIO                              "MenuRatio"
+#define MENU_TITLESET_NR                        "TitlesetNr"
+#define MENU_MENU_NR                            "MenuNr"
 
 // This one is used for Templates. If nothing has been put into a DropZone, ignore.
 #define IGNORE_OBJECT                            "IgnoreObject"
@@ -88,6 +96,7 @@
 #define TEXT_OBJECT                             "TextObject"
 #define TEXT_OBJECT_TEXT                        "Text"
 #define TEXT_OBJECT_TEXT_ALIGN                  "TextAlign"
+#define TEXT_OBJECT_STYLE_STRATEGY              "StyleStrategy"
 #define TEXT_OBJECT_FONT                        "Font"
 #define TEXT_OBJECT_BACKGROUND_COLOR            "BackgroundColor"
 #define TEXT_OBJECT_FOREGROUND_COLOR            "ForegroundColor"
@@ -122,6 +131,8 @@
 // The SourceFileEntry - class
 #define SOURCE_OBJECT                           "SourceEntry"
 #define SOURCE_OBJECT_DISPLAY_NAME              "DisplayName"
+#define SOURCE_OBJECT_PRE                       "Pre"
+#define SOURCE_OBJECT_POST                      "Post"
 #define SOURCE_OBJECT_IS_SOUND_SOURCE           "SoundSource"
 #define SOURCE_OBJECT_INFO                      "SourceInfo"
 #define SOURCE_OBJECT_FILE_NAME                 "File"
@@ -136,8 +147,11 @@
 #define SOURCE_OBJECT_BITS                      "Bits"
 #define SOURCE_OBJECT_SAMPLE                    "Sample"
 #define SOURCE_OBJECT_BPS                       "BPS"
+#define SOURCE_OBJECT_PAUSE                     "Pause"
+#define SOURCE_OBJECT_TITLESET                  "Titleset"
 #define SOURCE_OBJECT_PROPERTIES                "Properties"
 #define SOURCE_OBJECT_TRANSCODE                 "TranscodeInterface"
+#define SOURCE_OBJECT_SUBTITLES                 "Subtitles"
 
 #define SOURCE_PROPERTIES_POST                  "PostCommands"
 #define SOURCE_PROPERTIES_PRE                   "PreCommands"
@@ -156,6 +170,17 @@
 #define TRANSCODE_STARTING_AT                   "StartingAt"
 #define TRANSCODE_ENDING_AT                     "EndingAt"
 
+#define SUBTITLES_SUBTITLE_ENTRY                 "Entry"
+#define SUBTITLES_SUBTITLE_FILE                  "TempFile"
+#define SUBTITLES_FONT                           "Font"
+#define SUBTITLES_RECT                           "Rect"
+#define SUBTITLES_ALIGNMENT                      "Alignment"
+#define SUBTITLES_TRANSPARENCY                   "Transparency"
+#define SUBTITLES_COLORS                         "Colors"
+#define SUBTITLES_SUBTITLE_INDEX                 "Index"
+#define SUBTITLES_SUBTITLE_START                 "Start"
+#define SUBTITLES_SUBTITLE_STOP                  "Stop"
+
 // The Modifier - class - variables :
 #define MODIFIERS                               "Modifiers"
 #define MODIFIERS_ROTATE                        "Rotate"
@@ -164,6 +189,8 @@
 #define MODIFIERS_SCALEY                        "ScaleY"
 #define MODIFIERS_SHEARX                        "ShearX"
 #define MODIFIERS_SHEARY                        "ShearY"
+#define MODIFIERS_START_FRAME                   "StartFrame"
+#define MODIFIERS_STOP_FRAME                    "StopFrame"
 #define MODIFIERS_TRANSPARENCY                  "Transparency"
 
 // The ImageManipulator - class
@@ -180,6 +207,9 @@
 #define MANIPULATOR_GREEN                       "Green"
 #define MANIPULATOR_BLUE                        "Blue"
 #define MANIPULATOR_BRIGHTNESS                  "Brightness"
+#define MANIPULATOR_COLOR_KEY                   "ColorKey"
+#define MANIPULATOR_COLOR                       "Color"
+#define MANIPULATOR_DELTA                       "Delta"
 
 // QRect variables ...
 #define RECT_X                                  "X"
