@@ -27,6 +27,10 @@ CXmlDVDAuthor::~CXmlDVDAuthor ()
 
 }
 
+CXmlDVDAuthor::dvdauthor_struct *CXmlDVDAuthor::getDVDAuthor ()
+{
+  return &m_dvdauthor;
+}
 //////////////////////////////////////////////////////////////
 //
 // READ XML file ...
@@ -41,6 +45,11 @@ bool CXmlDVDAuthor::readXml ()
 	//
 	//////////////////////////////////////////////////////////////////////////////////
 	QString fileName = QFileDialog::getOpenFileName ( QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));
+	return readXml ( fileName );
+}
+
+bool CXmlDVDAuthor::readXml (QString &fileName )
+{
 	// Assign the file
 	QFile projectFile(fileName);
 	if (!projectFile.open(IO_Raw | IO_ReadWrite))
@@ -344,6 +353,11 @@ bool CXmlDVDAuthor::vob_struct::readXml(QDomElement *pNodeElement)
 	// First read the attributes
 	QDomAttr a = pNodeElement->attributeNode ( VOB_FILE );
 	file = a.value();
+	// We assume Global::qsCurrentPath is set to the path of the xml file
+	QFileInfo fileInfo   ( file );
+	if ( fileInfo.isRelative () )
+	  file = Global::qsCurrentPath + "/" + a.value ();
+
 	a = pNodeElement->attributeNode ( VOB_CHAPTERS );
 	chapters = a.value();
 	a = pNodeElement->attributeNode ( VOB_PAUSE );
@@ -376,10 +390,10 @@ bool CXmlDVDAuthor::post_struct::readXml(QDomElement *pNodeElement)
 	value = pNodeElement->text();
 	return true;
 }
-// HJere the readXml functions for CXmlSpumux - class
+// Here the readXml functions for CXmlSpumux - class
 bool CXmlSpumux::subpictures_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlSpumux::subpictures_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+        debug_out ("CXmlSpumux::subpictures_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	// vmgm has no attributes thus far I can tell.
 	// And now read in all remaining nodes and handle them accordingly.
 	QDomNode xmlNode = pNodeElement->firstChild();
@@ -394,9 +408,11 @@ bool CXmlSpumux::subpictures_struct::readXml(QDomElement *pNodeElement)
 bool CXmlSpumux::stream_struct::readXml(QDomElement *pNodeElement)
 {
 	debug_out ("CXmlSpumux::stream_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
-	bool bReturn = true;
-	spu_struct tempSpu;
-	spu_struct *pNewSpu = NULL;
+	bool            bReturn = true;
+	spu_struct      tempSpu;
+	textsub_struct  tempTextsub;
+	spu_struct     *pNewSpu     = NULL;
+	textsub_struct *pNewTextsub = NULL;
 	// And now read in all remaining nodes and handle them accordingly.
 	QDomNode xmlNode = pNodeElement->firstChild();
 	// And only one menus entry is allowed ...
@@ -406,6 +422,10 @@ bool CXmlSpumux::stream_struct::readXml(QDomElement *pNodeElement)
 			pNewSpu = addSpu ();
 			bReturn = pNewSpu->readXml(&searchTree);
 		}
+		if (searchTree.tagName() == tempTextsub.node_name)	{
+			pNewTextsub = addTextsub ();
+			bReturn = pNewTextsub->readXml(&searchTree);
+		}
 		if (!bReturn)
 			return false;
 		// Otherwise go to the next node ...
@@ -467,6 +487,43 @@ bool CXmlSpumux::spu_struct::readXml(QDomElement *pNodeElement)
 	}
 	return true;
 }
+bool CXmlSpumux::textsub_struct::readXml(QDomElement *pNodeElement)
+{
+  debug_out ("CXmlSpumuxr::textsub_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+  // First read the attributes
+  QDomAttr a = pNodeElement->attributeNode ( TEXTSUB_FILENAME );
+  filename = a.value();
+  a = pNodeElement->attributeNode ( TEXTSUB_CHARACTERSET );
+  characterset = a.value();
+  a = pNodeElement->attributeNode ( TEXTSUB_FONTSIZE );
+  fontsize = a.value().toInt();
+  a = pNodeElement->attributeNode ( TEXTSUB_HORIZ_ALIGNMENT );
+  horizontal_alignment = a.value();
+  a = pNodeElement->attributeNode ( TEXTSUB_VERT_ALIGNMENT );
+  vertical_alignment = a.value();
+  a = pNodeElement->attributeNode ( TEXTSUB_LEFT_MARGIN );
+  left_margin = a.value().toInt ();
+  a = pNodeElement->attributeNode ( TEXTSUB_RIGHT_MARGIN );
+  right_margin = a.value().toInt();
+  a = pNodeElement->attributeNode ( TEXTSUB_BOTTOM_MARGIN );
+  bottom_margin = a.value().toInt ();
+  a = pNodeElement->attributeNode ( TEXTSUB_TOP_MARGIN );
+  top_margin = a.value().toInt();
+  a = pNodeElement->attributeNode ( TEXTSUB_FONT );
+  font = a.value();
+  a = pNodeElement->attributeNode ( TEXTSUB_SUBTITLE_FPS );
+  subtitle_fps= a.value().toInt();
+  a = pNodeElement->attributeNode ( TEXTSUB_MOVIE_FPS );
+  movie_fps = a.value().toInt();
+  a = pNodeElement->attributeNode ( TEXTSUB_MOVIE_WIDTH );
+  movie_width = a.value().toInt();
+  a = pNodeElement->attributeNode ( TEXTSUB_MOVIE_HEIGHT );
+  movie_height = a.value().toInt();
+  a = pNodeElement->attributeNode ( TEXTSUB_TRANSPARENT );
+  transparent = a.value();
+
+  return true;
+}
 bool CXmlSpumux::button_struct::readXml(QDomElement *pNodeElement)
 {
 	debug_out ("CXmlSpumux::button_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
@@ -540,6 +597,9 @@ bool CXmlDVDAuthor::writeXml (QString &fileName)
 		return false;
 
 	QString xml = xmlDoc.toString();
+	// QDomDocument converts '<' to "&lt;", So if we want comments in
+	// the generated file, we should replace them here.
+	xml.replace ( "&lt;", "<"); 
 	debug_out ("%s\n", (const char *)xml);
 	projectFile.writeBlock(xml, qstrlen (xml));
 
@@ -547,7 +607,7 @@ bool CXmlDVDAuthor::writeXml (QString &fileName)
 	return true;
 }
 
-bool CXmlDVDAuthor::dvdauthor_struct::writeXml(QDomDocument *pDocument)
+bool CXmlDVDAuthor::dvdauthor_struct::writeXml(QDomDocument *pDocument, QDomElement *)
 {
 	debug_out ("CXmlDVDAuthor::dvdauthor_struct::writeXml <%s>\n", (const char *)node_name);
 	bool bReturn = true;
@@ -883,8 +943,39 @@ CXmlSpumux::~CXmlSpumux ()
 
 bool CXmlSpumux::readXml ()
 {
-//	m_subpictures.readXml();
-	return false;
+  // Here we read in a xml - file and create the neccesary underlying structure.
+  //
+  // For now we are going to ask for the file name here and handle the QDom...
+  // Later on this is done a level further up and only QDomNode * is sent.
+  //
+  //////////////////////////////////////////////////////////////////////////////////
+  QString fileName = QFileDialog::getOpenFileName ( QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));
+  return readXml ( fileName );
+}
+
+bool CXmlSpumux::readXml ( QString &fileName )
+{
+  // Assign the file
+  QFile projectFile(fileName);
+  if (!projectFile.open(IO_Raw | IO_ReadWrite))
+    return false;
+  
+  QDomDocument xmlDoc( DVD_DOCTYPE );
+  if (!xmlDoc.setContent (&projectFile))	{
+    // Error handling ...
+    projectFile.close();
+    int iReturn = QMessageBox::warning ( NULL, QObject::tr ("xml spumux file seems to be defective."),
+					 QObject::tr ("Do you want to try to load another project file ?"),
+					 QMessageBox::Yes, QMessageBox::No);
+    if (iReturn == QMessageBox::Yes)
+      return readXml (); // Okay, user wants to specify another project file.
+  }
+	// And at last lets try to read the information of the file.
+  QDomElement docElem = xmlDoc.documentElement();
+  bool bReturn = m_subpictures.readXml (&docElem);
+  
+  projectFile.close();
+  return bReturn;
 }
 
 bool CXmlSpumux::writeXml ()
@@ -914,6 +1005,7 @@ bool CXmlSpumux::writeXml (QString &fileName)
 	bool bRet = m_subpictures.writeXml (&xmlDoc);
 	if (bRet)	{
 		QString xml = xmlDoc.toString();
+		xml.replace ( "&lt;", "<"); 
 		debug_out ("%s\n", (const char *)xml);
 		projectFile.writeBlock(xml, qstrlen (xml));
 	}
@@ -922,7 +1014,7 @@ bool CXmlSpumux::writeXml (QString &fileName)
 	return bRet;
 }
 
-bool CXmlSpumux::subpictures_struct::writeXml(QDomDocument *pDocument)
+bool CXmlSpumux::subpictures_struct::writeXml(QDomDocument *pDocument, QDomElement *)
 {
 	debug_out ("CXmlSpumux::subpictures_struct::writeXml <%s>\n",(const char *)node_name);
 
@@ -948,8 +1040,18 @@ bool CXmlSpumux::stream_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 			t++;
 		}
 	}
+	t = 0;
+	if (ppArrayTextsub)	{
+		while (ppArrayTextsub[t])	{
+			bReturn = ppArrayTextsub[t]->writeXml(pDocument, &streamNode);
+			if (!bReturn)
+				return false;
+			t++;
+		}
+	}
 	return true;
 }
+
 bool CXmlSpumux::spu_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
 	debug_out ("CXmlSpumux::spu_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
@@ -1002,6 +1104,45 @@ bool CXmlSpumux::spu_struct::writeXml(QDomDocument *pDocument, QDomElement *pNod
 	}
 	return true;
 }
+bool CXmlSpumux::textsub_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
+{
+  debug_out ("CXmlSpumux::textsub_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+  QDomElement txtNode = pDocument->createElement( node_name );	// <spu>
+  if ( ! filename.isNull())
+    txtNode.setAttribute( TEXTSUB_FILENAME, filename );
+  if ( ! characterset.isNull())
+    txtNode.setAttribute( TEXTSUB_CHARACTERSET, characterset );
+  if ( ! font.isNull())
+    txtNode.setAttribute( TEXTSUB_FONT, font );
+  if ( ! transparent.isNull())
+    txtNode.setAttribute( TEXTSUB_TRANSPARENT, transparent );
+  if ( fontsize != 0 )
+    txtNode.setAttribute( TEXTSUB_FONTSIZE, fontsize );
+  if ( ! horizontal_alignment.isNull ( ) )
+    txtNode.setAttribute( TEXTSUB_HORIZ_ALIGNMENT, horizontal_alignment );
+  if ( ! vertical_alignment.isNull ( ) )
+    txtNode.setAttribute( TEXTSUB_VERT_ALIGNMENT, vertical_alignment );
+  if ( left_margin != 0 )
+    txtNode.setAttribute( TEXTSUB_LEFT_MARGIN, left_margin );
+  if ( right_margin != 0 )
+    txtNode.setAttribute( TEXTSUB_RIGHT_MARGIN, right_margin );
+  if ( bottom_margin != 0 )
+    txtNode.setAttribute( TEXTSUB_BOTTOM_MARGIN, bottom_margin );
+  if ( top_margin != 0 )
+    txtNode.setAttribute( TEXTSUB_TOP_MARGIN, top_margin );
+  if ( subtitle_fps != 0.0 )
+    txtNode.setAttribute( TEXTSUB_SUBTITLE_FPS, subtitle_fps );
+  if ( movie_fps != 0 )
+    txtNode.setAttribute( TEXTSUB_MOVIE_FPS, movie_fps );
+  if ( movie_width != 0 )
+    txtNode.setAttribute( TEXTSUB_MOVIE_WIDTH, movie_width );
+  if ( movie_height != 0 )
+    txtNode.setAttribute( TEXTSUB_MOVIE_HEIGHT, movie_height );
+
+  pNodeElement->appendChild( txtNode );
+
+  return true;
+}
 bool CXmlSpumux::button_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
 	// First check if this node holds any information at all ...
@@ -1191,22 +1332,33 @@ CXmlDVDAuthor::dvdauthor_struct::~dvdauthor_struct ()
 
 CXmlSpumux::stream_struct::stream_struct ()
 {
-	node_name = QString ("stream");
-	ppArraySpu = NULL;
+	node_name      = QString ("stream");
+	ppArraySpu     = NULL;
+	ppArrayTextsub = NULL;
 }
 CXmlSpumux::stream_struct::~stream_struct ()
 {
-	// Lets clean up a little bit ...
-	int t=0;
-	if (ppArraySpu)	{
-		spu_struct *pSpu = ppArraySpu[t];
-		while (pSpu)	{
-			delete pSpu;
-			t++;
-			pSpu = ppArraySpu[t];
-		}
-		delete []ppArraySpu;
-	}
+  // Lets clean up a little bit ...
+  int t=0;
+  if (ppArraySpu)	{
+    spu_struct *pSpu = ppArraySpu[t];
+    while (pSpu)	{
+      delete pSpu;
+      t++;
+      pSpu = ppArraySpu[t];
+    }
+    delete []ppArraySpu;
+  }
+  t=0;
+  if (ppArrayTextsub)  {
+    textsub_struct *pTextsub = ppArrayTextsub[t];
+    while  ( pTextsub )	{
+      delete pTextsub;
+      t++;
+      pTextsub = ppArrayTextsub[t];
+    }
+    delete []ppArrayTextsub;
+  }
 }
 CXmlSpumux::spu_struct::spu_struct ()
 {
@@ -1239,6 +1391,19 @@ CXmlSpumux::spu_struct::~spu_struct ()
 		delete []ppArrayAction;
 	}
 }
+CXmlSpumux::textsub_struct::textsub_struct ()
+{
+  node_name = QString ("textsub");
+  horizontal_alignment   = "center";
+  vertical_alignment     = "center";
+  fontsize = left_margin = right_margin = 0;
+  bottom_margin = top_margin = movie_width = movie_height = 0;
+  subtitle_fps = movie_fps = 0.0;
+}
+CXmlSpumux::textsub_struct::~textsub_struct ()
+{
+}
+
 CXmlSpumux::button_struct::button_struct ()
 {
 	node_name = QString ("button");
@@ -1555,6 +1720,38 @@ CXmlSpumux::spu_struct *CXmlSpumux::stream_struct::addSpu ()
 	return ppArraySpu[i];
 }
 
+CXmlSpumux::textsub_struct *CXmlSpumux::stream_struct::addTextsub ()
+{
+  // This function simply enlarges the array of available titlesets.
+  // That'll keep the structure dynamic.
+  if (!ppArrayTextsub)	{
+    // This is the first ...
+    ppArrayTextsub=new textsub_struct *[2];
+    ppArrayTextsub[0]=new textsub_struct;
+    ppArrayTextsub[1]=NULL;
+    return ppArrayTextsub[0];
+  }
+  
+  int i,t=0;
+  textsub_struct *pTextsub = ppArrayTextsub[t];
+  textsub_struct **ppNewArray=NULL, **ppOldArray=NULL;
+  while (pTextsub) 
+    pTextsub = ppArrayTextsub[++t];
+  // Now we have the count of actual titlesets.
+  ppNewArray=new textsub_struct *[t+2];
+  for (i=0;i<t;i++) 
+    ppNewArray[i]=ppArrayTextsub[i];
+
+  ppNewArray[i] = new textsub_struct();
+  ppNewArray[i+1] = NULL;
+  // Now we can delete th old array (but not the contents.
+  ppOldArray     = ppArrayTextsub;
+  ppArrayTextsub = ppNewArray;
+  delete []ppOldArray;
+  // And finally return the latest addition ...
+  return ppArrayTextsub[i];
+}
+
 CXmlSpumux::button_struct *CXmlSpumux::spu_struct::addButton ()
 {
 	// This function simply enlarges the array of available titlesets.
